/**************************************************************************//**
 * @file     system_ARMCM55.c
 * @brief    CMSIS Device System Source File for
 *           ARMCM55 Device
 * @version  V1.0.0
 * @date     30. March 2020
 ******************************************************************************/
/*
 * Copyright (c) 2009-2020 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if defined (ARMCM55)
  #include "WE2_device.h"
#else
#error device not specified!
#endif

#if defined (__ARM_FEATURE_CMSE) &&  (__ARM_FEATURE_CMSE == 3U)
#ifdef TRUSTZONE_SEC
    #include "partition_ARMCM55.h"
#endif
  #endif

#include "board.h"

/*----------------------------------------------------------------------------
 Exception / Interrupt Vector table
 *----------------------------------------------------------------------------*/
extern const VECTOR_TABLE_Type __VECTOR_TABLE[496];

/*----------------------------------------------------------------------------
 System Core Clock Variable
 *----------------------------------------------------------------------------*/
uint32_t SystemCoreClock = SYSTEM_CLOCK;

volatile unsigned long g_time_loop = 0;

#if !defined(ENABLE_OS) && !defined(RTE_CMSIS_RTOS2)
void SysTick_Handler(void) {
	if (g_time_loop >= 0xFFFFFFFF)
		g_time_loop = 0;
	else
		g_time_loop++;
}
#endif

/*----------------------------------------------------------------------------
 System Core Clock update function
 *----------------------------------------------------------------------------*/
void SystemCoreClockInit() {
	uint32_t val = SysTick_LOAD_RELOAD_Msk+1;
	SystemCoreClock = SYSTEM_CLOCK;
	g_time_loop = 0;
	//SYSTICK MAX
	if (SysTick_Config(val)) {

		while (1)
			;
	}
}

void SystemCoreClockUpdate(uint32_t clock) {
	uint32_t val = SysTick_LOAD_RELOAD_Msk+1;
	SystemCoreClock = clock;
	g_time_loop = 0;
	//SYSTICK MAX
	if (SysTick_Config(val)) {

		while (1)
			;
	}
}

/**
 \brief  Get Current Tick.

 */
void SystemGetTick(uint32_t *systick, uint32_t *loop_cnt)
{
	*systick = SysTick->VAL;
	*loop_cnt = g_time_loop;
}
/*----------------------------------------------------------------------------
 System initialization function
 *----------------------------------------------------------------------------*/
void SystemInit(void) {

	SystemCoreClock = SYSTEM_CLOCK;
	SystemCoreClockInit();

}


#if defined (__clang__)
void __attribute__((used)) _platform_post_lib_init() {
	board_init();
}
#endif
