/*
 * veneer_power_ctrl.c
 *
 *  Created on: 2021~129
 *      Author: 902447
 */
#if (__ARM_FEATURE_CMSE & 1) == 0
#error "Need ARMv8-M security extensions"
#elif (__ARM_FEATURE_CMSE & 2) == 0
#error "Compile with --cmse"
#endif

#include <stdio.h>
#include "stdint.h"
#include "arm_cmse.h"
#include "veneer_power_ctrl.h"
#include "hx_drv_scu.h"
#include "hx_drv_pmu.h"
#include "powermode.h"

#ifdef CM55_BIG

/**
 * \brief Sensor DP library PMU to CPU control
 *
 * \retval void.
 */
#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_pmutocpuctrl_NS_t)(void);
#else
typedef void (*sensordplib_pmutocpuctrl_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif
/**
 * \brief Sensor DP library Wait DMA Done
 *
 * \retval void.
 */
#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_waitpmudmadone_NS_t)(void);
#else
typedef void (*sensordplib_waitpmudmadone_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif
/**
 * \brief Sensor DP library Init
 *
 * \retval void.
 */
#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_pmudpinit_NS_t)(void);
#else
typedef void (*sensordplib_pmudpinit_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif

sensordplib_waitpmudmadone_NS_t g_sensordplib_waitpmudmadoneCB = NULL;
sensordplib_pmutocpuctrl_NS_t g_sensordplib_pmutocpuctrlCB = NULL;
sensordplib_pmudpinit_NS_t g_sensordplib_pmudpinitCB = NULL;

/**
 * \brief Sensor DP library PMU to CPU control
 *
 * \retval void.
 */
void sensordplib_pmutocpuctrl_s()
{
	if(g_sensordplib_pmutocpuctrlCB !=NULL )
		g_sensordplib_pmutocpuctrlCB();
}

/**
 * \brief Sensor DP library Wait DMA Done
 *
 * \retval void.
 */
void sensordplib_waitpmudmadone_s()
{
	if(g_sensordplib_waitpmudmadoneCB !=NULL )
		g_sensordplib_waitpmudmadoneCB();
}

/**
 * \brief Sensor DP library Init
 *
 * \retval void.
 */
void sensordplib_pmudpinit_s()
{
	if(g_sensordplib_pmudpinitCB !=NULL )
		g_sensordplib_pmudpinitCB();
}
/**
 * \brief	Configure the power manager library for specific power mode
 *
 * \param[in] PM_CFG_T		configuration of power mode
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_get_defcfg_bymode(void *aCfg, PM_CFG_PWR_MODE_E mode)
{
	return hx_lib_pm_get_defcfg_bymode(aCfg,  mode);
}

/**
 * \brief	check PMU done capture frame done when PMU to ALLON.
 *
 *
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_pmu_dpdone_check(sensordplib_waitpmudmadone_t cb_fun)
{

	g_sensordplib_waitpmudmadoneCB = (sensordplib_waitpmudmadone_NS_t) cmse_nsfptr_create(cb_fun);

	return hx_lib_pm_pmu_dpdone_check(sensordplib_waitpmudmadone_s);
}

/**
 * \brief	hand over control from PMU to CPU. Then CPU can control everything
 *
 *
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_ctrl_fromPMUtoCPU(sensordplib_pmutocpuctrl_t cb_fun)
{

	g_sensordplib_pmutocpuctrlCB = (sensordplib_pmutocpuctrl_NS_t) cmse_nsfptr_create(cb_fun);

	return hx_lib_pm_ctrl_fromPMUtoCPU(sensordplib_pmutocpuctrl_s);
}

/**
 * \brief	Configure the power manager library for specific power mode
 *
 * \param[in] PM_CFG_T		configuration of power mode
 * \param[in] cb_fun		DP initial before enter PMU only use when DP in NS side
 * \param[in] mode		power mode
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_cfg_set(void *aCfg, sensordplib_pmudpinit_t cb_fun, PM_CFG_PWR_MODE_E mode)
{
	g_sensordplib_pmudpinitCB = (sensordplib_pmudpinit_NS_t) cmse_nsfptr_create(cb_fun);

	return hx_lib_pm_cfg_set(aCfg, sensordplib_pmudpinit_s, mode);
}

/**
 * \brief	Get Current power mode in the power manager library
 *
 * \param[out] PM_CFG_T		configuration of power mode
 * \param[in] mode		power mode
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_cfg_get(void *aCfg, PM_CFG_PWR_MODE_E mode)
{
	return hx_lib_pm_cfg_get(aCfg, mode);
}

/**
 * \brief	Get Current power mode in the power manager library
 *
 * \param[out] mode		configuration of power mode
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_mode_get(PM_CFG_PWR_MODE_E *mode)
{
	return hx_lib_pm_mode_get(mode);
}
/**
 * \brief	The function is used to trigger to enter PMU mode. It is handled by PMU library hx_lib_pm_mode_set so application doesn't need take care it.
 *
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_trigger(SCU_PDHSC_HSCCLK_CFG_T *hsc_cfg, SCU_LSC_CLK_CFG_T *lsc_cfg, PM_CLK_PARA_CTRL_E clkparactrl)
{
	SCU_PDHSC_HSCCLK_CFG_T hsc_cfg_S;
	SCU_LSC_CLK_CFG_T lsc_cfg_S;
	memcpy(&hsc_cfg_S, hsc_cfg, sizeof(SCU_PDHSC_HSCCLK_CFG_T));
	memcpy(&lsc_cfg_S, lsc_cfg, sizeof(SCU_LSC_CLK_CFG_T));
	return hx_lib_pm_trigger(hsc_cfg_S, lsc_cfg_S, clkparactrl);
}
#endif

__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_get_event(PMU_WAKEUPEVENT_E *aWakeupEvt, PMU_WAKEUPEVENT1_E *aWakeupEvt1)
{
	return hx_lib_pm_get_event(aWakeupEvt, aWakeupEvt1);
}


/**
 * \brief	The function is used to clear the PMU wake up event flag
 *
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_clear_event(void)
{
	return hx_lib_pm_clear_event();
}
/**
 * \brief	The function is used to Force PMU to go to power state
 *
 * \param[in] state	 force power state
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_force_state_set(PMU_PS_STATE_E state)
{
	return hx_lib_pm_force_state_set(state);
}

/**
 * \brief	The function is used to get power state
 *
 * \param[in] state	 get power state
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_force_state_get(PMU_PS_STATE_E *state)
{
	return hx_lib_pm_force_state_get(state);
}

/**
 * \brief	The function is used to set dma usage cfg
 *
 * \param[in] dma_int	 dma_int cfg
 * \retval	PM_NO_ERROR		success
 * \retval	others			fail
 */
__attribute__((cmse_nonsecure_entry))  PM_ERROR_E veneer_pm_set_dma_cfg(uint8_t dma_int)
{
	hx_drv_pmu_set_ctrl(PMU_REG_PMU_DMA_CFG, dma_int);//WDMA1
	return PM_NO_ERROR;
}
