#-------------------------------------------------------------------------------
# Copyright (c) 2020-2022, Arm Limited. All rights reserved.
# Copyright (c) 2021-2022 Cypress Semiconductor Corporation (an Infineon company)
# or an affiliate of Cypress Semiconductor Corporation. All rights reserved.
#
# SPDX-License-Identifier: BSD-3-Clause
#
#-------------------------------------------------------------------------------

#function(tfm_invalid_config)
#    if (${ARGV})
#        string (REPLACE ";" " " ARGV_STRING "${ARGV}")
#        string (REPLACE "STREQUAL"     "=" ARGV_STRING "${ARGV_STRING}")
#        string (REPLACE "GREATER"      ">" ARGV_STRING "${ARGV_STRING}")
#        string (REPLACE "LESS"         "<" ARGV_STRING "${ARGV_STRING}")
#        string (REPLACE "VERSION_LESS" "<" ARGV_STRING "${ARGV_STRING}")
#        string (REPLACE "EQUAL"        "=" ARGV_STRING "${ARGV_STRING}")
#        string (REPLACE "IN_LIST"      "in" ARGV_STRING "${ARGV_STRING}")
#
#        message(FATAL_ERROR "INVALID CONFIG: ${ARGV_STRING}")
#    endif()
#endfunction()

#set (VALID_ISOLATION_LEVELS 1 2 3)
$(eval $(call set_tfm_vars,VALID_ISOLATION_LEVELS,1 2 3))

#tfm_invalid_config(NOT TFM_ISOLATION_LEVEL IN_LIST VALID_ISOLATION_LEVELS)
ifeq ($(findstring $(strip ${TFM_ISOLATION_LEVEL}),$(strip ${VALID_ISOLATION_LEVELS})),) # OR logic
$(error tfm_invalid_config. TFM_ISOLATION_LEVEL = ${TFM_ISOLATION_LEVEL})
endif

#tfm_invalid_config(TFM_ISOLATION_LEVEL EQUAL 3 AND NOT PLATFORM_HAS_ISOLATION_L3_SUPPORT)
ifeq ($(strip ${TFM_ISOLATION_LEVEL}),3)
ifeq ($(strip ${PLATFORM_HAS_ISOLATION_L3_SUPPORT}),OFF)
$(error tfm_invalid_config. TFM_ISOLATION_LEVEL = ${TFM_ISOLATION_LEVEL}, PLATFORM_HAS_ISOLATION_L3_SUPPORT = ${PLATFORM_HAS_ISOLATION_L3_SUPPORT})
endif
endif

#tfm_invalid_config(TFM_ISOLATION_LEVEL GREATER 1 AND PSA_FRAMEWORK_HAS_MM_IOVEC)
ifneq ($(strip ${TFM_ISOLATION_LEVEL}),1)
ifeq ($(strip ${PSA_FRAMEWORK_HAS_MM_IOVEC}),ON)
$(error tfm_invalid_config. TFM_ISOLATION_LEVEL = ${TFM_ISOLATION_LEVEL}, PSA_FRAMEWORK_HAS_MM_IOVEC = ${PSA_FRAMEWORK_HAS_MM_IOVEC})
endif
endif

#tfm_invalid_config(TFM_MULTI_CORE_TOPOLOGY AND TFM_NS_MANAGE_NSID)
ifeq ($(strip ${TFM_MULTI_CORE_TOPOLOGY}),ON)
ifeq ($(strip ${TFM_NS_MANAGE_NSID}),ON)
$(error tfm_invalid_config. TFM_MULTI_CORE_TOPOLOGY = ${TFM_MULTI_CORE_TOPOLOGY}, TFM_NS_MANAGE_NSID = ${TFM_NS_MANAGE_NSID})
endif
endif

#tfm_invalid_config(TFM_PLAT_SPECIFIC_MULTI_CORE_COMM AND NOT TFM_MULTI_CORE_TOPOLOGY)
ifeq ($(strip ${TFM_PLAT_SPECIFIC_MULTI_CORE_COMM}),ON)
ifeq ($(strip ${TFM_MULTI_CORE_TOPOLOGY}),OFF)
$(error tfm_invalid_config. TFM_PLAT_SPECIFIC_MULTI_CORE_COMM = ${TFM_PLAT_SPECIFIC_MULTI_CORE_COMM}, TFM_MULTI_CORE_TOPOLOGY = ${TFM_MULTI_CORE_TOPOLOGY})
endif
endif

# Multi-core platform with mailbox partition cannot fully work with SFN backend yet.
#tfm_invalid_config(TFM_PARTITION_NS_AGENT_MAILBOX AND CONFIG_TFM_SPM_BACKEND_SFN)
ifeq ($(strip ${TFM_PARTITION_NS_AGENT_MAILBOX}),ON)
ifeq ($(strip ${CONFIG_TFM_SPM_BACKEND_SFN}),ON)
$(error tfm_invalid_config. TFM_PARTITION_NS_AGENT_MAILBOX = ${TFM_PARTITION_NS_AGENT_MAILBOX}, CONFIG_TFM_SPM_BACKEND_SFN = ${CONFIG_TFM_SPM_BACKEND_SFN})
endif
endif

#tfm_invalid_config(TFM_ISOLATION_LEVEL EQUAL 3 AND CONFIG_TFM_STACK_WATERMARKS)
ifeq ($(strip ${TFM_ISOLATION_LEVEL}),3)
ifeq ($(strip ${CONFIG_TFM_STACK_WATERMARKS}),ON)
$(error tfm_invalid_config. TFM_ISOLATION_LEVEL = ${TFM_ISOLATION_LEVEL}, CONFIG_TFM_STACK_WATERMARKS = ${CONFIG_TFM_STACK_WATERMARKS})
endif
endif

#tfm_invalid_config((TFM_S_REG_TEST OR TFM_NS_REG_TEST) AND TEST_PSA_API)
ifeq ($(findstring ON,$(strip ${TFM_S_REG_TEST}) $(strip ${TFM_S_REG_TEST})),) # OR logic
ifeq ($(strip ${TEST_PSA_API}),ON)
$(error tfm_invalid_config. TFM_S_REG_TEST = ${TFM_S_REG_TEST}, TFM_NS_REG_TEST = ${TFM_NS_REG_TEST}, TEST_PSA_API = ${TEST_PSA_API})
endif
endif

#tfm_invalid_config(SUITE STREQUAL "IPC" AND NOT TEST_PSA_API STREQUAL "IPC")

#tfm_invalid_config(TEST_PSA_API STREQUAL "CRYPTO" AND NOT TFM_PARTITION_CRYPTO)
ifeq ($(strip ${TEST_PSA_API}),CRYPTO)
ifeq ($(TFM_PARTITION_CRYPTO),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_CRYPTO = ${TFM_PARTITION_CRYPTO})
endif
endif

#tfm_invalid_config(TEST_PSA_API STREQUAL "INITIAL_ATTESTATION" AND NOT TFM_PARTITION_INITIAL_ATTESTATION)
ifeq ($(strip ${TEST_PSA_API}),INITIAL_ATTESTATION)
ifeq ($(TFM_PARTITION_INITIAL_ATTESTATION),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_INITIAL_ATTESTATION = ${TFM_PARTITION_INITIAL_ATTESTATION})
endif
endif

#tfm_invalid_config(TEST_PSA_API STREQUAL "INTERNAL_TRUSTED_STORAGE" AND NOT TFM_PARTITION_INTERNAL_TRUSTED_STORAGE)
ifeq ($(strip ${TEST_PSA_API}),INTERNAL_TRUSTED_STORAGE)
ifeq ($(TFM_PARTITION_INTERNAL_TRUSTED_STORAGE),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_INTERNAL_TRUSTED_STORAGE = ${TFM_PARTITION_INTERNAL_TRUSTED_STORAGE})
endif
endif

#tfm_invalid_config(TEST_PSA_API STREQUAL "PROTECTED_STORAGE" AND NOT TFM_PARTITION_PROTECTED_STORAGE)
ifeq ($(strip ${TEST_PSA_API}),PROTECTED_STORAGE)
ifeq ($(TFM_PARTITION_PROTECTED_STORAGE),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_PROTECTED_STORAGE = ${TFM_PARTITION_PROTECTED_STORAGE})
endif
endif

#tfm_invalid_config(TEST_PSA_API STREQUAL "STORAGE" AND NOT TFM_PARTITION_INTERNAL_TRUSTED_STORAGE)
ifeq ($(strip ${TEST_PSA_API}),STORAGE)
ifeq ($(TFM_PARTITION_INTERNAL_TRUSTED_STORAGE),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_INTERNAL_TRUSTED_STORAGE = ${TFM_PARTITION_INTERNAL_TRUSTED_STORAGE})
endif
endif

#tfm_invalid_config(TEST_PSA_API STREQUAL "STORAGE" AND NOT TFM_PARTITION_PROTECTED_STORAGE)
ifeq ($(strip ${TEST_PSA_API}),STORAGE)
ifeq ($(TFM_PARTITION_PROTECTED_STORAGE),OFF)
$(error tfm_invalid_config. TEST_PSA_API = ${TEST_PSA_API}, TFM_PARTITION_PROTECTED_STORAGE = ${TFM_PARTITION_PROTECTED_STORAGE})
endif
endif

########################## BL1 #################################################

#tfm_invalid_config((BL1 AND PLATFORM_DEFAULT_BL1 AND CONFIG_TFM_BOOT_STORE_MEASUREMENTS) AND NOT TFM_PARTITION_MEASURED_BOOT)
ifeq ($(strip ${BL1}),ON)
ifeq ($(strip ${PLATFORM_DEFAULT_BL1}),ON)
ifeq ($(strip ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}),ON)
ifeq ($(strip ${TFM_PARTITION_MEASURED_BOOT}),OFF)
$(error tfm_invalid_config. BL1 = ${BL1}, PLATFORM_DEFAULT_BL1 = ${PLATFORM_DEFAULT_BL1}, CONFIG_TFM_BOOT_STORE_MEASUREMENTS = ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}, TFM_PARTITION_MEASURED_BOOT = ${TFM_PARTITION_MEASURED_BOOT})
endif
endif
endif
endif

########################## BL2 #################################################

#get_property(MCUBOOT_STRATEGY_LIST CACHE MCUBOOT_UPGRADE_STRATEGY PROPERTY STRINGS)
#tfm_invalid_config(BL2 AND (NOT MCUBOOT_UPGRADE_STRATEGY IN_LIST MCUBOOT_STRATEGY_LIST))
ifeq ($(strip ${BL2}),ON)
ifeq ($(strip ${MCUBOOT_UPGRADE_STRATEGY_PROPERTY}),)
$(error tfm_invalid_config. MCUBOOT_UPGRADE_STRATEGY_PROPERTY = ${MCUBOOT_UPGRADE_STRATEGY_PROPERTY})
endif
ifeq ($(findstring $(strip ${MCUBOOT_UPGRADE_STRATEGY}),$(strip ${MCUBOOT_UPGRADE_STRATEGY_PROPERTY})),) # OR logic
$(error tfm_invalid_config. BL2 = ${BL2}, MCUBOOT_UPGRADE_STRATEGY = ${MCUBOOT_UPGRADE_STRATEGY})
endif
endif

# Maximum number of MCUBoot images supported by TF-M NV counters and ROTPKs
#tfm_invalid_config(MCUBOOT_IMAGE_NUMBER GREATER 4)
ifneq ($(strip ${MCUBOOT_IMAGE_NUMBER}),)
ifeq ($(findstring $(strip ${MCUBOOT_IMAGE_NUMBER}),0 1 2 3 4),) # OR logic
$(error tfm_invalid_config. MCUBOOT_IMAGE_NUMBER = ${MCUBOOT_IMAGE_NUMBER})
endif
endif

#tfm_invalid_config((BL2 AND CONFIG_TFM_BOOT_STORE_MEASUREMENTS AND NOT CONFIG_TFM_BOOT_STORE_ENCODED_MEASUREMENTS) AND NOT MCUBOOT_DATA_SHARING)
ifeq ($(strip ${BL2}),ON)
ifeq ($(strip ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}),ON)
ifeq ($(strip ${CONFIG_TFM_BOOT_STORE_ENCODED_MEASUREMENTS}),OFF)
ifeq ($(strip ${MCUBOOT_DATA_SHARING}),OFF)
$(error tfm_invalid_config. BL2 = ${BL2}, CONFIG_TFM_BOOT_STORE_MEASUREMENTS = ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}, CONFIG_TFM_BOOT_STORE_ENCODED_MEASUREMENTS = ${CONFIG_TFM_BOOT_STORE_ENCODED_MEASUREMENTS}, MCUBOOT_DATA_SHARING = ${MCUBOOT_DATA_SHARING})
endif
endif
endif
endif

#tfm_invalid_config((NOT (TFM_PARTITION_FIRMWARE_UPDATE OR CONFIG_TFM_BOOT_STORE_MEASUREMENTS)) AND MCUBOOT_DATA_SHARING)
ifeq ($(strip ${TFM_PARTITION_FIRMWARE_UPDATE}),OFF)
ifeq ($(strip ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}),OFF)
ifeq ($(strip ${MCUBOOT_DATA_SHARING}),ON)
$(error tfm_invalid_config. TFM_PARTITION_FIRMWARE_UPDATE = ${TFM_PARTITION_FIRMWARE_UPDATE}, CONFIG_TFM_BOOT_STORE_MEASUREMENTS = ${CONFIG_TFM_BOOT_STORE_MEASUREMENTS}, MCUBOOT_DATA_SHARING = ${MCUBOOT_DATA_SHARING})
endif
endif
endif

#set_property(CACHE MCUBOOT_ALIGN_VAL PROPERTY STRINGS "1;2;4;8;16;32")
$(eval $(call set_tfm_cache_vars_property,MCUBOOT_ALIGN_VAL,1 2 4 8 16 32))
#get_property(MCUBOOT_ALIGN_VAL_LIST CACHE MCUBOOT_ALIGN_VAL PROPERTY STRINGS)
#tfm_invalid_config(BL2 AND (NOT MCUBOOT_ALIGN_VAL IN_LIST MCUBOOT_ALIGN_VAL_LIST))
ifeq ($(strip ${BL2}),ON)
ifeq ($(findstring $(strip ${MCUBOOT_ALIGN_VAL}),$(strip ${MCUBOOT_ALIGN_VAL_PROPERTY})),) # OR logic
$(error tfm_invalid_config. BL2 = ${BL2}, MCUBOOT_ALIGN_VAL = ${MCUBOOT_ALIGN_VAL})
endif
endif
####################### Code sharing ###########################################

#set(TFM_CODE_SHARING_PLATFORM_LISTS arm/mps2/an521 arm/musca_b1) # Without crypto hw acceleration
#tfm_invalid_config(NOT TFM_CODE_SHARING STREQUAL "OFF" AND NOT TFM_PLATFORM IN_LIST TFM_CODE_SHARING_PLATFORM_LISTS)
ifneq ($(strip ${TFM_CODE_SHARING}),OFF)
ifeq ($(findstring $(strip ${TFM_PLATFORM}),arm/mps2/an521 arm/musca_b1),) # OR logic
$(error tfm_invalid_config. BL2 = ${BL2}, MCUBOOT_ALIGN_VAL = ${MCUBOOT_ALIGN_VAL})
endif
endif
#tfm_invalid_config(NOT TFM_CODE_SHARING STREQUAL "OFF" AND CRYPTO_HW_ACCELERATOR)
ifneq ($(strip ${TFM_CODE_SHARING}),OFF)
ifeq ($(strip ${CRYPTO_HW_ACCELERATOR}),ON)
$(error tfm_invalid_config. TFM_CODE_SHARING = ${TFM_CODE_SHARING}, CRYPTO_HW_ACCELERATOR = ${CRYPTO_HW_ACCELERATOR})
endif
endif
#tfm_invalid_config(NOT TFM_CODE_SHARING STREQUAL "OFF" AND NOT C_COMPILER_ID:IAR)
ifneq ($(strip ${TFM_CODE_SHARING}),OFF)
ifneq ($(findstring $(strip ${TOOLCHAIN}),gnu arm),) # OR logic
$(error tfm_invalid_config. TFM_CODE_SHARING = ${TFM_CODE_SHARING}, TOOLCHAIN = ${TOOLCHAIN})
endif
endif
########################## Platform ############################################

#tfm_invalid_config(OTP_NV_COUNTERS_RAM_EMULATION AND NOT (PLATFORM_DEFAULT_OTP OR PLATFORM_DEFAULT_NV_COUNTERS))
ifeq ($(strip ${OTP_NV_COUNTERS_RAM_EMULATION}),ON)
ifeq ($(strip ${PLATFORM_DEFAULT_OTP}),OFF)
ifeq ($(strip ${PLATFORM_DEFAULT_NV_COUNTERS}),OFF)
$(error tfm_invalid_config. OTP_NV_COUNTERS_RAM_EMULATION = ${OTP_NV_COUNTERS_RAM_EMULATION}, PLATFORM_DEFAULT_OTP = ${PLATFORM_DEFAULT_OTP}, PLATFORM_DEFAULT_NV_COUNTERS = ${PLATFORM_DEFAULT_NV_COUNTERS})
endif
endif
endif

#tfm_invalid_config(PLATFORM_DEFAULT_NV_COUNTERS AND  NOT PLATFORM_DEFAULT_OTP_WRITEABLE)
ifeq ($(strip ${PLATFORM_DEFAULT_NV_COUNTERS}),ON)
ifeq ($(strip ${PLATFORM_DEFAULT_OTP_WRITEABLE}),OFF)
$(error tfm_invalid_config. PLATFORM_DEFAULT_NV_COUNTERS = ${PLATFORM_DEFAULT_NV_COUNTERS}, PLATFORM_DEFAULT_OTP_WRITEABLE = ${PLATFORM_DEFAULT_OTP_WRITEABLE})
endif
endif

#tfm_invalid_config(TFM_DUMMY_PROVISIONING AND (PLATFORM_DEFAULT_OTP AND NOT PLATFORM_DEFAULT_OTP_WRITEABLE))
ifeq ($(strip ${TFM_DUMMY_PROVISIONING}),ON)
ifeq ($(strip ${PLATFORM_DEFAULT_OTP}),ON)
ifeq ($(strip ${PLATFORM_DEFAULT_OTP_WRITEABLE}),OFF)
$(error tfm_invalid_config. TFM_DUMMY_PROVISIONING = ${TFM_DUMMY_PROVISIONING}, PLATFORM_DEFAULT_OTP = ${PLATFORM_DEFAULT_OTP}, PLATFORM_DEFAULT_OTP_WRITEABLE = ${PLATFORM_DEFAULT_OTP_WRITEABLE})
endif
endif
endif

#tfm_invalid_config(TFM_NS_NV_COUNTER_AMOUNT GREATER 3)
ifeq ($(findstring $(strip ${TFM_NS_NV_COUNTER_AMOUNT}),0 1 2 3),) # OR logic
$(error tfm_invalid_config. TFM_NS_NV_COUNTER_AMOUNT = ${TFM_NS_NV_COUNTER_AMOUNT})
endif

####################### Firmware Update Parttion ###############################

#tfm_invalid_config(NOT PLATFORM_HAS_FIRMWARE_UPDATE_SUPPORT AND TFM_PARTITION_FIRMWARE_UPDATE)
ifeq ($(strip ${PLATFORM_HAS_FIRMWARE_UPDATE_SUPPORT}),OFF)
ifeq ($(strip ${TFM_PARTITION_FIRMWARE_UPDATE}),ON)
$(error tfm_invalid_config. PLATFORM_HAS_FIRMWARE_UPDATE_SUPPORT = ${PLATFORM_HAS_FIRMWARE_UPDATE_SUPPORT}, TFM_PARTITION_FIRMWARE_UPDATE = ${TFM_PARTITION_FIRMWARE_UPDATE})
endif
endif

#tfm_invalid_config(TFM_PARTITION_FIRMWARE_UPDATE AND NOT TFM_PARTITION_PLATFORM)
ifeq ($(strip ${TFM_PARTITION_FIRMWARE_UPDATE}),ON)
ifeq ($(strip ${TFM_PARTITION_PLATFORM}),OFF)
$(error tfm_invalid_config. TFM_PARTITION_FIRMWARE_UPDATE = ${TFM_PARTITION_FIRMWARE_UPDATE}, TFM_PARTITION_PLATFORM = ${TFM_PARTITION_PLATFORM})
endif
endif
#tfm_invalid_config((MCUBOOT_UPGRADE_STRATEGY STREQUAL "DIRECT_XIP" OR MCUBOOT_UPGRADE_STRATEGY STREQUAL "RAM_LOAD") AND TFM_PARTITION_FIRMWARE_UPDATE)
ifeq ($(findstring $(strip ${MCUBOOT_UPGRADE_STRATEGY}),DIRECT_XIP RAM_LOAD),) # OR logic
ifeq ($(strip ${TFM_PARTITION_FIRMWARE_UPDATE}),ON)
$(error tfm_invalid_config. MCUBOOT_UPGRADE_STRATEGY = ${MCUBOOT_UPGRADE_STRATEGY}, TFM_PARTITION_FIRMWARE_UPDATE = ${TFM_PARTITION_FIRMWARE_UPDATE})
endif
endif

#tfm_invalid_config(TFM_PARTITION_FIRMWARE_UPDATE AND NOT MCUBOOT_DATA_SHARING)
ifeq ($(strip ${TFM_PARTITION_FIRMWARE_UPDATE}),ON)
ifeq ($(strip ${MCUBOOT_DATA_SHARING}),OFF)
$(error tfm_invalid_config. TFM_PARTITION_FIRMWARE_UPDATE = ${TFM_PARTITION_FIRMWARE_UPDATE}, MCUBOOT_DATA_SHARING = ${MCUBOOT_DATA_SHARING})
endif
endif

####################### Protected Storage Parttion ###############################

#tfm_invalid_config(TFM_PARTITION_PROTECTED_STORAGE AND NOT TFM_PARTITION_INTERNAL_TRUSTED_STORAGE)
ifeq ($(strip ${TFM_PARTITION_PROTECTED_STORAGE}),ON)
ifeq ($(strip ${TFM_PARTITION_INTERNAL_TRUSTED_STORAGE}),OFF)
$(error tfm_invalid_config. TFM_PARTITION_PROTECTED_STORAGE = ${TFM_PARTITION_PROTECTED_STORAGE}, TFM_PARTITION_INTERNAL_TRUSTED_STORAGE = ${TFM_PARTITION_INTERNAL_TRUSTED_STORAGE})
endif
endif
# PS only uses the platform partition when PS_ROLLBACK_PROTECTION is ON, but
# the dependency in the manifest file means the dependency is unconditional
#tfm_invalid_config(TFM_PARTITION_PROTECTED_STORAGE AND NOT TFM_PARTITION_PLATFORM)
ifeq ($(strip ${TFM_PARTITION_PROTECTED_STORAGE}),ON)
ifeq ($(strip ${TFM_PARTITION_PLATFORM}),OFF)
$(error tfm_invalid_config. TFM_PARTITION_PROTECTED_STORAGE = ${TFM_PARTITION_PROTECTED_STORAGE}, TFM_PARTITION_PLATFORM = ${TFM_PARTITION_PLATFORM})
endif
endif

########################## FIH #################################################

#get_property(TFM_FIH_PROFILE_LIST CACHE TFM_FIH_PROFILE PROPERTY STRINGS)
ifeq ($(strip ${TFM_FIH_PROFILE_PROPERTY}),)
$(error tfm_invalid_config. TFM_FIH_PROFILE_PROPERTY = ${TFM_FIH_PROFILE_PROPERTY})
endif
#tfm_invalid_config(NOT TFM_FIH_PROFILE IN_LIST TFM_FIH_PROFILE_LIST)
ifeq ($(findstring $(strip ${TFM_FIH_PROFILE}),$(strip ${TFM_FIH_PROFILE_PROPERTY})),) # OR logic
$(error tfm_invalid_config. TFM_FIH_PROFILE = ${TFM_FIH_PROFILE})
endif

########################### TF-M initial attestation #####################################

#tfm_invalid_config(ATTEST_INCLUDE_TEST_CODE AND NOT (TEST_NS_ATTESTATION OR TEST_S_ATTESTATION))
ifeq ($(strip ${ATTEST_INCLUDE_TEST_CODE}),ON)
ifeq ($(strip ${TEST_NS_ATTESTATION}),OFF)
ifeq ($(strip ${TEST_S_ATTESTATION}),OFF)
$(error tfm_invalid_config. ATTEST_INCLUDE_TEST_CODE = ${ATTEST_INCLUDE_TEST_CODE}, TEST_NS_ATTESTATION = ${TEST_NS_ATTESTATION}, TEST_S_ATTESTATION = ${TEST_S_ATTESTATION})
endif
endif
endif
######################## TF-M Profile config check #############################

#tfm_invalid_config(TFM_PROFILE STREQUAL "profile_small" AND CONFIG_TFM_SPM_BACKEND_IPC)
ifeq ($(strip ${TFM_PROFILE}),profile_small)
ifeq ($(strip ${CONFIG_TFM_SPM_BACKEND_IPC}),ON)
$(error tfm_invalid_config. TFM_PROFILE = ${TFM_PROFILE}, CONFIG_TFM_SPM_BACKEND_IPC = ${CONFIG_TFM_SPM_BACKEND_IPC})
endif
endif
########################### Test check config ##################################

#if(TFM_S_REG_TEST OR TFM_NS_REG_TEST)
#    include(${TFM_TEST_PATH}/config/check_config.cmake)
#endif()
ifneq ($(findstring ON,$(strip ${TFM_S_REG_TEST}) $(strip ${TFM_NS_REG_TEST})),) # OR logic
include ${TFM_ROOT}/lib/ext/tfm_test_repo-src/test/config/check_config.mk
endif

###################### Compiler check for FP support ###########################

#include(config/cp_check.cmake)
include ${TFM_ROOT}/config/cp_check.mk

###################### Platform-specific checks ################################

#if (EXISTS ${CMAKE_SOURCE_DIR}/platform/ext/target/${TFM_PLATFORM}/check_config.cmake)
#    include(platform/ext/target/${TFM_PLATFORM}/check_config.cmake)
#endif()
-include ${TFM_ROOT}/platform/ext/target/${TFM_PLATFORM}/check_config.mk
