/*
 * Copyright (c) 2021-2022, Arm Limited. All rights reserved.
 * Copyright (c) 2021-2022 Cypress Semiconductor Corporation (an Infineon
 * company) or an affiliate of Cypress Semiconductor Corporation. All rights
 * reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

/***********  WARNING: This is an auto-generated file. Do not edit!  ***********/

#include <stdint.h>
#include <stddef.h>
#include "config_tfm.h"
#include "region.h"
#include "region_defs.h"
#include "spm_ipc.h"
#include "load/interrupt_defs.h"
#include "load/partition_defs.h"
#include "load/service_defs.h"
#include "load/asset_defs.h"
#include "tfm_peripherals_def.h"
#include "psa_manifest/pid.h"
#include "psa_manifest/sid.h"
#include "psa_manifest/server_partition_psa.h"

#define SERVER_PARTITION_NDEPS                                  (2)
#define SERVER_PARTITION_NSERVS                                 (7)
#if TFM_LVL == 3
#define SERVER_PARTITION_NASSETS                                (1 + 1)
#else
#define SERVER_PARTITION_NASSETS                                (1)
#endif
#define SERVER_PARTITION_NIRQS                                  (0)

/* Memory region declaration */
#if TFM_LVL == 3
REGION_DECLARE(Image$$, PT_SERVER_PARTITION_PRIVATE, _DATA_START$$Base);
REGION_DECLARE(Image$$, PT_SERVER_PARTITION_PRIVATE, _DATA_END$$Base);
#endif

extern uint8_t server_partition_stack[];

/* Entrypoint function declaration */
extern void server_main(void);

/* Interrupt init functions */

/* partition load info type definition */
struct partition_server_partition_load_info_t {
    /* common length load data */
    struct partition_load_info_t    load_info;
    /* per-partition variable length load data */
    uintptr_t                       stack_addr;
    uintptr_t                       heap_addr;
    uint32_t                        deps[SERVER_PARTITION_NDEPS];
    struct service_load_info_t      services[SERVER_PARTITION_NSERVS];
#if TFM_LVL == 3
    struct asset_desc_t             assets[SERVER_PARTITION_NASSETS];
#else
    struct asset_desc_t             assets[SERVER_PARTITION_NASSETS];
#endif
} __attribute__((aligned(4)));

/* Partition load, deps, service load data. Put to a dedicated section. */
#if defined(__ICCARM__)
#pragma location = ".part_load_priority_normal"
__root
#endif /* __ICCARM__ */
const struct partition_server_partition_load_info_t server_partition_load
    __attribute__((used, section(".part_load_priority_normal"))) = {
    .load_info = {
        .psa_ff_ver                 = 0x0100 | PARTITION_INFO_MAGIC,
        .pid                        = SERVER_PARTITION,
        .flags                      = 0
                                    | PARTITION_MODEL_IPC
                                    | PARTITION_PRI_NORMAL,
        .entry                      = ENTRY_TO_POSITION(server_main),
        .stack_size                 = 0x400,
        .heap_size                  = 0,
        .ndeps                      = SERVER_PARTITION_NDEPS,
        .nservices                  = SERVER_PARTITION_NSERVS,
        .nassets                    = SERVER_PARTITION_NASSETS,
        .nirqs                      = SERVER_PARTITION_NIRQS,
    },
    .stack_addr                     = (uintptr_t)server_partition_stack,
    .heap_addr                      = 0,
    .deps = {
        DRIVER_UART_SID,
        DRIVER_NVMEM_SID,
    },
    .services = {
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_TEST_DISPATCHER"),
            .sfn                    = 0,
            .signal                 = SERVER_TEST_DISPATCHER_SIGNAL,

            .sid                    = 0x0000FB01,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_RELAXED,
            .version                = 1,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_SECURE_CONNECT_ONLY"),
            .sfn                    = 0,
            .signal                 = SERVER_SECURE_CONNECT_ONLY_SIGNAL,

            .sid                    = 0x0000FB02,
            .flags                  = 0
                                    | SERVICE_VERSION_POLICY_RELAXED,
            .version                = 2,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_STRICT_VERSION"),
            .sfn                    = 0,
            .signal                 = SERVER_STRICT_VERSION_SIGNAL,

            .sid                    = 0x0000FB03,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_STRICT,
            .version                = 2,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_UNSPECIFED_VERSION"),
            .sfn                    = 0,
            .signal                 = SERVER_UNSPECIFED_VERSION_SIGNAL,

            .sid                    = 0x0000FB04,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_STRICT,
            .version                = 1,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_RELAX_VERSION"),
            .sfn                    = 0,
            .signal                 = SERVER_RELAX_VERSION_SIGNAL,

            .sid                    = 0x0000FB05,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_RELAXED,
            .version                = 2,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_UNEXTERN"),
            .sfn                    = 0,
            .signal                 = SERVER_UNEXTERN_SIGNAL,

            .sid                    = 0x0000FB06,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_RELAXED,
            .version                = 2,
        },
        {
            .name_strid             = STRING_PTR_TO_STRID("SERVER_CONNECTION_DROP"),
            .sfn                    = 0,
            .signal                 = SERVER_CONNECTION_DROP_SIGNAL,

            .sid                    = 0x0000FB07,
            .flags                  = 0
                                    | SERVICE_FLAG_NS_ACCESSIBLE
                                    | SERVICE_VERSION_POLICY_RELAXED,
            .version                = 2,
        },
    },
#if TFM_LVL == 3
    .assets                         = {
        {
            .mem.start              = PART_REGION_ADDR(PT_SERVER_PARTITION_PRIVATE, _DATA_START$$Base),
            .mem.limit              = PART_REGION_ADDR(PT_SERVER_PARTITION_PRIVATE, _DATA_END$$Base),
            .attr                   = ASSET_ATTR_READ_WRITE,
        },
        {
            .dev.dev_ref            = PTR_TO_REFERENCE(FF_TEST_SERVER_PARTITION_MMIO),
            .attr                   = ASSET_ATTR_NAMED_MMIO
                                    | ASSET_ATTR_READ_WRITE,
        },
    },
#else
    .assets                         = {
        {
            .dev.dev_ref            = PTR_TO_REFERENCE(FF_TEST_SERVER_PARTITION_MMIO),
            .attr                   = ASSET_ATTR_NAMED_MMIO
                                    | ASSET_ATTR_READ_WRITE,
        },
    },
#endif
};

/* Placeholder for partition and service runtime space. Do not reference it. */
#if defined(__ICCARM__)
#pragma location=".bss.part_runtime_priority_normal"
__root
#endif /* __ICCARM__ */
static struct partition_t server_partition_partition_runtime_item
    __attribute__((used, section(".bss.part_runtime_priority_normal")));
#if defined(__ICCARM__)
#pragma location = ".bss.serv_runtime_priority_normal"
__root
#endif /* __ICCARM__ */
static struct service_t server_partition_service_runtime_item[SERVER_PARTITION_NSERVS]
    __attribute__((used, section(".bss.serv_runtime_priority_normal")));
