/*
 * Copyright (c) 2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#ifndef __TFM_FLIH_HX_SERVICE_DEFS_H__
#define __TFM_FLIH_HX_SERVICE_DEFS_H__

#include "psa/framework_feature.h"
#include <limits.h>
#include <stdbool.h>
#include <stdint.h>
#include "tfm_api.h"

enum tfm_hx_err_t {
    TFM_FLIH_HX_ERR_SUCCESS = 0,
    TFM_FLIH_HX_ERR_SYSTEM_ERROR,
    TFM_FLIH_HX_ERR_INVALID_PARAM,
    TFM_FLIH_HX_ERR_NOT_SUPPORTED,

    /* Following entry is only to ensure the error code of int size */
    TFM_FLIH_HX_ERR_FORCE_INT_SIZE = INT_MAX
};

#define TFM_HX_SERVICE                     (0x1000)

//////////////////////////////////////////////////////////
#define _veneer_timer_sensor_start           (0x000)
#define _veneer_timer_sensor_stop            (0x001)
#ifdef CM55_BIG  
#define _veneer_timer_cm55m_start            (0x002)
#define _veneer_timer_cm55m_stop             (0x003)
#else
#define _veneer_timer_cm55s_start            (0x004)
#define _veneer_timer_cm55s_stop             (0x005)  
#endif

//////////////////////////////////////////////////////////
#define _veneer_clk_ctrl_set_timer_clk_en    (0x100)
#define _veneer_clk_ctrl_set_timer_clkdiv    (0x101)
#define _veneer_clk_ctrl_set_wdg_clk_en      (0x102)
#define _veneer_clk_ctrl_set_wdg_clkdiv      (0x103)
#define _veneer_clk_ctrl_set_rtc_clk_en      (0x104)
#define _veneer_clk_ctrl_set_rtc_cycle       (0x105)
#define _veneer_clk_get_freq                 (0x106)
#define _veneer_clk_set_vad_d_src_sel        (0x107)
#define _veneer_clk_get_vad_d_src_sel        (0x108)
#define _veneer_clk_set_i2s_clkdiv           (0x109)
#define _veneer_clk_get_i2s_clkdiv           (0x10A)
#define _veneer_clk_set_pdm_clkdiv           (0x10B)
#define _veneer_clk_get_pdm_clkdiv           (0x10C)
#define _veneer_clk_set_xtal32k_en           (0x10E)
#define _veneer_clk_get_xtal32k_en           (0x10F)
#define _veneer_clk_set_xtal24m_en           (0x110)
#define _veneer_clk_get_xtal24m_en           (0x111)
#ifdef CM55_BIG  
#define _veneer_clk_set_pll_cfg              (0x112)
#endif  
#define _veneer_clk_get_pll_cfg              (0x113)
#define _veneer_clk_get_pll_src              (0x114)
#ifdef CM55_BIG  
#define _veneer_clk_set_pll_enable           (0x115)
#endif  
#define _veneer_clk_get_pll_lock_status      (0x116)
#define _veneer_clk_set_pdhsc_dpclk_cfg      (0x117)
#define _veneer_clk_get_pdhsc_dpclk_cfg      (0x118)
#define _veneer_clk_set_pdhsc_dpclken_cfg    (0x119)
#define _veneer_clk_set_pdhsc_hscclk_cfg     (0x11A)
#define _veneer_clk_get_pdhsc_hscclk_cfg     (0x11B)
#ifdef CM55_BIG
#define _veneer_clk_set_simple_clk_cfg       (0x11C)
#define _veneer_clk_get_simple_clk_cfg       (0x11D)
#endif
//#define _veneer_clk_set_pdhsc_hsc32kclk_cfg  (0x11E)
//#define _veneer_clk_get_pdhsc_hsc32kclk_cfg  (0x11F)
//#define _veneer_clk_set_pdhsc_clk_cfg        (0x120)
//#define _veneer_clk_get_pdhsc_clk_cfg        (0x121)
#define _veneer_clk_set_pdhsc_clken_cfg      (0x122)
//#define _veneer_clk_get_pdhsc_clken_cfg      (0x123)
//#define _veneer_clk_set_pdlsc_dpclk_cfg      (0x124)
//#define _veneer_clk_get_pdlsc_dpclk_cfg      (0x125)
//#define _veneer_clk_set_pdlsc_dpclken_cfg    (0x126)
//#define _veneer_clk_get_pdlsc_dpclken_cfg    (0x127)
//#define _veneer_clk_set_pdlsc_lscclk_cfg     (0x128)
//#define _veneer_clk_get_pdlsc_lscclk_cfg     (0x129)
//#define _veneer_clk_set_pdlsc_lscrefclk_cfg  (0x12A)
//#define _veneer_clk_get_pdlsc_lscrefclk_cfg  (0x12B)
#define _veneer_clk_set_pdlsc_adcckinclk_cfg (0x12C)
//#define _veneer_clk_get_pdlsc_adcckinclk_cfg (0x12D)
//#define _veneer_clk_set_pdlsc_clk_cfg        (0x12E)
//#define _veneer_clk_get_pdlsc_clk_cfg        (0x12F)
//#define _veneer_clk_set_pdlsc_clken_cfg      (0x130)
#define _veneer_clk_get_pdlsc_clken_cfg      (0x131)
//#define _veneer_clk_set_pdsb_clk_cfg         (0x132)
//#define _veneer_clk_get_pdsb_clk_cfg         (0x133)
//#define _veneer_clk_set_pdsb_clken_cfg       (0x134)
#define _veneer_clk_get_pdsb_clken_cfg       (0x135)
//#define _veneer_clk_set_pdaon_clk_cfg        (0x136)
//#define _veneer_clk_get_pdaon_clk_cfg        (0x137)
#define _veneer_clk_get_pdhsc_dpclken_cfg    (0x138)
#define _veneer_clk_get_pdaon_clken_cfg      (0x139)
#define _veneer_set_rtc_state                (0x13A)

//////////////////////////////////////////////////////////
#define _veneer_sys_get_u55_state                 (0x200)
#define _veneer_sys_get_U55_PORPL                 (0x201)
#define _veneer_sys_get_cm55s_state               (0x202)
#define _veneer_sys_set_I2S_mode                  (0x203)
#define _veneer_sys_get_I2S_mode                  (0x204)
#define _veneer_sys_set_PDM_IP                    (0x205)
#define _veneer_sys_get_PDM_IP                    (0x206)
#define _veneer_sys_set_xip_en                    (0x207)
#define _veneer_sys_set_ospi_xip_en               (0x208)
#define _veneer_sys_set_ospi_slave                (0x209)
#define _veneer_sys_set_ospi_resetn               (0x20A)
#define _veneer_sys_set_vad_d_pcm_sel             (0x20B)
#define _veneer_sys_set_sdio_itcfval              (0x20C)
#define _veneer_sys_set_sdio_itcfmul              (0x20D)
#define _veneer_sys_set_sdio_itcfsel              (0x20E)
#define _veneer_sys_get_version                   (0x20F)
#define _veneer_sys_set_PA1_pinmux                (0x210)
#define _veneer_sys_set_PA0_pinmux                (0x211)
#define _veneer_sys_set_PA2_pinmux                (0x212)
#define _veneer_sys_set_PA3_pinmux                (0x213)
#define _veneer_sys_set_sensor_i2cm_pinmux        (0x214)
#define _veneer_sys_set_SEN_FAE_pinmux            (0x215)
#define _veneer_sys_set_SEN_TRIG_pinmux           (0x216)
#define _veneer_sys_set_SEN_INT_pinmux            (0x217)
#define _veneer_sys_set_SEN_XSLEEP_pinmux         (0x218)
#define _veneer_sys_set_SEN_MCLK_pinmux           (0x219)
#define _veneer_sys_set_sensorgpio_pinmux         (0x21A)
#define _veneer_sys_set_SEN_CSW0_pinmux           (0x21B)
#define _veneer_sys_set_SEN_CSW1_pinmux           (0x21C)
#define _veneer_sys_set_SEN_D1_pinmux             (0x21D)
#define _veneer_sys_set_SEN_D2_pinmux             (0x21E)
#define _veneer_sys_set_SEN_D3_pinmux             (0x21F)
#define _veneer_sys_set_SEN_D4_pinmux             (0x220)
#define _veneer_sys_set_SEN_D5_pinmux             (0x221)
#define _veneer_sys_set_SEN_D6_pinmux             (0x222)
#define _veneer_sys_set_SEN_D7_pinmux             (0x223)
#define _veneer_sys_set_SEN_FVALID_pinmux         (0x224)
#define _veneer_sys_set_SEN_LVALID_pinmux         (0x225)
#define _veneer_sys_set_SDIO_SDCLK_pinmux         (0x226)
#define _veneer_sys_set_SDIO_CMD_pinmux           (0x227)
#define _veneer_sys_set_SDIO_DAT0_pinmux          (0x228)
#define _veneer_sys_set_SDIO_DAT1_pinmux          (0x229)
#define _veneer_sys_set_SDIO_DAT2_pinmux          (0x22A)
#define _veneer_sys_set_SDIO_DAT3_pinmux          (0x22B)
#define _veneer_sys_set_SW_DATA_pinmux            (0x22C)
#define _veneer_sys_set_SW_CLK_pinmux             (0x22D)
#define _veneer_sys_set_PB2_pinmux                (0x22E)
#define _veneer_sys_set_PB3_pinmux                (0x22F)
#define _veneer_sys_set_PB4_pinmux                (0x230)
#define _veneer_sys_set_PB5_pinmux                (0x231)
#define _veneer_sys_set_PB6_pinmux                (0x232)
#define _veneer_sys_set_PB7_pinmux                (0x233)
#define _veneer_sys_set_PB8_pinmux                (0x234)
#define _veneer_sys_set_PB9_pinmux                (0x235)
#define _veneer_sys_set_PB10_pinmux               (0x236)
#define _veneer_sys_set_PB11_pinmux               (0x237)
#define _veneer_sys_set_PC3_pinmux                (0x238)
#define _veneer_sys_set_PC4_pinmux                (0x239)
#define _veneer_sys_set_I2CM_SCLSDA_pinmux        (0x23A)
#define _veneer_sys_set_PB0_pinmux                (0x23B)
#define _veneer_sys_set_PB1_pinmux                (0x23C)
#define _veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux (0x23D)
#define _veneer_sys_set_SPIS_DO_pinmux            (0x23E)
#define _veneer_sys_set_SPIS_DI_pinmux            (0x23F)
#define _veneer_sys_set_SPIS_SCLK_pinmux          (0x240)
#define _veneer_sys_set_SPIS_CS_pinmux            (0x241)
#define _veneer_sys_set_I2C_SLV_share_enable      (0x242)
#define _veneer_sys_set_I3C_SLV_share_enable      (0x243)
#define _veneer_sys_set_DP_SWReset                (0x244)
#define _veneer_sys_set_wdt_ctrl                  (0x245)
#define _veneer_sys_set_timer_ctrl                (0x246)
#define _veneer_set_audio_capture_channel         (0x247)
#define _veneer_get_audio_capture_channel         (0x248)
#define _veneer_set_lsc_adclv_reset               (0x249)
#define _veneer_set_lsc_adchv_reset               (0x24A)
#define _veneer_set_SRSTN_pinmux                  (0x24B)
#define _veneer_set_SWCLKTCK_pinmux               (0x24C)
#define _veneer_set_SWDIO_TMS_pinmux              (0x24D)
#define _veneer_get_all_pinmux_cfg                (0x24E)
#define _veneer_set_all_pinmux_cfg                (0x24F)
#define _veneer_sys_get_DP_SWReset                (0x250)
#if(IC_VERSION >= 30)
#define _veneer_set_pdlsc_pdmck_src               (0x251)
#define _veneer_sys_set_SEN_PCLKO_pinmux          (0x252)
#endif
#define _veneer_get_pllfreq                       (0x253)

//////////////////////////////////////////////////////////
#define _veneer_pm_get_defcfg_bymode              (0x300)
#define _veneer_pm_pmu_dpdone_check               (0x301)
#define _veneer_pm_ctrl_fromPMUtoCPU              (0x302)
#define _veneer_pm_cfg_set                        (0x303)
#define _veneer_pm_cfg_get                        (0x304)
#define _veneer_pm_mode_get                       (0x305)
#define _veneer_pm_trigger                        (0x306)
#define _veneer_pm_get_event                      (0x307)
#define _veneer_pm_clear_event                    (0x308)
#define _veneer_pm_force_state_set                (0x309)
#define _veneer_pm_force_state_get                (0x30A)
#define _veneer_pm_set_dma_cfg                    (0x30B)
#define _veneer_pm_ext_int_get                    (0x30C)
#define _veneer_get_pmuwakeup_freq                (0x30D)
//////////////////////////////////////////////////////////
#define _veneer_spi_eeprom_open                   (0x400)
#define _veneer_spi_eeprom_open_speed             (0x401)
#define _veneer_spi_eeprom_read_ID                (0x402)
#define _veneer_spi_eeprom_1read                  (0x403)
#define _veneer_spi_eeprom_2read                  (0x404)
#define _veneer_spi_eeprom_4read                  (0x405)
#define _veneer_spi_eeprom_word_read              (0x406)
#define _veneer_spi_eeprom_word_write             (0x407)
#define _veneer_spi_eeprom_write                  (0x408)
#define _veneer_spi_eeprom_Send_Op_code           (0x409)
#define _veneer_spi_eeprom_erase_all              (0x40A)
#define _veneer_spi_eeprom_erase_sector           (0x40B)
#define _veneer_spi_eeprom_enable_XIP             (0x40C)
//////////////////////////////////////////////////////////
#define _veneer_spi_psram_open                    (0x500)
#define _veneer_spi_psram_SetXIP                  (0x501)
#define _veneer_spi_psram_set_powermode           (0x502)
#define _veneer_spi_psram_get_info                (0x503)
#define _veneer_spi_psram_close                   (0x504)


psa_status_t test_tfm_hx_veneer_timer_ctrl();
psa_status_t test_tfm_hx_veneer_spi_eeprom();
psa_status_t test_tfm_hx_veneer_clk_ctrl();
psa_status_t test_tfm_hx_veneer_sys_ctrl();
psa_status_t test_tfm_hx_veneer_spi_psram();
psa_status_t test_tfm_hx_veneer_power_ctrl();

#endif /* __TFM_SPM_COMMON_TEST_DEFS_H__ */
