/*
 * Copyright (c) 2019-2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#include <stdbool.h>
#include "tfm_hx_service_defs.h"
#include "psa_manifest/sid.h"
#include "psa/client.h"

#include "veneer_clk_ctrl.h" //YX 20230210
#include "veneer_eeprom_ctrl.h"
#include "veneer_power_ctrl.h"
#include "veneer_psram_ctrl.h"
#include "veneer_sys_ctrl.h"
#include "veneer_timer_ctrl.h"
#include "dev_common.h"

#define UNUSED(x) ((void)x)

#if 0
volatile static uint32_t* isr_event_cnt;

void test_timer_isr_event(uint32_t event)
{
    (*isr_event_cnt)++;
}

psa_status_t test_tfm_hx_veneer_timer_ctrl()
{
    TIMER_CFG_T cfg;
    uint32_t test_timer_isr_event_cnt[3] = {0};

    cfg.period = 1;
    cfg.mode = TIMER_MODE_PERIODICAL;//TIMER_MODE_ONESHOT;
    cfg.ctrl = TIMER_CTRL_CPU;
    cfg.state = TIMER_STATE_DC;

    isr_event_cnt = &test_timer_isr_event_cnt[0];

    if (TIMER_NO_ERROR != veneer_timer_sensor_start(&cfg, test_timer_isr_event))
        return PSA_ERROR_PROGRAMMER_ERROR;
    
    while (test_timer_isr_event_cnt[0] < 10);

    if (TIMER_NO_ERROR != veneer_timer_sensor_stop())
        return PSA_ERROR_PROGRAMMER_ERROR;

#ifdef CM55_BIG
    isr_event_cnt = &test_timer_isr_event_cnt[1];

    if (TIMER_NO_ERROR != veneer_timer_cm55m_start(&cfg, test_timer_isr_event))
        return PSA_ERROR_PROGRAMMER_ERROR;

    while (test_timer_isr_event_cnt[1] < 10);

    if (TIMER_NO_ERROR != veneer_timer_cm55m_stop())
        return PSA_ERROR_PROGRAMMER_ERROR;

#else
    isr_event_cnt = &test_timer_isr_event_cnt[2];

    if (TIMER_NO_ERROR != veneer_timer_cm55s_start(&cfg, test_timer_isr_event))
        return PSA_ERROR_PROGRAMMER_ERROR;

    while (test_timer_isr_event_cnt[2] < 10);

    if (TIMER_NO_ERROR != veneer_timer_cm55s_stop())
        return PSA_ERROR_PROGRAMMER_ERROR;
#endif

    return PSA_SUCCESS;
}

#define WinbondManufacturerID  0xEF

uint32_t swap_int32(uint32_t val)
{
    val = ((val << 8) & 0xFF00FF00) | ((val >> 8) & 0xFF00FF ); 
    return (val << 16) | ((val >> 16) & 0xFFFF);
}

psa_status_t test_tfm_hx_veneer_spi_eeprom()
{
#define TOTAL_NUM_WORD  (4)
#define TOTAL_NUM_BYTE  (sizeof(uint32_t) * TOTAL_NUM_WORD)

    uint8_t id_info[3];
    uint32_t w_worddata[TOTAL_NUM_WORD] = {
        0x11223344,
        0x55667788,
        0x99AABBCC,
        0xDDEEFF00,
    };

    uint32_t r_worddata[TOTAL_NUM_WORD] = {0};
    uint8_t r_bytedata[TOTAL_NUM_BYTE] = {0};

    if (E_OK != veneer_spi_eeprom_open(VENEER_QSPI_EEPROM))
        return PSA_ERROR_PROGRAMMER_ERROR;
#if 0
    if (E_OK != veneer_spi_eeprom_open_speed(VENEER_QSPI_EEPROM, 60000))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint8_t opcode = 0x9F;

    if (E_OK != veneer_spi_eeprom_Send_Op_code(VENEER_QSPI_EEPROM, &opcode, 1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_read_ID(VENEER_QSPI_EEPROM, &id_info))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (WinbondManufacturerID != id_info[0])
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_erase_sector(VENEER_QSPI_EEPROM, 0x10000))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_word_read(VENEER_QSPI_EEPROM, 0x10000, r_worddata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (0xFFFFFFFF != r_worddata[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_word_write(VENEER_QSPI_EEPROM, 0x10000, w_worddata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;
    
    if (E_OK != veneer_spi_eeprom_word_read(VENEER_QSPI_EEPROM, 0x10000, r_worddata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (w_worddata[i] != r_worddata[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_4read(VENEER_QSPI_EEPROM, 0x10000, r_bytedata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (swap_int32(w_worddata[i]) != ((uint32_t *)r_bytedata)[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_2read(VENEER_QSPI_EEPROM, 0x10000, r_bytedata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (swap_int32(w_worddata[i]) != ((uint32_t *)r_bytedata)[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_1read(VENEER_QSPI_EEPROM, 0x10000, r_bytedata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (swap_int32(w_worddata[i]) != ((uint32_t *)r_bytedata)[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_erase_sector(VENEER_QSPI_EEPROM, 0x10000))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_write(VENEER_QSPI_EEPROM, 0x10000, (uint8_t *)w_worddata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_1read(VENEER_QSPI_EEPROM, 0x10000, r_bytedata, TOTAL_NUM_BYTE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    for (int i = 0; i < TOTAL_NUM_WORD; i++) {
        if (w_worddata[i] != ((uint32_t *)r_bytedata)[i])
            return PSA_ERROR_PROGRAMMER_ERROR;
    }

    if (E_OK != veneer_spi_eeprom_enable_XIP(VENEER_QSPI_EEPROM, 1, VENEER_FLASH_QUAD, 0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_eeprom_enable_XIP(VENEER_QSPI_EEPROM, 0, VENEER_FLASH_QUAD, 0))
        return PSA_ERROR_PROGRAMMER_ERROR;
#endif
    return PSA_SUCCESS;
}

psa_status_t test_tfm_hx_veneer_clk_ctrl()
{
    //TEST_LOG("test_tfm_hx_veneer_clk_ctrl\r\n");

#if 1
    if (SCU_NO_ERROR != veneer_clk_ctrl_set_timer_clk_en(TIMER_ID_0, 1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_ctrl_set_timer_clkdiv(TIMER_ID_0, 2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_ctrl_set_wdg_clk_en(WATCHDOG_ID_0, 1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_ctrl_set_wdg_clkdiv(WATCHDOG_ID_0, 2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_ctrl_set_rtc_clk_en(RTC_ID_0, 1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_ctrl_set_rtc_cycle(RTC_ID_0, 100))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint32_t fpga_hsc_freq = veneer_clk_get_freq(SCU_CLK_FREQ_TYPE_HSC_CLK);

    if (fpga_hsc_freq != 50000000)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_vad_d_src_sel(SCU_LSCVADDCLKSRC_PDMPCM))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_LSCVADDCLKSRC_E src_sel;

    if (SCU_NO_ERROR != veneer_clk_get_vad_d_src_sel(&src_sel))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (src_sel != SCU_LSCVADDCLKSRC_PDMPCM)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_i2s_clkdiv(2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint8_t clkdiv;

    if (SCU_NO_ERROR != veneer_clk_get_i2s_clkdiv(&clkdiv))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (clkdiv != 2)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_pdm_clkdiv(clkdiv))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_get_pdm_clkdiv(&clkdiv))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (clkdiv != 2)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_xtal32k_en(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint8_t xtal32k_en;

    if (SCU_NO_ERROR != veneer_clk_get_xtal32k_en(&xtal32k_en))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (xtal32k_en != 1)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_xtal24m_en(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint8_t xtal24m_en;

    if (SCU_NO_ERROR != veneer_clk_get_xtal24m_en(&xtal24m_en))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (xtal24m_en != 1)
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_PLL_CLK_CFG_T pll_cfg;

    if (SCU_NO_ERROR != veneer_clk_get_pll_cfg(&pll_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    pll_cfg.init_pll_para = 1;
    pll_cfg.AREG0_3 = 0x1122;
    pll_cfg.freq = SCU_PLL_FREQ_ENABLE;

    if (SCU_NO_ERROR != veneer_clk_set_pll_cfg(&pll_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_get_pll_cfg(&pll_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (pll_cfg.AREG0_3 != 0x1122)
        return PSA_ERROR_PROGRAMMER_ERROR;
#endif
    SCU_PLLCLKSRC_E pllclksrc;

    if (SCU_NO_ERROR != veneer_clk_get_pll_src(&pllclksrc))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_pll_enable(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint8_t lock;

    if (SCU_NO_ERROR != veneer_clk_get_pll_lock_status(&lock))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_PDHSC_DPCLK_CFG_T pdhsc_dpclk_cfg;

    if (SCU_NO_ERROR != veneer_clk_get_pdhsc_dpclk_cfg(&pdhsc_dpclk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_pdhsc_dpclk_cfg(&pdhsc_dpclk_cfg, 0, 0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_PDHSC_HSCCLK_CFG_T pdhsc_hscclk_cfg;

    if (SCU_NO_ERROR != veneer_clk_get_pdhsc_hscclk_cfg(&pdhsc_hscclk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_set_pdhsc_hscclk_cfg(&pdhsc_hscclk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_SIMPLE_CLK_CFG_T simple_clk_cfg;

    if (SCU_NO_ERROR != veneer_clk_get_simple_clk_cfg(&simple_clk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    simple_clk_cfg.cm55m_div = SCU_HSCCLKDIV_5;

    if (SCU_NO_ERROR != veneer_clk_set_simple_clk_cfg(&simple_clk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_clk_get_simple_clk_cfg(&simple_clk_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (simple_clk_cfg.cm55m_div != SCU_HSCCLKDIV_5)
        return PSA_ERROR_PROGRAMMER_ERROR;

    return PSA_SUCCESS;
}

psa_status_t test_tfm_hx_veneer_sys_ctrl()
{
    SCU_U55_STATE_E u55_state;

    if (SCU_NO_ERROR != veneer_sys_get_u55_state(&u55_state))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_U55_PORPL_E U55_PORPL;

    if (SCU_NO_ERROR != veneer_sys_get_U55_PORPL(&U55_PORPL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_CM55S_STATE_E cm55s_state;

    if (SCU_NO_ERROR != veneer_sys_get_cm55s_state(&cm55s_state))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_I2S_MODE_E I2S_mode;

    if (SCU_NO_ERROR != veneer_sys_set_I2S_mode(SCU_I2S_MODE_SLAVE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_get_I2S_mode(&I2S_mode))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (I2S_mode != SCU_I2S_MODE_SLAVE)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PDM_IP(SCU_PDM_IP_HIMAX))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_PDM_IP_E PDM_IP_mode;

    if (SCU_NO_ERROR != veneer_sys_get_PDM_IP(&PDM_IP_mode))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PDM_IP_mode != SCU_PDM_IP_HIMAX)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_xip_en(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_xip_en(0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_ospi_xip_en(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_ospi_xip_en(0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_ospi_slave(0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_ospi_resetn(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_vad_d_pcm_sel(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_sdio_itcfval(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_sdio_itcfmul(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_sdio_itcfsel(1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    uint32_t version1;
    uint32_t version2;

    if (SCU_NO_ERROR != veneer_sys_get_version(&version1, &version2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PA1_pinmux(SCU_PA1_PINMUX_AON_GPIO1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PA0_pinmux(SCU_PA0_PINMUX_AON_GPIO0_2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PA2_pinmux(SCU_PA2_PINMUX_I2C_M_SCL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PA3_pinmux(SCU_PA3_PINMUX_I3C_M_SDA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_1,SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_FAE_pinmux(SCU_SEN_FAE_PINMUX_FAE1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_TRIG_pinmux(SCU_SEN_TRIG_PINMUX_GPIO7))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_INT_pinmux(SCU_SEN_INT_PINMUX_INT1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_XSLEEP_pinmux(SCU_SEN_XSLEEP_PINMUX_TRIG))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_MCLK_pinmux(SCU_SEN_MCLK_PINMUX_SENGPIO))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_sensorgpio_pinmux(SCU_SEN_GPIO_PINMUX_SENAONGPIO2_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_CSW0_pinmux(SCU_SEN_CSW0_PINMUX_CSW0_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_CSW1_pinmux(SCU_SEN_CSW1_PINMUX_CSW1_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D1_pinmux(SCU_SEN_D1_PINMUX_SEN_D1_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D2_pinmux(SCU_SEN_D2_PINMUX_SEN_D2_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D3_pinmux(SCU_SEN_D3_PINMUX_SEN_D3_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D4_pinmux(SCU_SEN_D4_PINMUX_SEN_D4_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D5_pinmux(SCU_SEN_D5_PINMUX_SEN_D5_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D6_pinmux(SCU_SEN_D6_PINMUX_SEN_D6_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_D7_pinmux(SCU_SEN_D7_PINMUX_SEN_D7_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_FVALID_pinmux(SCU_SEN_FVALID_PINMUX_SEN_FVALID_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_FVALID_pinmux(SCU_SEN_FVALID_PINMUX_SEN_FVALID_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SEN_LVALID_pinmux(SCU_SEN_LVALID_PINMUX_SEN_LVALID_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_SDCLK_pinmux(SCU_SDIO_SDCLK_PINMUX_SDIO_SDCLK))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_CMD_pinmux(SCU_SDIO_CMD_PINMUX_SDIO_CMD))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_DAT0_pinmux(SCU_SDIO_DATA0_PINMUX_SDIO_DATA0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_DAT1_pinmux(SCU_SDIO_DATA1_PINMUX_SDIO_DATA1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_DAT2_pinmux(SCU_SDIO_DATA2_PINMUX_SDIO_DATA2))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SDIO_DAT3_pinmux(SCU_SDIO_DATA3_PINMUX_SDIO_DATA3))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SW_DATA_pinmux(SCU_SW_DATA_PINMUX_SW_DATA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SW_CLK_pinmux(SCU_SW_CLK_PINMUX_SW_CLK))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB2_pinmux(SCU_PB2_PINMUX_I2C_M_SDA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB3_pinmux(SCU_PB3_PINMUX_I3C_S1_SCL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB4_pinmux(SCU_PB4_PINMUX_GPIO15))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB5_pinmux(SCU_PB5_PINMUX_I2C_M_SCL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB6_pinmux(SCU_PB6_PINMUX_NA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB7_pinmux(SCU_PB7_PINMUX_SWCLK_0)) ///
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB8_pinmux(SCU_PB8_PINMUX_SWDIO_0)) ///
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB9_pinmux(SCU_PB9_PINMUX_I2C_M_SCL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB10_pinmux(SCU_PB10_PINMUX_I2C_M_SDA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB11_pinmux(SCU_PB11_PINMUX_I2S_M_SDI))
        return PSA_ERROR_PROGRAMMER_ERROR;
    
    if (SCU_NO_ERROR != veneer_sys_set_PC3_pinmux(SCU_PC3_PINMUX_I2S_M_SDO))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PC4_pinmux(SCU_PC4_PINMUX_PDM_DATA3))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_I2CM_SCLSDA_pinmux(SCU_I2CM_SCLSDA_PINMUX_I2CM_SCLSDA))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB0_pinmux(SCU_PB0_PINMUX_UART0_RX_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_PB1_pinmux(SCU_PB1_PINMUX_UART0_TX_1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux(SCU_UART_PINMUX_UART1))
        return PSA_ERROR_PROGRAMMER_ERROR;
    
    if (SCU_NO_ERROR != veneer_sys_set_SPIS_DO_pinmux(SCU_SPIS_DO_PINMUX_SPI_S_DO))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SPIS_DI_pinmux(SCU_SPIS_DI_PINMUX_SPI_S_DI))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SPIS_SCLK_pinmux(SCU_SPIS_SCLK_PINMUX_SPI_S_SCLK))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_SPIS_CS_pinmux(SCU_SPIS_CS_PINMUX_SPI_S_CS))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_I2C_SLV_share_enable(SCU_I2CSLV_SHARE_DISABLE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_I3C_SLV_share_enable(SCU_I3CSLV_SHARE_DISABLE))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_DP_SWRESET_T DP_SWReset_cfg;
	DP_SWReset_cfg.LSC_SC = SCU_SWRESET_NORMAL;
	DP_SWReset_cfg.HSC_XDMA = SCU_SWRESET_NORMAL;
	DP_SWReset_cfg.HSC_PCLK = SCU_SWRESET_NORMAL;
	DP_SWReset_cfg.HSC_SCCLK = SCU_SWRESET_NORMAL;
	DP_SWReset_cfg.HSC_MIPIRX = SCU_SWRESET_NORMAL;
	DP_SWReset_cfg.HSC_MIPITX = SCU_SWRESET_NORMAL;

    if (SCU_NO_ERROR != veneer_sys_set_DP_SWReset(&DP_SWReset_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_wdt_ctrl(WATCHDOG_ID_0, SCU_WDTCTRL_CPU))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_sys_set_timer_ctrl(TIMER_ID_0, SCU_TIMERCTRL_CPU))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_audio_capture_channel(SCU_AUDIO_HWTYPE_HXPDM, SCU_AUDIO_CAPTURE_CHANNEL_LEFT_ONLY))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_AUDIO_CAPTURE_CHANNEL_E audio_capture_channel;

    if (SCU_NO_ERROR != veneer_get_audio_capture_channel(SCU_AUDIO_HWTYPE_HXPDM, &audio_capture_channel))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_lsc_adclv_reset(SCU_SWRESET_NORMAL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_lsc_adchv_reset(SCU_SWRESET_NORMAL))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_SRSTN_pinmux(SCU_PAD_SRSTN_PINMUX_NA)) //must be NA.
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_SWCLKTCK_pinmux(SCU_PAD_SWCLK_TCK_PINMUX_SWCLK))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_set_SWDIO_TMS_pinmux(SCU_PAD_SWDIO_TMS_PINMUX_SWDIO))
        return PSA_ERROR_PROGRAMMER_ERROR;

    SCU_PINMUX_CFG_T pinmux_cfg;

    if (SCU_NO_ERROR != veneer_get_all_pinmux_cfg(&pinmux_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    pinmux_cfg.pin_pa0 = SCU_PA0_PINMUX_AON_GPIO0_0;

    if (SCU_NO_ERROR != veneer_set_all_pinmux_cfg(&pinmux_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (SCU_NO_ERROR != veneer_get_all_pinmux_cfg(&pinmux_cfg))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (pinmux_cfg.pin_pa0 != SCU_PA0_PINMUX_AON_GPIO0_0)
        return PSA_ERROR_PROGRAMMER_ERROR;

    return PSA_SUCCESS;
}

psa_status_t test_tfm_hx_veneer_spi_psram()
{
    if (E_OK != veneer_spi_psram_open())
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_psram_SetXIP(0))
        return PSA_ERROR_PROGRAMMER_ERROR;

    //uint32_t info;
    //if (E_OK != veneer_spi_psram_get_info(&info, 0, 0))
    //    return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_psram_set_powermode(VENEER_PSRAM_WAKE_UP))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (E_OK != veneer_spi_psram_close())
        return PSA_ERROR_PROGRAMMER_ERROR;

    return PSA_SUCCESS;
}

volatile static uint32_t waitpmudmadone_cb_cnt = 0;
volatile static uint32_t pmutocpuctrl_cb_cnt = 0;
volatile static uint32_t pmudpinit_cb_cnt = 0;

void waitpmudmadone_cb(void)
{
    waitpmudmadone_cb_cnt++;
}

void pmutocpuctrl_cb(void)
{
    pmutocpuctrl_cb_cnt++;
}

void pmudpinit_cb(void)
{
    pmudpinit_cb_cnt++;
}

psa_status_t test_tfm_hx_veneer_power_ctrl()
{
    PM_PD_VIDPRE_CFG_T vidpre_cfg;
    PM_CFG_PWR_MODE_E mode;

    if (PM_NO_ERROR != veneer_pm_get_defcfg_bymode(&vidpre_cfg, PM_MODE_PS_VID_ONLY_PREROLLING))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_pmu_dpdone_check(waitpmudmadone_cb))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_ctrl_fromPMUtoCPU(pmutocpuctrl_cb))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_cfg_get(&vidpre_cfg, PM_MODE_PS_VID_ONLY_PREROLLING))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_cfg_set(&vidpre_cfg, pmudpinit_cb, PM_MODE_PS_VID_ONLY_PREROLLING))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_mode_get(&mode))
        return PSA_ERROR_PROGRAMMER_ERROR;
    
    if (mode != PM_MODE_PS_VID_ONLY_PREROLLING)
        return PSA_ERROR_PROGRAMMER_ERROR;

    //SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;
    //SCU_LSC_CLK_CFG_T lsc_cfg;
	//hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC24M1M;
	//hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	//hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	//hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	//hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	//lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC24M1M;
	//lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;

    //if (PM_NO_ERROR != veneer_pm_trigger(&hsc_cfg, &lsc_cfg))
    //    return PSA_ERROR_PROGRAMMER_ERROR;

    PMU_WAKEUPEVENT_E aWakeupEvt;
    PMU_WAKEUPEVENT1_E aWakeupEvt1;

    if (PM_NO_ERROR != veneer_pm_get_event(&aWakeupEvt, &aWakeupEvt1))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_clear_event())
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_force_state_set(PMU_PS_STATE_DC))
        return PSA_ERROR_PROGRAMMER_ERROR;

    PMU_PS_STATE_E ps_state;

    if (PM_NO_ERROR != veneer_pm_force_state_get(&ps_state))
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (ps_state != PMU_PS_STATE_DC)
        return PSA_ERROR_PROGRAMMER_ERROR;

    if (PM_NO_ERROR != veneer_pm_set_dma_cfg(1)) //8bit ??
        return PSA_ERROR_PROGRAMMER_ERROR;

    return PSA_SUCCESS;
}
#endif

TIMER_ERROR_E veneer_timer_sensor_start(TIMER_CFG_T *cfg, Timer_ISREvent_t cb_event)
{
#if defined(_veneer_timer_sensor_start)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(TIMER_CFG_T);
    in_vec[1].base = &cb_event;
    in_vec[1].len = sizeof(cb_event);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_sensor_start,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    UNUSED(cb_event);
    return TIMER_UNKNOWN_ERROR;
#endif
}

TIMER_ERROR_E veneer_timer_sensor_stop()
{
#if defined(_veneer_timer_sensor_stop)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_sensor_stop,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    return TIMER_UNKNOWN_ERROR;
#endif
}

#ifdef CM55_BIG
TIMER_ERROR_E veneer_timer_cm55m_start(TIMER_CFG_T *cfg, Timer_ISREvent_t cb_event)
{
#if defined(_veneer_timer_cm55m_start)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(TIMER_CFG_T);
    in_vec[1].base = &cb_event;
    in_vec[1].len = sizeof(cb_event);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_cm55m_start,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    UNUSED(cb_event);
    return TIMER_UNKNOWN_ERROR;
#endif
}

TIMER_ERROR_E veneer_timer_cm55m_stop()
{
#if defined(_veneer_timer_cm55m_stop)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_cm55m_stop,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    return TIMER_UNKNOWN_ERROR;
#endif
}
#else
TIMER_ERROR_E veneer_timer_cm55s_start(TIMER_CFG_T *cfg, Timer_ISREvent_t cb_event)
{
#if defined(_veneer_timer_cm55s_start)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(TIMER_CFG_T);
    in_vec[1].base = &cb_event;
    in_vec[1].len = sizeof(cb_event);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_cm55s_start,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    UNUSED(cb_event);
    return TIMER_UNKNOWN_ERROR;
#endif
}

TIMER_ERROR_E veneer_timer_cm55s_stop()
{
#if defined(_veneer_timer_cm55s_stop)
    psa_status_t status;
    TIMER_ERROR_E return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_timer_cm55s_stop,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return TIMER_UNKNOWN_ERROR;

    return return_value;
#else
    return TIMER_UNKNOWN_ERROR;
#endif
}
#endif

uint32_t veneer_clk_ctrl_set_timer_clk_en(TIMER_ID_E id, uint8_t clk_en)
{
#if defined(_veneer_clk_ctrl_set_timer_clk_en)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &clk_en;
    in_vec[1].len = sizeof(clk_en);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_timer_clk_en,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(clk_en);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_ctrl_set_timer_clkdiv(TIMER_ID_E id, uint32_t clk_div)
{
#if defined(_veneer_clk_ctrl_set_timer_clkdiv)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &clk_div;
    in_vec[1].len = sizeof(clk_div);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_timer_clkdiv,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_ctrl_set_wdg_clk_en(WATCHDOG_ID_E id, uint8_t clk_en)
{
#if defined(_veneer_clk_ctrl_set_wdg_clk_en)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &clk_en;
    in_vec[1].len = sizeof(clk_en);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_wdg_clk_en,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(clk_en);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_ctrl_set_wdg_clkdiv(WATCHDOG_ID_E id, uint32_t clk_div)
{
#if defined(_veneer_clk_ctrl_set_wdg_clkdiv)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &clk_div;
    in_vec[1].len = sizeof(clk_div);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_wdg_clkdiv,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_ctrl_set_rtc_clk_en(RTC_ID_E id, uint8_t clk_en)
{
#if defined(_veneer_clk_ctrl_set_rtc_clk_en)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &clk_en;
    in_vec[1].len = sizeof(clk_en);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_rtc_clk_en,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(clk_en);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_ctrl_set_rtc_cycle(RTC_ID_E id, uint32_t cycle_width)
{
#if defined(_veneer_clk_ctrl_set_rtc_cycle)
    psa_status_t status;
    uint32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &cycle_width;
    in_vec[1].len = sizeof(cycle_width);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_ctrl_set_rtc_cycle,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(cycle_width);
    return SCU_UNKNOWN_ERROR;
#endif
}

uint32_t veneer_clk_get_freq(SCU_CLK_FREQ_TYPE_E type)
{
#if defined(_veneer_clk_get_freq)
    psa_status_t status;
    uint32_t freq;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &type;
    in_vec[0].len = sizeof(type);

    out_vec[0].base = &freq;
    out_vec[0].len = sizeof(freq);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_freq,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return freq;
#else
    UNUSED(type);
    return 0;
#endif
}

SCU_ERROR_E veneer_clk_set_vad_d_src_sel(SCU_LSCVADDCLKSRC_E data)
{
#if defined(_veneer_clk_set_vad_d_src_sel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_vad_d_src_sel,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_vad_d_src_sel(SCU_LSCVADDCLKSRC_E *data)
{
#if defined(_veneer_clk_get_vad_d_src_sel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = sizeof(SCU_LSCVADDCLKSRC_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_vad_d_src_sel,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_i2s_clkdiv(uint8_t clk_div)
{
#if defined(_veneer_clk_set_i2s_clkdiv)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &clk_div;
    in_vec[0].len = sizeof(clk_div);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_i2s_clkdiv,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_i2s_clkdiv(uint8_t *clk_div)
{
#if defined(_veneer_clk_get_i2s_clkdiv)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = clk_div;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_i2s_clkdiv,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdm_clkdiv(uint8_t clk_div)
{
#if defined(_veneer_clk_set_pdm_clkdiv)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &clk_div;
    in_vec[0].len = sizeof(clk_div);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdm_clkdiv,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdm_clkdiv(uint8_t *clk_div)
{
#if defined(_veneer_clk_get_pdm_clkdiv)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = clk_div;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdm_clkdiv,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(clk_div);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_xtal32k_en(uint8_t enable)
{
#if defined(_veneer_clk_set_xtal32k_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_xtal32k_en,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_xtal32k_en(uint8_t *enable)
{
#if defined(_veneer_clk_get_xtal32k_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = enable;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_xtal32k_en,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_xtal24m_en(uint8_t enable)
{
#if defined(_veneer_clk_set_xtal24m_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_xtal24m_en,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_xtal24m_en(uint8_t *enable)
{
#if defined(_veneer_clk_get_xtal24m_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = enable;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_xtal24m_en,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pll_cfg(SCU_PLL_CLK_CFG_T *cfg)
{
#if defined(_veneer_clk_set_pll_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PLL_CLK_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pll_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pll_cfg(SCU_PLL_CLK_CFG_T *pll_cfg)
{
#if defined(_veneer_clk_get_pll_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = pll_cfg;
    out_vec[1].len = sizeof(SCU_PLL_CLK_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pll_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(pll_cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pll_src(SCU_PLLCLKSRC_E *pllclksrc)
{
#if defined(_veneer_clk_get_pll_src)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = pllclksrc;
    out_vec[1].len = sizeof(SCU_PLLCLKSRC_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pll_src,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(pllclksrc);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pll_enable(uint8_t enable)
{
#if defined(_veneer_clk_set_pll_enable)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pll_enable,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pll_lock_status(uint8_t *lock)
{
#if defined(_veneer_clk_get_pll_lock_status)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = lock;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pll_lock_status,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(lock);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdhsc_dpclk_cfg(SCU_PDHSC_DPCLK_CFG_T *cfg, uint8_t change_dprx, uint8_t change_dp)
{
#if defined(_veneer_clk_set_pdhsc_dpclk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[3];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PDHSC_DPCLK_CFG_T);
    in_vec[1].base = &change_dprx;
    in_vec[1].len = sizeof(change_dprx);
    in_vec[2].base = &change_dp;
    in_vec[2].len = sizeof(change_dp);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_dpclk_cfg,
                     in_vec, 3, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    UNUSED(change_dprx);
    UNUSED(change_dp);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdhsc_dpclk_cfg(SCU_PDHSC_DPCLK_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdhsc_dpclk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDHSC_DPCLK_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_dpclk_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdhsc_dpclken_cfg(SCU_PDHSC_DPCLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_set_pdhsc_dpclken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PDHSC_DPCLKEN_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_dpclken_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdhsc_dpclken_cfg(SCU_PDHSC_DPCLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdhsc_dpclken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDHSC_DPCLKEN_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_dpclken_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdhsc_hscclk_cfg(SCU_PDHSC_HSCCLK_CFG_T *cfg)
{
#if defined(_veneer_clk_set_pdhsc_hscclk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PDHSC_HSCCLK_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_hscclk_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdhsc_hscclk_cfg(SCU_PDHSC_HSCCLK_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdhsc_hscclk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDHSC_HSCCLK_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_hscclk_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdlsc_adcckinclk_cfg(SCU_PDLSC_ADCCKIN_CFG_T *cfg)
{
#if defined(_veneer_clk_set_pdlsc_adcckinclk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PDLSC_ADCCKIN_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_adcckinclk_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdaon_clken_cfg(SCU_PDAON_CLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdaon_clken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDAON_CLKEN_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdaon_clken_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdsb_clken_cfg(SCU_PDSB_CLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdsb_clken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDSB_CLKEN_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdsb_clken_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdlsc_clken_cfg(SCU_PDLSC_CLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdlsc_clken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDLSC_CLKEN_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_clken_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_set_pdhsc_clken_cfg(SCU_PDHSC_CLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_set_pdhsc_clken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_PDHSC_CLKEN_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_clken_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_pdhsc_clken_cfg(SCU_PDHSC_CLKEN_CFG_T *cfg)
{
#if defined(_veneer_clk_get_pdhsc_clken_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_PDHSC_CLKEN_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_clken_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

//SCU_ERROR_E veneer_clk_set_pdhsc_hsc32kclk_cfg(SCU_HSC32KCLKSRC_E cfg)
//{
//#if defined(_veneer_clk_set_pdhsc_hsc32kclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = &cfg;
//    in_vec[0].len = sizeof(SCU_HSC32KCLKSRC_E);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_hsc32kclk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdhsc_hsc32kclk_cfg(SCU_HSC32KCLKSRC_E *cfg)
//{
//#if defined(_veneer_clk_get_pdhsc_hsc32kclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_HSC32KCLKSRC_E);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_hsc32kclk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdhsc_clk_cfg(SCU_PDHSC_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdhsc_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDHSC_CLK_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_clk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdhsc_clk_cfg(SCU_PDHSC_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdhsc_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDHSC_CLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdhsc_clk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdhsc_clken_cfg(SCU_PDHSC_CLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdhsc_clken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDHSC_CLKEN_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdhsc_clken_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_dpclk_cfg(SCU_PDLSC_DPCLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdlsc_dpclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_DPCLK_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_dpclk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_dpclk_cfg(SCU_PDLSC_DPCLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_dpclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_DPCLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_dpclk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_dpclken_cfg(SCU_PDLSC_DPCLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdlsc_dpclken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_DPCLKEN_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_dpclken_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_dpclken_cfg(SCU_PDLSC_DPCLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_dpclken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_DPCLKEN_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_dpclken_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_lscclk_cfg(SCU_LSC_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_dpclken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_DPCLKEN_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_lscclk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_lscclk_cfg(SCU_LSC_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_lscclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_LSC_CLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_lscclk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_lscrefclk_cfg(SCU_PDLSC_LSCREF_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdlsc_lscrefclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_LSCREF_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_lscrefclk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_lscrefclk_cfg(SCU_PDLSC_LSCREF_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_lscrefclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_LSCREF_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_lscrefclk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_adcckinclk_cfg(SCU_PDLSC_ADCCKIN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_adcckinclk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_ADCCKIN_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_adcckinclk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_clk_cfg(SCU_PDLSC_CLK_CFG_T *cfg, uint8_t change_dp, uint8_t vad_src_change)
//{
//#if defined(_veneer_clk_set_pdlsc_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[3];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_CLK_CFG_T);
//    in_vec[1].base = change_dp;
//    in_vec[1].len = sizeof(change_dp);
//    in_vec[2].base = vad_src_change;
//    in_vec[2].len = sizeof(vad_src_change);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_clk_cfg,
//                     in_vec, 3, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    UNUSED(change_dp);
//    UNUSED(vad_src_change);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_clk_cfg(SCU_PDLSC_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_CLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_clk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdlsc_clken_cfg(SCU_PDLSC_CLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdlsc_clken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDLSC_CLKEN_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdlsc_clken_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdlsc_clken_cfg(SCU_PDLSC_CLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdlsc_clken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDLSC_CLKEN_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdlsc_clken_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdsb_clk_cfg(SCU_PDSB_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdsb_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDSB_CLK_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdsb_clk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdsb_clk_cfg(SCU_PDSB_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdsb_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDSB_CLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdsb_clk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdsb_clken_cfg(SCU_PDSB_CLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdsb_clken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDSB_CLKEN_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdsb_clken_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdsb_clken_cfg(SCU_PDSB_CLKEN_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdsb_clken_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDSB_CLKEN_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdsb_clken_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_set_pdaon_clk_cfg(SCU_PDAON_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_set_pdaon_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_invec in_vec[1];
//    psa_outvec out_vec[1];
//
//    in_vec[0].base = cfg;
//    in_vec[0].len = sizeof(SCU_PDAON_CLK_CFG_T);
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_set_pdaon_clk_cfg,
//                     in_vec, 1, 
//                     out_vec, 1);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}
//
//SCU_ERROR_E veneer_clk_get_pdaon_clk_cfg(SCU_PDAON_CLK_CFG_T *cfg)
//{
//#if defined(_veneer_clk_get_pdaon_clk_cfg)
//    psa_status_t status;
//    SCU_ERROR_E return_value;
//    psa_outvec out_vec[2];
//
//    out_vec[0].base = &return_value;
//    out_vec[0].len = sizeof(return_value);
//    out_vec[1].base = cfg;
//    out_vec[1].len = sizeof(SCU_PDAON_CLK_CFG_T);
//
//    status = psa_call(TFM_HX_SERVICE_HANDLE,
//                     TFM_HX_SERVICE + _veneer_clk_get_pdaon_clk_cfg,
//                     NULL, 0, 
//                     out_vec, 2);
//
//    if (status != PSA_SUCCESS)
//        return SCU_UNKNOWN_ERROR;
//
//    return return_value;
//#else
//    UNUSED(cfg);
//    return SCU_UNKNOWN_ERROR;
//#endif
//}

SCU_ERROR_E veneer_clk_set_simple_clk_cfg(SCU_SIMPLE_CLK_CFG_T *cfg)
{
#if defined(_veneer_clk_set_simple_clk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_SIMPLE_CLK_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_set_simple_clk_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_clk_get_simple_clk_cfg(SCU_SIMPLE_CLK_CFG_T *cfg)
{
#if defined(_veneer_clk_get_simple_clk_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_SIMPLE_CLK_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_clk_get_simple_clk_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_rtc_state(RTC_ID_E id, SCU_RTC_STATE_E state)
{
#if defined(_veneer_set_rtc_state)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &state;
    in_vec[1].len = sizeof(state);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_rtc_state,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(state);
    return SCU_UNKNOWN_ERROR;
#endif
}

///////////////
SCU_ERROR_E veneer_sys_get_u55_state(SCU_U55_STATE_E *state)
{
#if defined(_veneer_sys_get_u55_state)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = state;
    out_vec[1].len = sizeof(SCU_U55_STATE_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_u55_state,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(state);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_U55_PORPL(SCU_U55_PORPL_E *data)
{
#if defined(_veneer_sys_get_U55_PORPL)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = sizeof(SCU_U55_PORPL_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_U55_PORPL,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_cm55s_state(SCU_CM55S_STATE_E *data)
{
#if defined(_veneer_sys_get_cm55s_state)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = sizeof(SCU_CM55S_STATE_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_cm55s_state,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_I2S_mode(SCU_I2S_MODE_E mode)
{
#if defined(_veneer_sys_set_I2S_mode)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &mode;
    in_vec[0].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_I2S_mode,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_I2S_mode(SCU_I2S_MODE_E *mode)
{
#if defined(_veneer_sys_get_I2S_mode)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = mode;
    out_vec[1].len = sizeof(SCU_I2S_MODE_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_I2S_mode,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PDM_IP(SCU_PDM_IP_E mode)
{
#if defined(_veneer_sys_set_PDM_IP)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &mode;
    in_vec[0].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_PDM_IP,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_PDM_IP(SCU_PDM_IP_E *mode)
{
#if defined(_veneer_sys_get_PDM_IP)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = mode;
    out_vec[1].len = sizeof(SCU_PDM_IP_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_PDM_IP,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_xip_en(uint8_t data)
{
#if defined(_veneer_sys_set_xip_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_xip_en,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_ospi_xip_en(uint8_t enable)
{
#if defined(_veneer_sys_set_ospi_xip_en)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_xip_en,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_ospi_slave(uint8_t data)
{
#if defined(_veneer_sys_set_ospi_slave)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_ospi_slave,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_ospi_resetn(uint8_t normal)
{
#if defined(_veneer_sys_set_ospi_resetn)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &normal;
    in_vec[0].len = sizeof(normal);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_ospi_resetn,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(normal);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_vad_d_pcm_sel(SCU_VAD_PCM_DATA_SEL_E data)
{
#if defined(_veneer_sys_set_vad_d_pcm_sel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_vad_d_pcm_sel,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_sdio_itcfval(uint32_t data)
{
#if defined(_veneer_sys_set_sdio_itcfval)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfval,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_sdio_itcfmul(uint32_t data)
{
#if defined(_veneer_sys_set_sdio_itcfmul)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfmul,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_sdio_itcfsel(uint32_t data)
{
#if defined(_veneer_sys_set_sdio_itcfsel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &data;
    in_vec[0].len = sizeof(data);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfsel,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(data);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_version(uint32_t *version1, uint32_t *version2)
{
#if defined(_veneer_sys_get_version)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[3];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = version1;
    out_vec[1].len = sizeof(uint32_t);
    out_vec[2].base = version2;
    out_vec[2].len = sizeof(uint32_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_version,
                     NULL, 0, 
                     out_vec, 3);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(version1);
    UNUSED(version2);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E sys_set_pinmux(int32_t type, uint8_t pinmux)
{
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &pinmux;
    in_vec[0].len = sizeof(pinmux);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     type,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
}

SCU_ERROR_E veneer_sys_set_PA1_pinmux(SCU_PA1_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PA1_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PA1_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PA0_pinmux(SCU_PA0_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PA0_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PA0_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PA2_pinmux(SCU_PA2_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PA2_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PA2_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PA3_pinmux(SCU_PA3_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PA3_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PA3_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_E i2cm_sda, SCU_SEN_I2CM_SCL_PINMUX_E i2cm_scl)
{
#if defined(_veneer_sys_set_sensor_i2cm_pinmux)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &i2cm_sda;
    in_vec[0].len = sizeof(i2cm_sda);
    in_vec[1].base = &i2cm_scl;
    in_vec[1].len = sizeof(i2cm_scl);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_sensor_i2cm_pinmux,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(i2cm_sda);
    UNUSED(i2cm_scl);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_FAE_pinmux(SCU_SEN_FAE_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_FAE_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_FAE_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_TRIG_pinmux(SCU_SEN_TRIG_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_TRIG_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_TRIG_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_INT_pinmux(SCU_SEN_INT_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_INT_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_INT_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_XSLEEP_pinmux(SCU_SEN_XSLEEP_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_XSLEEP_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_XSLEEP_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_MCLK_pinmux(SCU_SEN_MCLK_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_MCLK_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_MCLK_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_sensorgpio_pinmux(SCU_SEN_GPIO_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_sensorgpio_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_sensorgpio_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_CSW0_pinmux(SCU_SEN_CSW0_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_CSW0_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_CSW0_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_CSW1_pinmux(SCU_SEN_CSW1_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_CSW1_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_CSW1_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D1_pinmux(SCU_SEN_D1_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D1_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D1_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D2_pinmux(SCU_SEN_D2_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D2_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D2_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D3_pinmux(SCU_SEN_D3_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D3_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D3_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D4_pinmux(SCU_SEN_D4_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D4_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D4_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D5_pinmux(SCU_SEN_D5_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D5_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D5_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D6_pinmux(SCU_SEN_D6_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D6_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D6_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_D7_pinmux(SCU_SEN_D7_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_D7_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_D7_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_FVALID_pinmux(SCU_SEN_FVALID_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_FVALID_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_FVALID_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_LVALID_pinmux(SCU_SEN_LVALID_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_LVALID_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_LVALID_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SEN_PCLKO_pinmux(SCU_SEN_PCLK_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SEN_PCLKO_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SEN_PCLKO_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_SDCLK_pinmux(SCU_SDIO_SDCLK_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_SDCLK_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_SDCLK_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_CMD_pinmux(SCU_SDIO_CMD_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_CMD_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_CMD_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_DAT0_pinmux(SCU_SDIO_DATA0_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_DAT0_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT0_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_DAT1_pinmux(SCU_SDIO_DATA1_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_DAT1_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT1_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_DAT2_pinmux(SCU_SDIO_DATA2_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_DAT2_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT2_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SDIO_DAT3_pinmux(SCU_SDIO_DATA3_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SDIO_DAT3_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT3_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SW_DATA_pinmux(SCU_SW_DATA_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SW_DATA_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SW_DATA_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SW_CLK_pinmux(SCU_SW_CLK_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SW_CLK_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SW_CLK_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB2_pinmux(SCU_PB2_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB2_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB2_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB3_pinmux(SCU_PB3_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB3_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB3_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB4_pinmux(SCU_PB4_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB4_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB4_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB5_pinmux(SCU_PB5_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB5_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB5_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB6_pinmux(SCU_PB6_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB6_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB6_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB7_pinmux(SCU_PB7_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB7_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB7_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB8_pinmux(SCU_PB8_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB8_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB8_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB9_pinmux(SCU_PB9_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB9_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB9_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB10_pinmux(SCU_PB10_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB10_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB10_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB11_pinmux(SCU_PB11_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB11_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB11_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PC3_pinmux(SCU_PC3_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PC3_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PC3_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PC4_pinmux(SCU_PC4_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PC4_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PC4_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_I2CM_SCLSDA_pinmux(SCU_I2CM_SCLSDA_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_I2CM_SCLSDA_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_I2CM_SCLSDA_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB0_pinmux(SCU_PB0_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB0_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB0_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_PB1_pinmux(SCU_PB1_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_PB1_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_PB1_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux(SCU_UART_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SPIS_DO_pinmux(SCU_SPIS_DO_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SPIS_DO_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SPIS_DO_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SPIS_DI_pinmux(SCU_SPIS_DI_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SPIS_DI_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SPIS_DI_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SPIS_SCLK_pinmux(SCU_SPIS_SCLK_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SPIS_SCLK_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SPIS_SCLK_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_SPIS_CS_pinmux(SCU_SPIS_CS_PINMUX_E pinmux)
{
#if defined(_veneer_sys_set_SPIS_CS_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_sys_set_SPIS_CS_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_I2C_SLV_share_enable(SCU_I2CSLV_SHARE_E enable)
{
#if defined(_veneer_sys_set_I2C_SLV_share_enable)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_I2C_SLV_share_enable,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_I3C_SLV_share_enable(SCU_I3CSLV_SHARE_E enable)
{
#if defined(_veneer_sys_set_I3C_SLV_share_enable)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_I3C_SLV_share_enable,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(enable);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_DP_SWReset(SCU_DP_SWRESET_T *cfg)
{
#if defined(_veneer_sys_set_DP_SWReset)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = cfg;
    in_vec[0].len = sizeof(SCU_DP_SWRESET_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_DP_SWReset,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_get_DP_SWReset(SCU_DP_SWRESET_T *cfg)
{
#if defined(_veneer_sys_get_DP_SWReset)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = cfg;
    out_vec[1].len = sizeof(SCU_DP_SWRESET_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_get_DP_SWReset,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_pdlsc_pdmck_src(SCU_LSCPDMCLKSRC_E pdmsrc_clk)
{
#if defined(_veneer_set_pdlsc_pdmck_src)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = &pdmsrc_clk;
    out_vec[1].len = sizeof(SCU_LSCPDMCLKSRC_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_pdlsc_pdmck_src,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(pdmsrc_clk);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_wdt_ctrl(uint32_t id, SCU_WDTCTRL_E ctrl)
{
#if defined(_veneer_sys_set_wdt_ctrl)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &ctrl;
    in_vec[1].len = sizeof(ctrl);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_wdt_ctrl,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(ctrl);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_sys_set_timer_ctrl(uint32_t id, SCU_TIMERCTRL_E ctrl)
{
#if defined(_veneer_sys_set_timer_ctrl)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &id;
    in_vec[0].len = sizeof(id);
    in_vec[1].base = &ctrl;
    in_vec[1].len = sizeof(ctrl);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_sys_set_timer_ctrl,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(id);
    UNUSED(ctrl);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_audio_capture_channel(SCU_AUDIO_HWTYPE_E audio_type, SCU_AUDIO_CAPTURE_CHANNEL_E channel)
{
#if defined(_veneer_set_audio_capture_channel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &audio_type;
    in_vec[0].len = sizeof(audio_type);
    in_vec[1].base = &channel;
    in_vec[1].len = sizeof(channel);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_audio_capture_channel,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(audio_type);
    UNUSED(channel);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_get_audio_capture_channel(SCU_AUDIO_HWTYPE_E audio_type, SCU_AUDIO_CAPTURE_CHANNEL_E *channel)
{
#if defined(_veneer_get_audio_capture_channel)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[2];

    in_vec[0].base = &audio_type;
    in_vec[0].len = sizeof(audio_type);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = channel;
    out_vec[1].len = sizeof(SCU_AUDIO_CAPTURE_CHANNEL_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_get_audio_capture_channel,
                     in_vec, 1, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(audio_type);
    UNUSED(channel);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_lsc_adclv_reset(SCU_SWRESET_E cfg)
{
#if defined(_veneer_set_lsc_adclv_reset)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &cfg;
    in_vec[0].len = sizeof(cfg);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_lsc_adclv_reset,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_lsc_adchv_reset(SCU_SWRESET_E cfg)
{
#if defined(_veneer_set_lsc_adchv_reset)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &cfg;
    in_vec[0].len = sizeof(cfg);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_lsc_adchv_reset,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_SRSTN_pinmux(SCU_PAD_SRSTN_PINMUX_E pinmux)
{
#if defined(_veneer_set_SRSTN_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_set_SRSTN_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_SWCLKTCK_pinmux(SCU_PAD_SWCLK_TCK_PINMUX_E pinmux)
{
#if defined(_veneer_set_SWCLKTCK_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_set_SWCLKTCK_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_SWDIO_TMS_pinmux(SCU_PAD_SWDIO_TMS_PINMUX_E pinmux)
{
#if defined(_veneer_set_SWDIO_TMS_pinmux)
    return sys_set_pinmux(TFM_HX_SERVICE + _veneer_set_SWDIO_TMS_pinmux, pinmux);
#else
    UNUSED(pinmux);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_get_all_pinmux_cfg(SCU_PINMUX_CFG_T *pinmux_cfg)
{
#if defined(_veneer_get_all_pinmux_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = pinmux_cfg;
    out_vec[1].len = sizeof(SCU_PINMUX_CFG_T);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_get_all_pinmux_cfg,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(pinmux_cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

SCU_ERROR_E veneer_set_all_pinmux_cfg(SCU_PINMUX_CFG_T *pinmux_cfg)
{
#if defined(_veneer_set_all_pinmux_cfg)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = pinmux_cfg;
    in_vec[0].len = sizeof(SCU_PINMUX_CFG_T);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_set_all_pinmux_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return SCU_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(pinmux_cfg);
    return SCU_UNKNOWN_ERROR;
#endif
}

void veneer_get_pllfreq(uint32_t *freq)
{
#if defined(_veneer_get_pllfreq)
    psa_status_t status;
    SCU_ERROR_E return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = freq;
    out_vec[0].len = sizeof(uint32_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_get_pllfreq,
                     NULL, 0, 
                     out_vec, 1);
#else
    UNUSED(freq);
#endif
}

PM_ERROR_E pm_get_cfgsize_bymode(PM_CFG_PWR_MODE_E mode, uint32_t* cfgsiz)
{
	switch(mode)
	{
	case PM_MODE_PS_DPD:
	    *cfgsiz = sizeof(PM_DPD_CFG_T);
		break;
	case PM_MODE_PS_NOVID_PREROLLING:
	    *cfgsiz = sizeof(PM_PD_NOVIDPRE_CFG_T);
		break;
	case PM_MODE_PS_VID_ONLY_PREROLLING:
	    *cfgsiz = sizeof(PM_PD_VIDPRE_CFG_T);
		break;
	case PM_MODE_PS_AUD_ONLY_PREROLLING:
	    *cfgsiz = sizeof(PM_PD_AUDPRE_CFG_T);
		break;
	case PM_MODE_PS_VIDAUD_PREROLLING:
        *cfgsiz = sizeof(PM_PD_VIDAUDPRE_CFG_T);
		break;
	default:
		return PM_ERROR_INVALID_PARAMETERS;
	}
	return PM_NO_ERROR;
}

PM_ERROR_E veneer_pm_get_defcfg_bymode(void *aCfg, PM_CFG_PWR_MODE_E mode)
{
#if defined(_veneer_pm_get_defcfg_bymode)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[2];
    uint32_t cfgsiz;

    if (PM_NO_ERROR != pm_get_cfgsize_bymode(mode, &cfgsiz))
        return PM_ERROR_INVALID_PARAMETERS;

    in_vec[0].base = &mode;
    in_vec[0].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = aCfg;
    out_vec[1].len = cfgsiz;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_get_defcfg_bymode,
                     in_vec, 1, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(aCfg);
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_pmu_dpdone_check(sensordplib_waitpmudmadone_t cb_fun)
{
#if defined(_veneer_pm_pmu_dpdone_check)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &cb_fun;
    in_vec[0].len = sizeof(cb_fun);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_pmu_dpdone_check,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cb_fun);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_ctrl_fromPMUtoCPU(sensordplib_pmutocpuctrl_t cb_fun)
{
#if defined(_veneer_pm_ctrl_fromPMUtoCPU)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &cb_fun;
    in_vec[0].len = sizeof(cb_fun);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_ctrl_fromPMUtoCPU,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(cb_fun);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_cfg_get(void *aCfg, PM_CFG_PWR_MODE_E mode)
{
#if defined(_veneer_pm_cfg_get)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[2];
    uint32_t cfgsiz;

    if (PM_NO_ERROR != pm_get_cfgsize_bymode(mode, &cfgsiz))
        return PM_ERROR_INVALID_PARAMETERS;

    in_vec[0].base = &mode;
    in_vec[0].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = aCfg;
    out_vec[1].len = cfgsiz;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_cfg_get,
                     in_vec, 1, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(aCfg);
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_cfg_set(void *aCfg, sensordplib_pmudpinit_t cb_fun, PM_CFG_PWR_MODE_E mode)
{
#if defined(_veneer_pm_cfg_set)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[3];
    psa_outvec out_vec[1];
    uint32_t cfgsiz;

    if (PM_NO_ERROR != pm_get_cfgsize_bymode(mode, &cfgsiz))
        return PM_ERROR_INVALID_PARAMETERS;

    in_vec[0].base = aCfg;
    in_vec[0].len = cfgsiz;
    in_vec[1].base = &cb_fun;
    in_vec[1].len = sizeof(cb_fun);
    in_vec[2].base = &mode;
    in_vec[2].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_cfg_set,
                     in_vec, 3, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(aCfg);
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_mode_get(PM_CFG_PWR_MODE_E *mode)
{
#if defined(_veneer_pm_mode_get)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = mode;
    out_vec[1].len = sizeof(PM_CFG_PWR_MODE_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_mode_get,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(mode);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_trigger(SCU_PDHSC_HSCCLK_CFG_T *hsc_cfg, SCU_LSC_CLK_CFG_T *lsc_cfg, PM_CLK_PARA_CTRL_E clkparactrl)
{
#if defined(_veneer_pm_trigger)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[3];
    psa_outvec out_vec[1];

    in_vec[0].base = hsc_cfg;
    in_vec[0].len = sizeof(SCU_PDHSC_HSCCLK_CFG_T);
    in_vec[1].base = lsc_cfg;
    in_vec[1].len = sizeof(SCU_LSC_CLK_CFG_T);
    in_vec[2].base = &clkparactrl;
    in_vec[2].len = sizeof(PM_CLK_PARA_CTRL_E);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_trigger,
                     in_vec, 3,
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(hsc_cfg);
    UNUSED(lsc_cfg);
    UNUSED(clkparactrl);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_get_event(PMU_WAKEUPEVENT_E *aWakeupEvt, PMU_WAKEUPEVENT1_E *aWakeupEvt1)
{
#if defined(_veneer_pm_get_event)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_outvec out_vec[3];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = aWakeupEvt;
    out_vec[1].len = sizeof(PMU_WAKEUPEVENT_E);
    out_vec[2].base = aWakeupEvt1;
    out_vec[2].len = sizeof(PMU_WAKEUPEVENT1_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_get_event,
                     NULL, 0, 
                     out_vec, 3);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(aWakeupEvt);
    UNUSED(aWakeupEvt1);
    return SCU_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_clear_event(void)
{
#if defined(_veneer_pm_clear_event)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_clear_event,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    return PM_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_force_state_set(PMU_PS_STATE_E state)
{
#if defined(_veneer_pm_force_state_set)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &state;
    in_vec[0].len = sizeof(state);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_force_state_set,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(state);
    return PM_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_force_state_get(PMU_PS_STATE_E *state)
{
#if defined(_veneer_pm_force_state_get)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_outvec out_vec[2];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = state;
    out_vec[1].len = sizeof(PMU_PS_STATE_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_force_state_get,
                     NULL, 0, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(state);
    return PM_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_set_dma_cfg(uint8_t dma_int)
{
#if defined(_veneer_pm_set_dma_cfg)
    psa_status_t status;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &dma_int;
    in_vec[0].len = sizeof(dma_int);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_set_dma_cfg,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(dma_int);
    return PM_UNKNOWN_ERROR;
#endif
}

PM_ERROR_E veneer_pm_ext_int_get(PM_EXT_INT_STATUS_TYPE_E type, uint8_t *status)
{
#if defined(_veneer_pm_ext_int_get)
    psa_status_t status_tmp;
    PM_ERROR_E return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[2];

    in_vec[0].base = &type;
    in_vec[0].len = sizeof(type);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = status;
    out_vec[1].len = sizeof(uint8_t);

    status_tmp = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_pm_ext_int_get,
                     in_vec, 1, 
                     out_vec, 2);

    if (status_tmp != PSA_SUCCESS)
        return PM_UNKNOWN_ERROR;

    return return_value;
#else
    UNUSED(type);
    UNUSED(status);
    return PM_UNKNOWN_ERROR;
#endif
}

void veneer_get_pmuwakeup_freq(SCU_PLL_FREQ_E *pll_freq, SCU_HSCCLKDIV_E *cm55m_div, SCU_LSCCLKDIV_E *cm55s_div)
{
#if defined(_veneer_get_pmuwakeup_freq)
    psa_status_t status;
    psa_outvec out_vec[3];

    out_vec[0].base = pll_freq;
    out_vec[0].len = sizeof(SCU_PLL_FREQ_E);
    out_vec[1].base = cm55m_div;
    out_vec[1].len = sizeof(SCU_HSCCLKDIV_E);
    out_vec[2].base = cm55s_div;
    out_vec[2].len = sizeof(SCU_LSCCLKDIV_E);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_get_pmuwakeup_freq,
                     NULL, 0, 
                     out_vec, 3);
#endif
}

int32_t veneer_spi_eeprom_open(VENEER_SPI_EEPROM_E spi_id)
{
#if defined(_veneer_spi_eeprom_open)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_open,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_open_speed(VENEER_SPI_EEPROM_E spi_id, uint32_t clk_hz)
{
#if defined(_veneer_spi_eeprom_open_speed)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &clk_hz;
    in_vec[1].len = sizeof(clk_hz);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_open_speed,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(clk_hz);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_read_ID(VENEER_SPI_EEPROM_E spi_id, uint8_t *id_info)
{
#if defined(_veneer_spi_eeprom_read_ID)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[2];
    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = id_info;
    out_vec[1].len = sizeof(uint8_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_read_ID,
                     in_vec, 1, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(id_info);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_1read(VENEER_SPI_EEPROM_E spi_id, uint32_t flash_addr, uint8_t *data, uint32_t len)
{
#if defined(_veneer_spi_eeprom_1read)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[2];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &flash_addr;
    in_vec[1].len = sizeof(flash_addr);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = len;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_1read,
                     in_vec, 2, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(flash_addr);
    UNUSED(data);
    UNUSED(len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_2read(VENEER_SPI_EEPROM_E spi_id, uint32_t flash_addr, uint8_t *data, uint32_t len)
{
#if defined(_veneer_spi_eeprom_2read)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[2];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &flash_addr;
    in_vec[1].len = sizeof(flash_addr);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = len;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_2read,
                     in_vec, 2, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(flash_addr);
    UNUSED(data);
    UNUSED(len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_4read(VENEER_SPI_EEPROM_E spi_id, uint32_t flash_addr, uint8_t *data, uint32_t len)
{
#if defined(_veneer_spi_eeprom_4read)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[2];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &flash_addr;
    in_vec[1].len = sizeof(flash_addr);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = len;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_4read,
                     in_vec, 2, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(flash_addr);
    UNUSED(data);
    UNUSED(len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_word_read(VENEER_SPI_EEPROM_E spi_id, uint32_t addr, uint32_t *data, uint32_t bytes_len)
{
#if defined(_veneer_spi_eeprom_word_read)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[2];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &addr;
    in_vec[1].len = sizeof(addr);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = bytes_len;

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_word_read,
                     in_vec, 2, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(addr);
    UNUSED(data);
    UNUSED(bytes_len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_word_write(VENEER_SPI_EEPROM_E spi_id, uint32_t addr, uint32_t *data, uint32_t bytes_len)
{
#if defined(_veneer_spi_eeprom_word_write)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[3];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &addr;
    in_vec[1].len = sizeof(addr);
    in_vec[2].base = data;
    in_vec[2].len = bytes_len;

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_word_write,
                     in_vec, 3, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(addr);
    UNUSED(data);
    UNUSED(bytes_len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_write(VENEER_SPI_EEPROM_E spi_id, uint32_t addr, uint8_t *data, uint32_t bytes_len)
{
#if defined(_veneer_spi_eeprom_write)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[3];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &addr;
    in_vec[1].len = sizeof(addr);
    in_vec[2].base = data;
    in_vec[2].len = bytes_len;

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_write,
                     in_vec, 3, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(addr);
    UNUSED(data);
    UNUSED(bytes_len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_Send_Op_code(VENEER_SPI_EEPROM_E spi_id, uint8_t *data, uint32_t len)
{
#if defined(_veneer_spi_eeprom_Send_Op_code)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = data;
    in_vec[1].len = len;

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_Send_Op_code,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(data);
    UNUSED(len);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_erase_all(VENEER_SPI_EEPROM_E spi_id)
{
#if defined(_veneer_spi_eeprom_erase_all)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_erase_all,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_erase_sector(VENEER_SPI_EEPROM_E spi_id, uint32_t addr)
{
#if defined(_veneer_spi_eeprom_erase_sector)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[1];

    in_vec[0].base = &spi_id;
    in_vec[0].len = sizeof(spi_id);
    in_vec[1].base = &addr;
    in_vec[1].len = sizeof(addr);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_erase_sector,
                     in_vec, 2, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(addr);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_eeprom_enable_XIP(VENEER_SPI_EEPROM_E spi_id, 
                                     bool xip_enable, 
                                     VENEER_FLASH_ACCESS_MODE_E xip_mode, 
                                     bool xip_cont)
{
#if defined(_veneer_spi_eeprom_enable_XIP)
    psa_status_t status;
    int32_t return_value;
    typedef struct veneer_spi_eeprom_enable_XIP_in_para_t {
        VENEER_SPI_EEPROM_E spi_id;
        bool xip_enable;
        VENEER_FLASH_ACCESS_MODE_E xip_mode;
        bool xip_cont;
    } veneer_spi_eeprom_enable_XIP_in_para_t;

    psa_invec in_vec[1];
    psa_outvec out_vec[1];
    //in_vec size + out_vec size <= 4

    veneer_spi_eeprom_enable_XIP_in_para_t in_para;
    in_para.spi_id = spi_id;
    in_para.xip_enable = xip_enable;
    in_para.xip_mode = xip_mode;
    in_para.xip_cont = xip_cont;

    in_vec[0].base = &in_para;
    in_vec[0].len = sizeof(in_para);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_eeprom_enable_XIP,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(spi_id);
    UNUSED(xip_enable);
    UNUSED(xip_mode);
    UNUSED(xip_cont);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_psram_open(void)
{
#if defined(_veneer_spi_psram_open)
    psa_status_t status;
    int32_t return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_psram_open,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else 
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_psram_SetXIP(bool enable)
{
#if defined(_veneer_spi_psram_SetXIP)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &enable;
    in_vec[0].len = sizeof(enable);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_psram_SetXIP,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(enable);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_psram_set_powermode(VENEER_PSRAM_POWER_MDOE_E mode)
{
#if defined(_veneer_spi_psram_set_powermode)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[1];
    psa_outvec out_vec[1];

    in_vec[0].base = &mode;
    in_vec[0].len = sizeof(mode);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_psram_set_powermode,
                     in_vec, 1, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(mode);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_psram_get_info(uint32_t *data, uint32_t reg, uint32_t id)
{
#if defined(_veneer_spi_psram_get_info)
    psa_status_t status;
    int32_t return_value;
    psa_invec in_vec[2];
    psa_outvec out_vec[2];

    in_vec[0].base = &reg;
    in_vec[0].len = sizeof(reg);
    in_vec[1].base = &id;
    in_vec[1].len = sizeof(id);

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);
    out_vec[1].base = data;
    out_vec[1].len = sizeof(uint32_t);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_psram_get_info,
                     in_vec, 2, 
                     out_vec, 2);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    UNUSED(data);
    UNUSED(reg);
    UNUSED(id);
    return PM_UNKNOWN_ERROR;
#endif
}

int32_t veneer_spi_psram_close(void)
{
#if defined(_veneer_spi_psram_close)
    psa_status_t status;
    int32_t return_value;
    psa_outvec out_vec[1];

    out_vec[0].base = &return_value;
    out_vec[0].len = sizeof(return_value);

    status = psa_call(TFM_HX_SERVICE_HANDLE,
                     TFM_HX_SERVICE + _veneer_spi_psram_close,
                     NULL, 0, 
                     out_vec, 1);

    if (status != PSA_SUCCESS)
        return E_PAR;

    return return_value;
#else
    return PM_UNKNOWN_ERROR;
#endif
}
