/*
 * Copyright (c) 2017-2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#include "test_app.h"
#include "tfm_log.h"
#include "tfm_hx_service_defs.h"
#include "psa/client.h"
 
#if defined(TEST_RETENTION)
#include "hx_drv_timer.h"
#include "veneer_power_ctrl.h"
void test_retention();
#endif

#ifdef TEST_FRAMEWORK_NS
#include "test_framework_integ_test.h"
#endif

#if PSA_API_TEST_NS
/**
 * \brief This symbol is the entry point provided by the PSA API compliance
 *        test libraries
 */
extern void val_entry(void);
#endif

/**
 * \brief Services test thread
 *
 */
__attribute__((noreturn))
void test_app(void *argument)
{
    UNUSED_VARIABLE(argument);

#ifdef TEST_FRAMEWORK_NS
    tfm_non_secure_client_run_tests();
#endif

#ifdef PSA_API_TEST_NS
    val_entry();
#endif
    
#if 0//def TEST_NS_FLIH_HX
    if (test_tfm_hx_veneer_timer_ctrl() != PSA_SUCCESS)
        LOG_MSG("test_tfm_hx_veneer_timer_ctrl, FAILED\r\n");
    else
        LOG_MSG("test_tfm_hx_veneer_timer_ctrl, PASS\r\n");

    //if (test_tfm_hx_veneer_spi_eeprom() != PSA_SUCCESS)
    //    LOG_MSG("test_tfm_hx_veneer_spi_eeprom, FAILED\r\n");
    //else
    //    LOG_MSG("test_tfm_hx_veneer_spi_eeprom, PASS\r\n");

    //if (test_tfm_hx_veneer_clk_ctrl() != PSA_SUCCESS)
    //    LOG_MSG("test_tfm_hx_veneer_clk_ctrl, FAILED\r\n");
    //else
    //    LOG_MSG("test_tfm_hx_veneer_clk_ctrl, PASS\r\n");

    //if (test_tfm_hx_veneer_sys_ctrl() != PSA_SUCCESS)
    //    LOG_MSG("test_tfm_hx_veneer_sys_ctrl, FAILED\r\n");
    //else
    //    LOG_MSG("test_tfm_hx_veneer_sys_ctrl, PASS\r\n");

    //if (test_tfm_hx_veneer_spi_psram() != PSA_SUCCESS)
    //    LOG_MSG("test_tfm_hx_veneer_spi_psram, FAILED\r\n");
    //else
    //    LOG_MSG("test_tfm_hx_veneer_spi_psram, PASS\r\n");

    //if (test_tfm_hx_veneer_power_ctrl() != PSA_SUCCESS)
    //    LOG_MSG("test_tfm_hx_veneer_power_ctrl, FAILED\r\n");
    //else
    //    LOG_MSG("test_tfm_hx_veneer_power_ctrl, PASS\r\n");
#endif

    /* Output EOT char for test environments like FVP. */
    LOG_MSG("\x04");

#if defined(TEST_RETENTION)
    test_retention();
#endif

    /* End of test */
    for (;;) {
    }
}

#if defined(TEST_RETENTION)
void GetPMULibClearEvt();
void SetPMUClearAllIPInt();
void Timer_StartPMU();
void SetPMULibNoVIDPD();
void SetPMULibTrig();
void RTCCM55_SetAlarmPMU();

void test_retention()
{
    GetPMULibClearEvt();
    SetPMUClearAllIPInt();
    SetPMULibNoVIDPD();
    Timer_StartPMU();
    //RTCCM55_SetAlarmPMU();
    SetPMULibTrig();
    LOG_MSG("!!!!!!!!!!!!!!!!!!!!!!!!!!!\r\n");
}

void GetPMULibClearEvt()
{
    LOG_MSG("veneer_pm_clear_event\r\n");
    veneer_pm_clear_event();
}

void clear_all_sysip_int()
{
#ifdef IP_rtc
    hx_drv_rtc_clear_alarm_int_status(RTC_ID_0);
    hx_drv_rtc_clear_alarm_int_status(RTC_ID_1);
    hx_drv_rtc_clear_alarm_int_status(RTC_ID_2);
#endif
#ifdef IP_timer
    hx_drv_timer_ClearIRQ(TIMER_ID_0);
    //hx_drv_timer_ClearIRQ(TIMER_ID_1);
    //hx_drv_timer_ClearIRQ(TIMER_ID_2);
    //hx_drv_timer_ClearIRQ(TIMER_ID_3);
    //hx_drv_timer_ClearIRQ(TIMER_ID_4);
    //hx_drv_timer_ClearIRQ(TIMER_ID_5);
    //hx_drv_timer_ClearIRQ(TIMER_ID_6);
    //hx_drv_timer_ClearIRQ(TIMER_ID_7);
    //hx_drv_timer_ClearIRQ(TIMER_ID_8);
#endif
#ifdef IP_watchdog
    hx_drv_watchdog_irq_clear(WATCHDOG_ID_0);
    hx_drv_watchdog_irq_clear(WATCHDOG_ID_1);
#endif
#ifdef IP_gpio
    hx_drv_gpio_clr_int_status(AON_GPIO0);
    hx_drv_gpio_clr_int_status(AON_GPIO1);
    hx_drv_gpio_clr_int_status(SB_GPIO0);
    hx_drv_gpio_clr_int_status(SB_GPIO1);
#endif
#ifdef IP_hxautoi2c_mst
    hx_drv_hxautoi2c_clr_noack_int(HXAUTOI2CHC_INTSTATUS_DATA_NO_ACK);
    hx_drv_hxautoi2c_clr_noack_int(HXAUTOI2CHC_INTSTATUS_ADDR_NO_ACK);
#endif
#ifdef IP_adcc_hv
    hx_drv_adcc_hv_set_int_clear(0xFFFFFFFF);
#endif
}

void SetPMUClearAllIPInt()
{
    LOG_MSG("SetPMUClearAllIPInt\r\n");
    clear_all_sysip_int();
}

void SetPMULibNoVIDPD()
{
    LOG_MSG("SetPMULibNoVIDPD\r\n");

    PM_PD_NOVIDPRE_CFG_T cfg;
    uint8_t speed,reset, retention, precap, nframeend_ctrl, mipilane, sensor_type;
    uint32_t pmu_pad_pa01_mask, pmu_rtc_mask, support_debugdump;
    uint32_t pmu_pad_pa23_mask, pmu_i2cw_mask, pmu_timer_mask, pmu_cmp_mask, pmu_ts_mask;
    uint32_t dcdcpin, freq, cm55mdiv, cm55sdiv, pmu_anti_mask;
    uint32_t cm55_m_rw, cm55_s_rw, ioret;
    uint32_t pd_simo_onoff;

    //0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0
    //0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 
    speed = 0;//strtoul(argv[0], NULL, 10);
    reset = 1;//strtoul(argv[1], NULL, 10);
    nframeend_ctrl = 0;//strtoul(argv[2], NULL, 10);
    retention = 1;//strtoul(argv[3], NULL, 10);
    precap = 1;//strtoul(argv[4], NULL, 10);
    pmu_pad_pa01_mask = 0;//strtoul(argv[5], NULL, 16);
    pmu_rtc_mask = 0;//strtoul(argv[6], NULL, 16);
    pmu_pad_pa23_mask = 0;//strtoul(argv[7], NULL, 16);
    pmu_i2cw_mask = 0;//strtoul(argv[8], NULL, 16);
    pmu_timer_mask = 0;//strtoul(argv[9], NULL, 16);
    pmu_cmp_mask = 0;//strtoul(argv[10], NULL, 16);
    pmu_ts_mask = 0;//strtoul(argv[11], NULL, 16);
    mipilane = 0;//strtoul(argv[12], NULL, 10);
    support_debugdump = 0;//strtoul(argv[13], NULL, 10);
    dcdcpin = 0;//strtoul(argv[14], NULL, 10);
    freq = 0;//strtoul(argv[15], NULL, 10);
    cm55mdiv = 0;//strtoul(argv[16], NULL, 10);
    cm55sdiv = 0;//strtoul(argv[17], NULL, 10);
    pmu_anti_mask = 0;//strtoul(argv[18], NULL, 10);
    cm55_m_rw = 0;//strtoul(argv[19], NULL, 10);
    cm55_s_rw = 1;//strtoul(argv[20], NULL, 10);
    ioret  = 0;//strtoul(argv[21], NULL, 10);
    sensor_type = 1;//strtoul(argv[22], NULL, 10);
    pd_simo_onoff = 0;//strtoul(argv[23], NULL, 10);

    LOG_MSG("speed=%d,reset=%d,nframeend_ctrl=%d,retention=%d,precap=%d\r\n", speed,reset,nframeend_ctrl,retention,precap);
    LOG_MSG("ag_mask=0x%x,rtc_mask=0x%x,sb_mask=0x%x,i2cw_mask=0x%x,timer_mask=0x%x,cmp_mask=0x%x,ts_mask=0x%x\r\n", pmu_pad_pa01_mask,pmu_rtc_mask,pmu_pad_pa23_mask,pmu_i2cw_mask,pmu_timer_mask,pmu_cmp_mask,pmu_ts_mask);
    LOG_MSG("mipilane=%d,debug=%d\r\n", mipilane,support_debugdump);
    LOG_MSG("dcdcpin=%d, pmu_anti_mask=0x%x, ioret=%d\r\n", dcdcpin, pmu_anti_mask, ioret);
    LOG_MSG("freq=%d, cm55mdiv=%d,cm55sdiv=%d\r\n", freq, cm55mdiv, cm55sdiv);
    LOG_MSG("cm55_m_rw=%d, cm55_s_rw=%d, sensor_type=%d\r\n", cm55_m_rw, cm55_s_rw, sensor_type);
    LOG_MSG("pd_simo_onoff=%d\r\n", pd_simo_onoff);

    switch(speed)
    {
    case 0:
        cfg.bootromspeed.bootromclkfreq = SCU_PLL_FREQ_DISABLE;
        cfg.bootromspeed.pll_freq = 0;
        cfg.bootromspeed.cm55m_div = SCU_HSCCLKDIV_1;
        cfg.bootromspeed.cm55s_div = SCU_LSCCLKDIV_1;
        break;
    default:
        cfg.bootromspeed.bootromclkfreq = SCU_PLL_FREQ_ENABLE;
        cfg.bootromspeed.pll_freq = freq;
        cfg.bootromspeed.cm55m_div = cm55mdiv;
        cfg.bootromspeed.cm55s_div = cm55sdiv;
        break;
    }

    cfg.cm55s_reset = reset;
    cfg.pmu_pad_pa01_mask = pmu_pad_pa01_mask;
    cfg.pmu_rtc_mask = pmu_rtc_mask;
    cfg.pmu_pad_pa23_mask = pmu_pad_pa23_mask;            /**< PMU SB GPIO Interrupt Mask **/
    cfg.pmu_i2cw_mask = pmu_i2cw_mask;            /**< PMU I2C Wakeup Interrupt Mask **/
    cfg.pmu_timer_mask = pmu_timer_mask;            /**< PMU Timer0~5 Wakeup Interrupt Mask  **/
    cfg.pmu_cmp_mask = pmu_cmp_mask;            /**< PMU CMP Wakeup Interrupt Mask  **/
    cfg.pmu_ts_mask = pmu_ts_mask;            /**< PMU TS Wakeup Interrupt Mask  **/
    cfg.mipi_lane_en = mipilane;
    cfg.support_debugdump = support_debugdump;
    cfg.pmu_anti_mask = pmu_anti_mask;
    cfg.nframeend_ctrl = nframeend_ctrl;    /**< NFrame Control **/

    cfg.tcm_retention = retention;            /**< CM55M TCM Retention**/
    cfg.hscsram_retention[0] = retention;    /**< HSC SRAM Retention**/
    cfg.hscsram_retention[1] = retention;    /**< HSC SRAM Retention**/
    cfg.hscsram_retention[2] = retention;    /**< HSC SRAM Retention**/
    cfg.hscsram_retention[3] = retention;    /**< HSC SRAM Retention**/
    cfg.lscsram_retention = retention;        /**< LSC SRAM Retention**/
    cfg.skip_bootflow.sec_mem_flag = retention;            /**< Skip Boot Flow**/
    cfg.skip_bootflow.first_bl_flag = retention; /*!< First BL Retention */
    cfg.skip_bootflow.cm55m_s_app_flag = retention; /*!< cm55m_s_app Retention */
    cfg.skip_bootflow.cm55m_ns_app_flag = retention; /*!< cm55m_ns_app Retention */
    cfg.skip_bootflow.cm55s_s_app_flag = retention; /*!< cm55s_s_app Retention */
    cfg.skip_bootflow.cm55s_ns_app_flag = retention; /*!< cm55s_ns_app Retention */
    cfg.skip_bootflow.cm55m_model_flag = retention; /*!< cm55m model Retention */
    cfg.skip_bootflow.cm55s_model_flag = retention; /*!< cm55s model Retention */
    cfg.skip_bootflow.cm55m_appcfg_flag = retention; /*!< cm55m appcfg Retention */
    cfg.skip_bootflow.cm55s_appcfg_flag = retention; /*!< cm55s appcfg Retention */
    cfg.skip_bootflow.cm55m_s_app_rwdata_flag = cm55_m_rw;/*!< cm55m_s_app RW Data Retention */
    cfg.skip_bootflow.cm55m_ns_app_rwdata_flag = cm55_m_rw;/*!< cm55m_ns_app RW Data Retention */
    cfg.skip_bootflow.cm55s_s_app_rwdata_flag = cm55_s_rw;/*!< cm55s_s_app RW Data Retention */
    cfg.skip_bootflow.cm55s_ns_app_rwdata_flag = cm55_s_rw;
    cfg.skip_bootflow.secure_debug_flag = retention;

    cfg.support_bootwithcap = precap;        /**< Support capture when boot up**/
    cfg.pmu_dcdc_outpin = dcdcpin;
    cfg.ioret = ioret;
    cfg.sensor_type = sensor_type;
    cfg.simo_pd_onoff = pd_simo_onoff;
    LOG_MSG("veneer_pm_cfg_set\r\n");
    veneer_pm_cfg_set(&cfg, NULL, PM_MODE_PS_NOVID_PREROLLING);
}

void Timer_StartPMU()
{
    uint32_t id;
    uint32_t period;
    uint32_t mode;
    TIMER_ERROR_E ret;
    TIMER_CFG_T timer_cfg;
    LOG_MSG("Timer_StartPMU\r\n");

    id = 0;//strtoul(argv[0], NULL, 10);
    period = 5000;//strtoul(argv[1], NULL, 10);

    mode  = 0;
    //g_cb_occur_flag = 0;

    timer_cfg.period = period;
    timer_cfg.mode = mode;
    timer_cfg.ctrl = TIMER_CTRL_PMU;
    timer_cfg.state = TIMER_STATE_PMU;

    LOG_MSG("ID=%d, period=%d ms, mode=%d\r\n", id, period, mode);
    ret = hx_drv_timer_hw_start(id, &timer_cfg, NULL);
    LOG_MSG("ID=%d, period=%d ms, mode=%d, ret=%d\r\n", id, period, mode, ret);
}

void RTCCM55_SetAlarmPMU()
{
    uint32_t alarm_en, alarm_cycle, time_cycle;
    uint32_t id;
    RTC_ERROR_E ret;
    TIMER_ERROR_E ret_timer;
    LOG_MSG("RTCCM55_SetAlarmPMU\r\n");

    id = 0;//strtoul(argv[0], NULL, 10);
    time_cycle  = 1000;//strtoul(argv[1], NULL, 10);
    alarm_cycle  = 1005;//strtoul(argv[2], NULL, 10);

    ret = hx_drv_rtc_clear_alarm_int_status(id);
    ret = hx_drv_rtc_enable(id, 0);
    alarm_en = 1;

    switch (id) {
        case RTC_ID_0:
            ret = hx_drv_rtc_set_time_cycle(id, time_cycle);
            ret = hx_drv_rtc_set_alarm_cycle(id, alarm_en, alarm_cycle, NULL);
            break;
        case RTC_ID_1:
            ret = hx_drv_rtc_set_time_cycle(id, time_cycle);
            ret = hx_drv_rtc_set_alarm_cycle(id, alarm_en, alarm_cycle, NULL);
            break;
        case RTC_ID_2:
            ret = hx_drv_rtc_set_time_cycle(id, time_cycle);
            ret = hx_drv_rtc_set_alarm_cycle(id, alarm_en, alarm_cycle, NULL);
            break;
    }
}


void SetPMULibTrig()
{
    LOG_MSG("SetPMULibTrig\r\n");
#define SUPPORT_XTAL24MRC32K

#ifdef CM55_BIG
    SCU_LSC_CLK_CFG_T lsc_cfg;
    SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;

#ifdef SUPPORT_RC24MRC32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC24M1M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC24M1M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC48MRC32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC96MRC32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_XTAL24M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_XTAL24M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC48MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC96MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC32K
    LOG_MSG("SUPPORT_XTAL24MRC32K\r\n");
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_XTAL24M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_XTAL24M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC48MRC32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC96MRC32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC24M1M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC24M1M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC48MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC96MXTAL32K
    hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
    hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
    hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
    hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
    hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
    lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
    lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
    LOG_MSG("hsc_cfg.hscclk.hscclksrc=%d\r\n", hsc_cfg.hscclk.hscclksrc);
    LOG_MSG("hsc_cfg.hscclk.hscclkdiv=%d\r\n", hsc_cfg.hscclk.hscclkdiv);
    LOG_MSG("hsc_cfg.hscd12clksrc=%d\r\n", hsc_cfg.hscd12clksrc);
    LOG_MSG("hsc_cfg.i3chcdiv=%d\r\n", hsc_cfg.i3chcdiv);
    LOG_MSG("lsc_cfg.lscclksrc=%d\r\n", lsc_cfg.lscclksrc);
    LOG_MSG("lsc_cfg.lscclkdiv=%d\r\n", lsc_cfg.lscclkdiv);
    LOG_MSG("veneer_pm_trigger\r\n");
    veneer_pm_trigger(&hsc_cfg, &lsc_cfg);
#endif
}
#endif
