/*
 * Copyright (c) 2019-2021 Arm Limited. All rights reserved.
 *
 * Licensed under the Apache License Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing software
 * distributed under the License is distributed on an "AS IS" BASIS
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * \file device_definition.h
 * \brief The structure definitions in this file are exported based on the
 * peripheral definitions from device_cfg.h.
 * This file is meant to be used as a helper for baremetal
 * applications and/or as an example of how to configure the generic
 * driver structures.
 */

#ifndef __DEVICE_DEFINITION_H__
#define __DEVICE_DEFINITION_H__

#include "WE2_core.h"

#ifdef IP_uart
#include "hx_drv_uart.h"
#endif
#ifdef IP_timer
#include "hx_drv_timer.h"
#endif
#ifdef IP_scu
#include "hx_drv_scu_export.h"
#include "hx_drv_scu.h"
#endif
#ifdef IP_mpc
#include "hx_drv_mpc.h"
#endif
#ifdef IP_ppc
#include "hx_drv_ppc.h"
#endif

#ifdef LIB_SPI_EEPROM
#include "spi_eeprom_comm.h"
#endif
#ifdef LIB_COMMON
#include "console_io.h"
#endif

#include "device_cfg.h"

#ifdef __cplusplus
extern "C" {
#endif

/* ======= Defines peripheral configuration structures ======= */

#ifdef __cplusplus
}
#endif

#endif  /* __DEVICE_DEFINITION_H__ */
