/*
 * Copyright (c) 2019-2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#include "cmsis.h"
//#include "systimer_armv8-m_drv.h"
#include "tfm_plat_test.h"
#include "device_definition.h"
//#include "BITOPS.h"
#include "psa_manifest/sid.h"
#include "psa/client.h"

/* Interrupt interval is set to 1 ms */
//#define TIMER_RELOAD_VALUE          (SYSTIMER0_ARMV8M_DEFAULT_FREQ_HZ / 1000)

typedef struct {
	__IO uint32_t CTRL; /*!< Offset: 0x000 Control Register (R/W) */
	__IO uint32_t VALUE; /*!< Offset: 0x004 Current Value Register (R/W) */
	__IO uint32_t RELOAD; /*!< Offset: 0x008 Reload Value Register  (R/W) */
	union {
		__I uint32_t INTSTATUS; /*!< Offset: 0x00C Interrupt Status Register (R/ ) */
		__O uint32_t INTCLEAR; /*!< Offset: 0x00C Interrupt Clear Register ( /W) */
	};

} HX_TIMER_TypeDef;

#define HX_TIMER_CTRL_IRQEN_Pos          3                                              /*!< HX_TIMER CTRL: IRQEN Position */
#define HX_TIMER_CTRL_IRQEN_Msk          (0x01ul << HX_TIMER_CTRL_IRQEN_Pos)         /*!< HX_TIMER CTRL: IRQEN Mask */

#define HX_TIMER_CTRL_SELEXTCLK_Pos      2                                              /*!< HX_TIMER CTRL: SELEXTCLK Position */
#define HX_TIMER_CTRL_SELEXTCLK_Msk      (0x01ul << HX_TIMER_CTRL_SELEXTCLK_Pos)     /*!< HX_TIMER CTRL: SELEXTCLK Mask */

#define HX_TIMER_CTRL_SELEXTEN_Pos       1                                              /*!< HX_TIMER CTRL: SELEXTEN Position */
#define HX_TIMER_CTRL_SELEXTEN_Msk       (0x01ul << HX_TIMER_CTRL_SELEXTEN_Pos)      /*!< HX_TIMER CTRL: SELEXTEN Mask */

#define HX_TIMER_CTRL_EN_Pos             0                                              /*!< HX_TIMER CTRL: EN Position */
#define HX_TIMER_CTRL_EN_Msk             (0x01ul << HX_TIMER_CTRL_EN_Pos)            /*!< HX_TIMER CTRL: EN Mask */

#define HX_TIMER_VAL_CURRENT_Pos         0                                              /*!< HX_TIMER VALUE: CURRENT Position */
#define HX_TIMER_VAL_CURRENT_Msk         (0xFFFFFFFFul << HX_TIMER_VAL_CURRENT_Pos)  /*!< HX_TIMER VALUE: CURRENT Mask */

#define HX_TIMER_RELOAD_VAL_Pos          0                                              /*!< HX_TIMER RELOAD: RELOAD Position */
#define HX_TIMER_RELOAD_VAL_Msk          (0xFFFFFFFFul << HX_TIMER_RELOAD_VAL_Pos)   /*!< HX_TIMER RELOAD: RELOAD Mask */

#define HX_TIMER_INTSTATUS_Pos           0                                              /*!< HX_TIMER INTSTATUS: INTSTATUSPosition */
#define HX_TIMER_INTSTATUS_Msk           (0x01ul << HX_TIMER_INTSTATUS_Pos)          /*!< HX_TIMER INTSTATUS: INTSTATUSMask */

#define HX_TIMER_INTCLEAR_Pos            0                                              /*!< HX_TIMER INTCLEAR: INTCLEAR Position */
#define HX_TIMER_INTCLEAR_Msk            (0x01ul << HX_TIMER_INTCLEAR_Pos)           /*!< HX_TIMER INTCLEAR: INTCLEAR Mask */

#define TIMER2_CLK_DIV          (2) 
#define HX_TIMER2_DEV_S         ((HX_TIMER_TypeDef  *) BASE_ADDR_APB_TIMER2_ALIAS)

#ifdef TEST_NS_SLIH_IRQ
TFM_LINK_SET_RW_IN_PARTITION_SECTION("TFM_SP_SLIH_TEST", "APP-ROT")
static uint32_t is_initialized = 0;
#elif defined(TEST_NS_FLIH_IRQ)
TFM_LINK_SET_RW_IN_PARTITION_SECTION("TFM_SP_FLIH_TEST", "APP-ROT")
static uint32_t is_initialized = 0;
#else
static uint32_t is_initialized = 0;
#endif

#ifdef TEST_NS_SLIH_IRQ
TFM_LINK_SET_RW_IN_PARTITION_SECTION("TFM_SP_SLIH_TEST", "APP-ROT")
static uint32_t timer2_reload_value;
#elif defined(TEST_NS_FLIH_IRQ)
TFM_LINK_SET_RW_IN_PARTITION_SECTION("TFM_SP_FLIH_TEST", "APP-ROT")
static uint32_t timer2_reload_value;
#else
static uint32_t timer2_reload_value;
#endif
#if 0
void tfm_plat_test_secure_timer_start(void)
{
    uint32_t freq, timer_clk_data;

    if (!is_initialized) {
        hx_drv_scu_get_freq(SCU_CLK_FREQ_TYPE_SB_APB_1_CLK, &freq);
        timer_clk_data = hx_get_memory((BASE_ADDR_APB_SCU_SB_ALIAS + SCU_TIMER_CLK_EN));

#if (TIMER2_CLK_DIV <= 1)
        HX_BIT_SET(timer_clk_data, BIT_SIZE_TIMER2_CLK_EN, BIT_POS_TIMER2_CLK_EN, 0);
#elif (TIMER2_CLK_DIV > 1)
        HX_BIT_SET(timer_clk_data, BIT_SIZE_TIMER2_CLK_EN, BIT_POS_TIMER2_CLK_EN, 1); //SELEXTCLK
#else
#error "TIMER2_CLK_DIV must > 0"
#endif

        hx_set_memory((BASE_ADDR_APB_SCU_SB_ALIAS + SCU_TIMER_CLK_EN), timer_clk_data);
        hx_set_memory((BASE_ADDR_APB_SCU_SB_ALIAS + SCU_TIMER2_CLK_DIV), TIMER2_CLK_DIV - 1);

        timer2_reload_value = (freq / TIMER2_CLK_DIV) / 1000; //Interrupt interval is set to 1 ms
        is_initialized = 1;
    }

    HX_TIMER2_DEV_S->VALUE = timer2_reload_value;
    HX_TIMER2_DEV_S->RELOAD = timer2_reload_value;

#if (TIMER2_CLK_DIV <= 1)
    HX_TIMER2_DEV_S->CTRL = (HX_TIMER_CTRL_IRQEN_Msk | 1);
#else
    HX_TIMER2_DEV_S->CTRL = (HX_TIMER_CTRL_SELEXTCLK_Msk | HX_TIMER_CTRL_IRQEN_Msk | 1);
#endif
}
#endif

void tfm_plat_test_secure_timer_start(void)
{
    uint32_t freq;

    if (!is_initialized) {
        hx_drv_scu_get_freq(SCU_CLK_FREQ_TYPE_SB_APB_1_CLK, &freq);
        hx_drv_scu_set_timer_ctrl(TIMER_ID_2, SCU_TIMERCTRL_CPU);
        hx_drv_scu_set_timer_clkdiv(TIMER_ID_2, 0);

#if (TIMER2_CLK_DIV <= 1)
        hx_drv_scu_set_timer_clk_en(TIMER_ID_2, 0);
#elif (TIMER2_CLK_DIV > 1)
        hx_drv_scu_set_timer_clk_en(TIMER_ID_2, 1);
#else
#error "TIMER2_CLK_DIV must > 0"
#endif
        hx_drv_scu_set_timer_clkdiv(TIMER_ID_2, TIMER2_CLK_DIV - 1);

        timer2_reload_value = (freq / TIMER2_CLK_DIV) / 1000; //Interrupt interval is set to 1 ms
        is_initialized = 1;
    }

    HX_TIMER2_DEV_S->VALUE = timer2_reload_value;
    HX_TIMER2_DEV_S->RELOAD = timer2_reload_value;

#if (TIMER2_CLK_DIV <= 1)
    HX_TIMER2_DEV_S->CTRL = (HX_TIMER_CTRL_IRQEN_Msk | 1);
#else
    HX_TIMER2_DEV_S->CTRL = (HX_TIMER_CTRL_SELEXTCLK_Msk | HX_TIMER_CTRL_IRQEN_Msk | 1);
#endif
}

void tfm_plat_test_secure_timer_clear_intr(void)
{
    HX_TIMER2_DEV_S->INTCLEAR = HX_TIMER_INTCLEAR_Msk;
}

void tfm_plat_test_secure_timer_stop(void)
{
    HX_TIMER2_DEV_S->CTRL = 0;
    HX_TIMER2_DEV_S->INTCLEAR = HX_TIMER_INTCLEAR_Msk;
}
