/*
 * Copyright (c) 2021-2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#include "cmsis.h"
#include "target_cfg.h"
#include "tfm_hal_platform.h"
#include "tfm_peripherals_def.h"
#include "uart_stdout.h"
#include "device_definition.h"
#if defined(TEST_NS_FPU) || defined(TEST_S_FPU)
#include "test_interrupt.h"
#endif

//#include "hx_drv_scu.h" //YX 20230202 porting to WE2.

/* Get address of memory regions to configure MPU */
extern const struct memory_region_limits memory_regions;

enum tfm_hal_status_t tfm_hal_platform_init(void)
{
    enum tfm_plat_err_t plat_err = TFM_PLAT_ERR_SYSTEM_ERR;

    plat_err = enable_fault_handlers();
    if (plat_err != TFM_PLAT_ERR_SUCCESS) {
        return TFM_HAL_ERROR_GENERIC;
    }

    plat_err = system_reset_cfg();
    if (plat_err != TFM_PLAT_ERR_SUCCESS) {
        return TFM_HAL_ERROR_GENERIC;
    }

    //plat_err = init_debug();
    //if (plat_err != TFM_PLAT_ERR_SUCCESS) {
    //    return TFM_HAL_ERROR_GENERIC;
    //}

    __enable_irq();

    //(*((volatile unsigned int*) 0x56100010)) = 0x00000002; //XTAL24M //just for EVB testing

    SCU_PAD_PULL_LIST_T pull_cfg;
    hx_drv_scu_get_all_pull_cfg(&pull_cfg);
    pull_cfg.pb0.pull_sel = SCU_PAD_PULL_UP; //PB0_RX0
    pull_cfg.pb0.pull_en = SCU_PAD_PULL_EN; //PB0_RX0
    hx_drv_scu_set_all_pull_cfg(&pull_cfg);

    hx_drv_scu_set_PB0_pinmux(SCU_PB0_PINMUX_UART0_RX_1);
    hx_drv_scu_set_PB1_pinmux(SCU_PB1_PINMUX_UART0_TX_1);

    stdio_init();

    //plat_err = nvic_interrupt_target_state_cfg();
    //if (plat_err != TFM_PLAT_ERR_SUCCESS) {
    //    return TFM_HAL_ERROR_GENERIC;
    //}

    //plat_err = nvic_interrupt_enable();
    //if (plat_err != TFM_PLAT_ERR_SUCCESS) {
    //    return TFM_HAL_ERROR_GENERIC;
    //}

#if defined(TEST_S_FPU) || defined(TEST_NS_FPU)
    /* Set IRQn in secure mode */
    NVIC_ClearTargetState(TFM_FPU_S_TEST_IRQ);
#if 0 //YX 20230111 Removed because vector table is set MPU RO region in LV3. TFM_FPU_S_TEST_Handler is registered startup_an552.c
    /* Register FPU secure test interrupt handler */
    NVIC_SetVector(TFM_FPU_S_TEST_IRQ, (uint32_t)TFM_FPU_S_TEST_Handler);
#endif
    /* Enable FPU secure test interrupt */
    NVIC_EnableIRQ(TFM_FPU_S_TEST_IRQ);
#endif

#if defined(TEST_NS_FPU)
    /* Set IRQn in non-secure mode */
    NVIC_SetTargetState(TFM_FPU_NS_TEST_IRQ);
#endif

    return TFM_HAL_SUCCESS;
}

uint32_t tfm_hal_get_ns_VTOR(void)
{
    return memory_regions.non_secure_code_start;
}

uint32_t tfm_hal_get_ns_MSP(void)
{
    return *((uint32_t *)(memory_regions.non_secure_code_start));
}

uint32_t tfm_hal_get_ns_entry_point(void)
{
    return *((uint32_t *)((memory_regions.non_secure_code_start) + 4));
}
