/*
 * Copyright (c) 2021-2022, Arm Limited. All rights reserved.
 * Copyright (c) 2022 Cypress Semiconductor Corporation (an Infineon
 * company) or an affiliate of Cypress Semiconductor Corporation. All rights
 * reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */

#include <stdint.h>

#include "cmsis.h"
#include "spm_ipc.h"
#include "tfm_hal_interrupt.h"
#include "tfm_peripherals_def.h"
#include "ffm/interrupt.h"
#include "load/interrupt_defs.h"
#include "tfm_plat_test.h"
#include "device_definition.h"

#if 0
static struct irq_t timer0_irq = {0};

void TFM_TIMER0_IRQ_Handler(void)
{
    spm_handle_interrupt(timer0_irq.p_pt, timer0_irq.p_ildi);
}

enum tfm_hal_status_t tfm_timer0_irq_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    timer0_irq.p_ildi = p_ildi;
    timer0_irq.p_pt = p_pt;

    NVIC_SetPriority(TFM_TIMER0_IRQ, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TFM_TIMER0_IRQ);
    NVIC_DisableIRQ(TFM_TIMER0_IRQ);

    return TFM_HAL_SUCCESS;
}

#else
static struct irq_t timer2_irq = {0};

void TFM_TIMER2_IRQ_Handler(void)
{
    spm_handle_interrupt(timer2_irq.p_pt, timer2_irq.p_ildi);
}

enum tfm_hal_status_t tfm_timer2_irq_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    timer2_irq.p_ildi = p_ildi;
    timer2_irq.p_pt = p_pt;

    NVIC_SetPriority(TFM_TIMER2_IRQ, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TFM_TIMER2_IRQ);
    NVIC_DisableIRQ(TFM_TIMER2_IRQ);

    return TFM_HAL_SUCCESS;
}
#endif

////////////
#if 0
static struct irq_t hx_timer0_irq = {0};

enum tfm_hal_status_t timer0int_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_timer0_irq.p_ildi = p_ildi;
    hx_timer0_irq.p_pt = p_pt;

    NVIC_SetPriority(TIMER0INT_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TIMER0INT_IRQn);
    NVIC_DisableIRQ(TIMER0INT_IRQn);

    return TFM_HAL_SUCCESS;
}

void __attribute__((used)) TIMER0_IRQ_Handler() {
    spm_handle_interrupt(hx_timer0_irq.p_pt, hx_timer0_irq.p_ildi);
}
#else
static struct irq_t hx_timer2_irq = {0};

enum tfm_hal_status_t timer2int_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_timer2_irq.p_ildi = p_ildi;
    hx_timer2_irq.p_pt = p_pt;

    NVIC_SetPriority(TIMER2INT_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TIMER2INT_IRQn);
    NVIC_DisableIRQ(TIMER2INT_IRQn);

    return TFM_HAL_SUCCESS;
}

void __attribute__((used)) TIMER2_IRQ_Handler() { //override hx_drv_timer.c TIMER2_IRQ_Handler
    spm_handle_interrupt(hx_timer2_irq.p_pt, hx_timer2_irq.p_ildi);
}

psa_flih_result_t timer2int_irqn_flih() {
    hx_drv_timer_irq_handler(TIMER_ID_2);
    return PSA_FLIH_SIGNAL;    
}
#endif

static struct irq_t hx_timer3_irq = {0};

enum tfm_hal_status_t timer3int_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_timer3_irq.p_ildi = p_ildi;
    hx_timer3_irq.p_pt = p_pt;

    NVIC_SetPriority(TIMER3INT_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TIMER3INT_IRQn);
    NVIC_DisableIRQ(TIMER3INT_IRQn);

    return TFM_HAL_SUCCESS;
}

void __attribute__((used)) TIMER3_IRQ_Handler() { //override hx_drv_timer.c TIMER3_IRQ_Handler
    spm_handle_interrupt(hx_timer3_irq.p_pt, hx_timer3_irq.p_ildi);
}

psa_flih_result_t timer3int_irqn_flih() {
    hx_drv_timer_irq_handler(TIMER_ID_3);
    return PSA_FLIH_SIGNAL;    
}

#if 0
static struct irq_t hx_timer4_irq = {0};

enum tfm_hal_status_t timer4int_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_timer4_irq.p_ildi = p_ildi;
    hx_timer4_irq.p_pt = p_pt;

    NVIC_SetPriority(TIMER4INT_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(TIMER4INT_IRQn);
    NVIC_DisableIRQ(TIMER4INT_IRQn);

    return TFM_HAL_SUCCESS;
}

void __attribute__((used)) TIMER4_IRQ_Handler() {
    spm_handle_interrupt(hx_timer4_irq.p_pt, hx_timer4_irq.p_ildi);
}
#endif

#if defined(TFM_PARTITION_HX_IRQS_DMA1_QSPI)
static struct irq_t hx_dmac1_dmacintr_irq = {0};
DEV_DMAC_PTR dev_dmac = NULL;
extern void dmac_irq_handler(DEV_DMAC *dmac_obj, unsigned int data);

void __attribute__((used)) hx_dmac_1_isr(void *ptr)
{
    if (hx_dmac1_dmacintr_irq.p_pt)
        spm_handle_interrupt(hx_dmac1_dmacintr_irq.p_pt, hx_dmac1_dmacintr_irq.p_ildi);
    else {
        dev_dmac = hx_drv_dmac_get_dev(USE_HX_DMAC_1);
        dmac_irq_handler(dev_dmac, 0);
    }
}

psa_flih_result_t dmac1_dmacintr_irqn_flih(void) {
    dmac_irq_handler(dev_dmac, 0);
    return PSA_FLIH_NO_SIGNAL;  
    //return PSA_FLIH_SIGNAL;
}

enum tfm_hal_status_t dmac1_dmacintr_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    if (!dev_dmac)
        dev_dmac = hx_drv_dmac_get_dev(USE_HX_DMAC_1);

    hx_dmac1_dmacintr_irq.p_ildi = p_ildi;
    hx_dmac1_dmacintr_irq.p_pt = p_pt;

    NVIC_SetPriority(DMAC1_DMACINTR_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(DMAC1_DMACINTR_IRQn);
    NVIC_DisableIRQ(DMAC1_DMACINTR_IRQn);

    return TFM_HAL_SUCCESS;
}

static struct irq_t hx_qspi_ssi_intp_irqn_flih_irq = {0};
extern void dw_spi_isr(DW_SPI_OBJECT spi_obj, void *ptr);
extern DEV_SPI dw_spi_q;
void __attribute__((used)) dw_spi_q_isr(void *ptr) {
    if (hx_qspi_ssi_intp_irqn_flih_irq.p_pt)
        spm_handle_interrupt(hx_qspi_ssi_intp_irqn_flih_irq.p_pt, hx_qspi_ssi_intp_irqn_flih_irq.p_ildi);
    else
        dw_spi_isr(&dw_spi_q, NULL);
}

psa_flih_result_t qspi_ssi_intp_irqn_flih(void)
{
    dw_spi_isr(&dw_spi_q, NULL);
    return PSA_FLIH_NO_SIGNAL;
    //return PSA_FLIH_SIGNAL;
}

enum tfm_hal_status_t qspi_ssi_intp_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_qspi_ssi_intp_irqn_flih_irq.p_ildi = p_ildi;
    hx_qspi_ssi_intp_irqn_flih_irq.p_pt = p_pt;

    NVIC_SetPriority(QSPI_ssi_intp_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(QSPI_ssi_intp_IRQn);
    NVIC_DisableIRQ(QSPI_ssi_intp_IRQn);

    return TFM_HAL_SUCCESS;
}
#endif

#if 0
static struct irq_t hx_ospi_irqn_flih_irq = {0};

//void dw_spi_o_isr(void *ptr)
//{
//    spm_handle_interrupt(hx_ospi_irqn_flih_irq.p_pt, hx_ospi_irqn_flih_irq.p_ildi);
//}

enum tfm_hal_status_t ospi_irqn_init(void *p_pt,
                                          const struct irq_load_info_t *p_ildi)
{
    hx_ospi_irqn_flih_irq.p_ildi = p_ildi;
    hx_ospi_irqn_flih_irq.p_pt = p_pt;

    NVIC_SetPriority(OSPI_IRQn, DEFAULT_IRQ_PRIORITY);
    NVIC_ClearTargetState(OSPI_IRQn);
    NVIC_DisableIRQ(OSPI_IRQn);

    return TFM_HAL_SUCCESS;
}
#endif
///////////

#include "exception_info.h"
#include "hx_drv_scu.h"
#include "hx_drv_mpc.h"
#include "hx_drv_ppc.h"

void __attribute__((used)) platform_exception_post_handler(uint32_t event)
{
    /* Print fault message and block execution */
    //[b3-b0] 0: ppc, 1:msc; 2:mpc
    switch ((0x0F&event))
    {
    case 0:
        SPMLOG_ERRMSGVAL("PPC fault: ", event);
        break;
    case 1:
        SPMLOG_ERRMSGVAL("MSC fault: ", event);
        break;
    case 2:
        SPMLOG_ERRMSGVAL("MPC fault: ", event);
        break;
    default:
        SPMLOG_ERRMSGVAL("Unknown fault: ", event);
        break;
    }

    tfm_core_panic();

    __ASM volatile("B         .                       \n");
}

void __attribute__((used)) PPC_DWC_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_ahb3_irq_handler();
    platform_exception_post_handler(0x00 << 4 | 0x00);
}

void __attribute__((used)) PPC_ISP_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_isp_irq_handler();
    platform_exception_post_handler(0x01 << 4 | 0x00);
}

void __attribute__((used)) PPC_AHB3_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_ahb3_irq_handler();
    platform_exception_post_handler(0x03 << 4 | 0x00);
}

void __attribute__((used)) PPC_AHB1M4_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_ahb1m4_irq_handler();
    platform_exception_post_handler(0x04 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB0NS_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_ahb0ns_irq_handler();
    platform_exception_post_handler(0x05 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB0PS_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_apb0ps_irq_handler();
    platform_exception_post_handler(0x06 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB1NS_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_apb1ns_irq_handler();
    platform_exception_post_handler(0x07 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB1PS_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_apb1ps_irq_handler();
    platform_exception_post_handler(0x08 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB2_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_apb2_irq_handler();
    platform_exception_post_handler(0x09 << 4 | 0x00);
}

void __attribute__((used)) PPC_BOOTROM_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_bootrom_irq_handler();
    platform_exception_post_handler(0x09 << 4 | 0x00);
}

void __attribute__((used)) PPC_APB1_AON_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_ppc_apb_aon_irq_handler();
    platform_exception_post_handler(0x0A << 4 | 0x00);
}

void __attribute__((used)) MSC_U55M0_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_u55m0_irq_handler();
    platform_exception_post_handler(0x00 << 4 | 0x01);
}

void __attribute__((used)) MSC_U55M1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_u55m1_irq_handler();
    platform_exception_post_handler(0x01 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA0_IRQ_Handler(void)  {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma0_irq_handler();
    platform_exception_post_handler(0x02 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma1_irq_handler();
    platform_exception_post_handler(0x03 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA2M1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma2m1_irq_handler();
    platform_exception_post_handler(0x04 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA2M2_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma2m2_irq_handler();
    platform_exception_post_handler(0x05 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA3M1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma3m1_irq_handler();
    platform_exception_post_handler(0x06 << 4 | 0x01);
}

void __attribute__((used)) MSC_DMA3M2_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dma3m2_irq_handler();
    platform_exception_post_handler(0x07 << 4 | 0x01);
}

void __attribute__((used)) MSC_DPDMA_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_dpdma_irq_handler();
    platform_exception_post_handler(0x08 << 4 | 0x01);
}

void __attribute__((used)) MSC_I3CH_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_i3ch_irq_handler();
    platform_exception_post_handler(0x09 << 4 | 0x01);
}

void __attribute__((used)) MSC_SDIO_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_scu_msc_sdio_irq_handler();
    platform_exception_post_handler(0x0A << 4 | 0x01);
}

void __attribute__((used)) MPC_SRAM0_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_mpc_sram0_irq_handler();
    platform_exception_post_handler(0x00 << 4 | 0x02);
}

void __attribute__((used)) MPC_SRAM1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_mpc_sram1_irq_handler();
    platform_exception_post_handler(0x01 << 4 | 0x02);
}

void __attribute__((used)) MPC_SRAM2_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_mpc_sram2_irq_handler();
    platform_exception_post_handler(0x02 << 4 | 0x02);
}

void __attribute__((used)) MPC_FLASH1_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_mpc_flash1_irq_handler();
    platform_exception_post_handler(0x03 << 4 | 0x02);
}

void __attribute__((used)) MPC_FLASH2_IRQ_Handler(void) {
    EXCEPTION_INFO(EXCEPTION_TYPE_PLATFORM);
    hx_drv_mpc_flash2_irq_handler();
    platform_exception_post_handler(0x04 << 4 | 0x02);
}
