/*
 * Copyright (c) 2022 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * This file is derivative of CMSIS V5.9.0 startup_ARMCM55.c
 * Git SHA: 2b7495b8535bdcb306dac29b9ded4cfb679d7e5c
 */

// NS linker scripts using the default CMSIS style naming conventions, while the
// secure and bl2 linker scripts remain untouched (region.h compatibility).
// To be compatible with the untouched files (which using ARMCLANG naming style),
// we have to override __INITIAL_SP and __STACK_LIMIT labels.
//
//set(CMSIS_OVERRIDE_HEADER "${CMAKE_CURRENT_LIST_DIR}/include/cmsis_override.h")
//add_library(cmsis_stack_override INTERFACE)
//target_compile_options(cmsis_stack_override
//    INTERFACE
//        "$<$<C_COMPILER_ID:GNU>:SHELL:-include ${CMSIS_OVERRIDE_HEADER}>"
//        "$<$<C_COMPILER_ID:IAR>:SHELL:--preinclude ${CMSIS_OVERRIDE_HEADER}>"
//)
#if !defined(BUILD_TFM_NS) //YX 20240116
#include "cmsis_override.h" //YX 20240116
#endif

#include "cmsis.h"

/*----------------------------------------------------------------------------
  External References
 *----------------------------------------------------------------------------*/
extern uint32_t __INITIAL_SP;
extern uint32_t __STACK_LIMIT;
#if defined (__ARM_FEATURE_CMSE) && (__ARM_FEATURE_CMSE == 3U)
extern uint64_t __STACK_SEAL;
#endif

#if defined (__cplusplus)
extern "C" {
extern void __PROGRAM_START(void) __NO_RETURN;

//*****************************************************************************
//
// The entry point for the C++ library startup
//
//*****************************************************************************
extern void __libc_init_array(void);
}
#endif

#if defined (__cplusplus)
extern "C" {
#endif
/*----------------------------------------------------------------------------
  Internal References
 *----------------------------------------------------------------------------*/
void Reset_Handler  (void) __NO_RETURN;

/*----------------------------------------------------------------------------
  Exception / Interrupt Handler
 *----------------------------------------------------------------------------*/
#define DEFAULT_IRQ_HANDLER(handler_name)  \
void __WEAK handler_name(void) __NO_RETURN; \
void handler_name(void) { \
    while(1); \
}

/* Exceptions */
DEFAULT_IRQ_HANDLER(NMI_Handler)
DEFAULT_IRQ_HANDLER(HardFault_Handler)
DEFAULT_IRQ_HANDLER(MemManage_Handler)
DEFAULT_IRQ_HANDLER(BusFault_Handler)
DEFAULT_IRQ_HANDLER(UsageFault_Handler)
DEFAULT_IRQ_HANDLER(SecureFault_Handler)
DEFAULT_IRQ_HANDLER(SVC_Handler)
DEFAULT_IRQ_HANDLER(DebugMon_Handler)
DEFAULT_IRQ_HANDLER(PendSV_Handler)
DEFAULT_IRQ_HANDLER(SysTick_Handler)

DEFAULT_IRQ_HANDLER(Interrupt0_Handler)
DEFAULT_IRQ_HANDLER(Interrupt1_Handler)
DEFAULT_IRQ_HANDLER(Interrupt2_Handler)
DEFAULT_IRQ_HANDLER(Interrupt3_Handler)
DEFAULT_IRQ_HANDLER(Interrupt4_Handler)
DEFAULT_IRQ_HANDLER(Interrupt5_Handler)
DEFAULT_IRQ_HANDLER(Interrupt6_Handler)
DEFAULT_IRQ_HANDLER(Interrupt7_Handler)
DEFAULT_IRQ_HANDLER(TFM_FPU_S_TEST_Handler)
DEFAULT_IRQ_HANDLER(TFM_FPU_NS_TEST_Handler)
DEFAULT_IRQ_HANDLER(Interrupt10_Handler)
DEFAULT_IRQ_HANDLER(Interrupt11_Handler)
DEFAULT_IRQ_HANDLER(Interrupt12_Handler)
DEFAULT_IRQ_HANDLER(Interrupt13_Handler)
DEFAULT_IRQ_HANDLER(Interrupt14_Handler)
DEFAULT_IRQ_HANDLER(Interrupt15_Handler)
DEFAULT_IRQ_HANDLER(Interrupt16_Handler)
DEFAULT_IRQ_HANDLER(Interrupt17_Handler)
DEFAULT_IRQ_HANDLER(Interrupt18_Handler)
DEFAULT_IRQ_HANDLER(Interrupt19_Handler)
DEFAULT_IRQ_HANDLER(Interrupt20_Handler)
DEFAULT_IRQ_HANDLER(Interrupt21_Handler)
DEFAULT_IRQ_HANDLER(Interrupt22_Handler)
DEFAULT_IRQ_HANDLER(Interrupt23_Handler)
DEFAULT_IRQ_HANDLER(Interrupt24_Handler)
DEFAULT_IRQ_HANDLER(Interrupt25_Handler)
DEFAULT_IRQ_HANDLER(Interrupt26_Handler)
DEFAULT_IRQ_HANDLER(Interrupt27_Handler)
DEFAULT_IRQ_HANDLER(Interrupt28_Handler)
DEFAULT_IRQ_HANDLER(Interrupt29_Handler)
DEFAULT_IRQ_HANDLER(Interrupt30_Handler)
DEFAULT_IRQ_HANDLER(Interrupt31_Handler)
DEFAULT_IRQ_HANDLER(Interrupt32_Handler)
DEFAULT_IRQ_HANDLER(Interrupt33_Handler)
DEFAULT_IRQ_HANDLER(TFM_TIMER0_IRQ_Handler)
DEFAULT_IRQ_HANDLER(Interrupt35_Handler)
DEFAULT_IRQ_HANDLER(TFM_TIMER2_IRQ_Handler)

#if defined (__cplusplus)
} // extern "C"
#endif

/*----------------------------------------------------------------------------
  Exception / Interrupt Vector table
 *----------------------------------------------------------------------------*/

#if defined ( __GNUC__ )
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wpedantic"
#endif

extern const VECTOR_TABLE_Type __VECTOR_TABLE[496];
const VECTOR_TABLE_Type __VECTOR_TABLE[496] __VECTOR_TABLE_ATTRIBUTE = {
	(VECTOR_TABLE_Type)(&__INITIAL_SP), /*     Initial Stack Pointer */
	Reset_Handler, /*     Reset Handler */
	NMI_Handler, /* -14 NMI Handler */
	HardFault_Handler, /* -13 Hard Fault Handler */
	MemManage_Handler, /* -12 MPU Fault Handler */
	BusFault_Handler, /* -11 Bus Fault Handler */
	UsageFault_Handler, /* -10 Usage Fault Handler */
	SecureFault_Handler, /*  -9 Secure Fault Handler */
	0, /*     Reserved */
	0, /*     Reserved */
	0, /*     Reserved */
	SVC_Handler, /*  -5 SVCall Handler */
	DebugMon_Handler, /*  -4 Debug Monitor Handler */
	0, /*     Reserved */
	PendSV_Handler, /*  -2 PendSV Handler */
	SysTick_Handler, /*  -1 SysTick Handler */

	/* Interrupts */
	Interrupt0_Handler, /*   0 Interrupt */
	Interrupt1_Handler, /*   1 Interrupt */
	Interrupt2_Handler, /*   2 Interrupt */
	Interrupt3_Handler, /*   3 Interrupt */
	Interrupt4_Handler, /*   4 Interrupt */
	Interrupt5_Handler, /*   5 Interrupt */
	Interrupt6_Handler, /*   6 Interrupt */
	Interrupt7_Handler, /*   7 Interrupt */
	TFM_FPU_S_TEST_Handler,  /*   8 FPIXC_IRQn */
	TFM_FPU_NS_TEST_Handler,  /*   9 FPIDC_IRQn */
	Interrupt10_Handler, /*   10 Interrupt */
	Interrupt11_Handler, /*   11 Interrupt */
	Interrupt12_Handler, /*   12 Interrupt */
	Interrupt13_Handler, /*   13 Interrupt */
	Interrupt14_Handler, /*   14 Interrupt */
	Interrupt15_Handler, /*   15 Interrupt */
	Interrupt16_Handler, /*   16 Interrupt */
	Interrupt17_Handler, /*   17 Interrupt */
	Interrupt18_Handler, /*   18 Interrupt */
	Interrupt19_Handler, /*   19 Interrupt */
	Interrupt20_Handler, /*   20 Interrupt */
	Interrupt21_Handler, /*   21 Interrupt */
	Interrupt22_Handler, /*   22 Interrupt */
	Interrupt23_Handler, /*   23 Interrupt */
	Interrupt24_Handler, /*   24 Interrupt */
	Interrupt25_Handler, /*   25 Interrupt */
	Interrupt26_Handler, /*   26 Interrupt */
	Interrupt27_Handler, /*   27 Interrupt */
	Interrupt28_Handler, /*   28 Interrupt */
	Interrupt29_Handler, /*   29 Interrupt */
	Interrupt30_Handler, /*   30 Interrupt */
	Interrupt31_Handler, /*   31 Interrupt */
	Interrupt32_Handler, /*   32 Interrupt */
	Interrupt33_Handler, /*   33 Interrupt */
	TFM_TIMER0_IRQ_Handler, /*   34 Interrupt */ //    	TIMER0INT_IRQn = 34
	Interrupt35_Handler,    /*   35 Interrupt */
	TFM_TIMER2_IRQ_Handler  /*   36 Interrupt */ //    	TIMER2INT_IRQn = 36
	/* Interrupts 35 .. 480 are left out */
};

#if defined ( __GNUC__ )
#pragma GCC diagnostic pop
#endif

/*----------------------------------------------------------------------------
  Reset Handler called on controller reset
 *---------------------------------------- ------------------------------------*/
void Reset_Handler(void)
{
#if defined (__ARM_FEATURE_CMSE) && (__ARM_FEATURE_CMSE == 3U)
    __disable_irq();
#endif

    __set_MSP((uint32_t)(&__INITIAL_SP)); //YX 20230112 confirm MSP
    __set_PSP((uint32_t)(&__INITIAL_SP));

    __set_MSPLIM((uint32_t)(&__STACK_LIMIT));
    __set_PSPLIM((uint32_t)(&__STACK_LIMIT));

    SystemInit();                             /* CMSIS System Initialization */

#if 1 //YX 20230315 porting to WE2
#if defined (__clang__)
#elif defined ( __GNUC__ )
#if defined (__cplusplus)
    //
    // Call C++ library initialisation
    //
    __libc_init_array();
#endif
#endif
    SCB_DisableICache();
    SCB_DisableDCache();
    SCB_EnableICache();
    SCB_EnableDCache();
    //hx_enable_ICache(0);
    //hx_enable_DCache(0);
    //hx_enable_ICache(1);
    //hx_enable_DCache(1);
#endif

#if defined (__ARM_FEATURE_CMSE) && (__ARM_FEATURE_CMSE == 3U)
    __TZ_set_STACKSEAL_S((uint32_t *)(&__STACK_SEAL));
#endif

    __PROGRAM_START();                        /* Enter PreMain (C library entry point) */
}
