#include "pmu_audpre_cm55m_timer2_sample.h"


#include "xprintf.h"
#include "hx_drv_scu.h"
#include "hx_drv_swreg_aon.h"

#include "hx_drv_scu_export.h"
#include "hx_drv_scu.h"
#include "hx_drv_swreg_aon.h"
#include "powermode.h"
#ifdef IP_rtc
#include "hx_drv_rtc.h"
#endif
#include "hxmb.h"


#define DBG_APP_SIM_LOG             (1)
//#define DUMP_BOOT_CNTS

#if DBG_APP_SIM_LOG
    #define dbg_app_log(fmt, ...)       xprintf(fmt, ##__VA_ARGS__)
#else
    #define dbg_app_log(fmt, ...)
#endif


TIMER_ID_E g_wakeuptimerid = TIMER_ID_2;

static volatile uint32_t g_cm55s_ready = 2;

#define MAX_STRING  100



static char wakeup_event[][MAX_STRING]={
	{"[0]: PS_DPD : wakeup by (ext_force_pmu_dc_sync)"},
	{"[1]: PS_DPD wakeup by (RTC_timer_int)"},
	{"[2]: PS_DPD wakeup by (anti_tamp_int)"},
	{"[3]: PS_PD wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[4]: PS_PD wakeup by (ext_int_nxt_dc)"},
	{"[5]: PS_PD wakeup by (RTC_timer_int)"},
	{"[6]: PS_PD wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[7]: PS_PD wakeup by (CMP_int)"},
	{"[8]: PS_PD wakeup by (TS_int)"},
	{"[9]: PS_PD wakeup by (I2C_W_int)"},
	{"[10]: PS_PD wakeup by (REG_CPU_SCENARIO == 4'b0010 && SB_timer_int[0])"},
	{"[11]: PS_SCL wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[12]: PS_SCL wakeup by (~pmu_sc_active && Sensor_EXT_INT)"},
	{"[13]: PS_SCL wakeup by (ext_int_nxt_dc)"},
	{"[14]: PS_SCL wakeup by (RTC_timer_int)"},
	{"[15]: PS_SCL wakeup by (SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[16]: PS_SCL wakeup by (ADCC_int)"},
	{"[17]: PS_SCL wakeup by (TS_int)"},
	{"[18]: PS_SCL wakeup by (I2C_W_int)"},
	{"[19]: PS_SCL wakeup by (pmu_wdg_timeout_int)"},
	{"[20]: PS_SCH wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[21]: PS_SCH wakeup by (ext_int_nxt_dc)"},
	{"[22]: PS_SCH wakeup by (RTC_timer_int)"},
	{"[23]: PS_SCH wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[24]: PS_SCH wakeup by (ADCC_int)"},
	{"[25]: PS_SCH wakeup by (TS_int)"},
	{"[26]: PS_SCH wakeup by (I2C_W_int)"},
	{"[27]: PS_SCH wakeup by (pmu_wdg_timeout_int)"},
	{"[28]: PS_SCH wakeup by (WRDMAx_abnormal_int)"},
	{"[29]: PS_SCH wakeup by (DP_ABNORMAL_INT)"},
	{"[30]: PS_SCH wakeup VID Only by (DP_CDM_MOTION_INT)"},
	{"[31]: PS_SCH wakeup VIDAUD by (DP_CDM_MOTION_INT)"},
};

static char wakeup_event1[][MAX_STRING]={
	{"[0]: PS_DPD wakeup by (~pmu_sc_active &&PAD_AON_GPIO_0)"},
	{"[1]: PS_DPD wakeup by (~pmu_sc_active &&PAD_VMUTE)"},
	{"[2]: PS_DPD wakeup by (~pmu_sc_active && ext_int_nxt_dc)"},
	{"[8]: PS_PD wakeup by (anti_tamp_int)"},
	{"[16]: PS_SCL wakeup by (anti_tamp_int)"},
	{"[24]: PS_SCH wakeup by (SC_sen_noack)"},
	{"[25]: PS_SCH wakeup by (anti_tamp_int)"}
};

void CM55M_MB_CB(uint32_t event)
{
	uint32_t irq_status;
	hx_drv_mb_get_cm55m_irq_status(&irq_status);
	dbg_app_log("CM55M irq_status=0x%x\n", irq_status);

	g_cm55s_ready = 1;
	dbg_app_log("irq_status=0x%x\n", irq_status);
	hx_drv_mb_clear_cm55m_irq(irq_status);

	hx_drv_mb_get_cm55m_irq_status(&irq_status);
	dbg_app_log("after clear in ISR get CM55M irq_status=0x%x\n", irq_status);
}

static void print_wakeup_event(uint32_t event, uint32_t event1)
{

	if((event & 0x1)  != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[0]);
	}
	if((event & 0x2) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[1]);
	}
	if((event & 0x4) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[2]);
	}
	if((event & 0x8) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[3]);
	}
	if((event & 0x10) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[4]);
	}
	if((event & 0x20) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[5]);
	}
	if((event & 0x40) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[6]);
	}
	if((event & 0x80) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[7]);
	}
	if((event & 0x100) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[8]);
	}
	if((event & 0x200) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[9]);
	}
	if((event & 0x400) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[10]);
	}
	if((event & 0x800) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[11]);
	}
	if((event & 0x1000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[12]);
	}
	if((event & 0x2000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[13]);
	}
	if((event & 0x4000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[14]);
	}
	if((event & 0x8000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[15]);
	}
	if((event & 0x10000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[16]);
	}
	if((event & 0x20000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[17]);
	}
	if((event & 0x40000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[18]);
	}
	if((event & 0x80000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[19]);
	}
	if((event & 0x100000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[20]);
	}
	if((event & 0x200000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[21]);
	}
	if((event & 0x400000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[22]);
	}
	if((event & 0x800000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[23]);
	}
	if((event & 0x1000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[24]);
	}
	if((event & 0x2000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[25]);
	}
	if((event & 0x4000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[26]);
	}
	if((event & 0x8000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[27]);
	}
	if((event & 0x10000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[28]);
	}
	if((event & 0x20000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[29]);
	}
	if((event & 0x40000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[30]);
	}
	if((event & 0x80000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[31]);
	}
	if((event1 & 0x1)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[0]);
	}
	if((event1 & 0x2)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[1]);
	}
	if((event1 & 0x4)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[2]);
	}
	if((event1 & 0x100)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[3]);
	}
	if((event1 & 0x10000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[4]);
	}
	if((event1 & 0x1000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[5]);
	}
	if((event1 & 0x2000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[6]);
	}
}

void getPMUExtIntStatus()
{
	uint8_t status;
	hx_lib_pm_ext_int_get(PMU_EXT_INT_TYPE_PA0_GPIO_DPD, &status);
	dbg_app_log("PAD_PA0 intstatus=0x%x\n", status);
}

void get_wakeup_ip_int()
{
	uint32_t status;

#ifdef IP_rtc
#if defined(IP_INST_RTC0) || defined(IP_INST_NS_RTC0)
		hx_drv_rtc_get_alarm_rawint_status(RTC_ID_0, &status);
		dbg_app_log("RTC0 raw status=%d\n", status);
		hx_drv_rtc_get_alarm_maskint_status(RTC_ID_0, &status);
		dbg_app_log("RTC0 mask status=%d\n", status);
#endif
#if defined(IP_INST_RTC1) || defined(IP_INST_NS_RTC1)
		hx_drv_rtc_get_alarm_rawint_status(RTC_ID_1, &status);
		dbg_app_log("RTC1 raw status=%d\n", status);
		hx_drv_rtc_get_alarm_maskint_status(RTC_ID_1, &status);
		dbg_app_log("RTC1 mask status=%d\n", status);
#endif
#if defined(IP_INST_RTC2) || defined(IP_INST_NS_RTC2)
		hx_drv_rtc_get_alarm_rawint_status(RTC_ID_2, &status);
		dbg_app_log("RTC2 raw status=%d\n", status);
		hx_drv_rtc_get_alarm_maskint_status(RTC_ID_2, &status);
		dbg_app_log("RTC2 mask status=%d\n", status);
#endif
#endif

#ifdef IP_timer
#if defined(IP_INST_TIMER0) || defined(IP_INST_NS_TIMER0)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_0);
		dbg_app_log("Timer0 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER1) || defined(IP_INST_NS_TIMER1)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_1);
		dbg_app_log("Timer1 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER2) || defined(IP_INST_NS_TIMER2)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_2);
		dbg_app_log("Timer2 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER3) || defined(IP_INST_NS_TIMER3)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_3);
		dbg_app_log("Timer3 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER4) || defined(IP_INST_NS_TIMER4)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_4);
		dbg_app_log("Timer4 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER5) || defined(IP_INST_NS_TIMER5)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_5);
		dbg_app_log("Timer5 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER6) || defined(IP_INST_NS_TIMER6)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_6);
		dbg_app_log("Timer6 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER7) || defined(IP_INST_NS_TIMER7)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_7);
		dbg_app_log("Timer7 raw status=%d\n",  status);
#endif
#if defined(IP_INST_TIMER8) || defined(IP_INST_NS_TIMER8)
		status = hx_drv_timer_StatusIRQ(TIMER_ID_8);
		dbg_app_log("Timer8 raw status=%d\n",  status);
#endif
#endif

#ifdef IP_gpio
#if defined(IP_INST_AON_GPIO) || defined(IP_INST_NS_AON_GPIO)
    status = hx_drv_gpio_get_int_status(AON_GPIO0);
    dbg_app_log("AON GPIO_0, int_status:%d \n", status);
#endif
#if defined(IP_INST_SB_GPIO) || defined(IP_INST_NS_SB_GPIO)
    status = hx_drv_gpio_get_int_status(SB_GPIO0);
    dbg_app_log("SB GPIO_0, int_status:%d \n", status);
#endif
#endif

#ifdef IP_hxautoi2c_mst
	uint32_t autoi2c_rawstatus = 0;
	autoi2c_rawstatus = hx_drv_hxautoi2c_get_rawstatus();
    dbg_app_log("autoi2c_rawstatus:0x%x \n", autoi2c_rawstatus);
#endif
}

void clear_all_wakeupip_int()
{
#ifdef IP_rtc
#if defined(IP_INST_RTC0) || defined(IP_INST_NS_RTC0)
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_0);
#endif
#if defined(IP_INST_RTC1) || defined(IP_INST_NS_RTC1)
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_1);
#endif
#if defined(IP_INST_RTC2) || defined(IP_INST_NS_RTC2)
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_2);
#endif
#endif
#ifdef IP_timer
#if defined(IP_INST_TIMER0) || defined(IP_INST_NS_TIMER0)
	hx_drv_timer_ClearIRQ(TIMER_ID_0);
#endif
#if defined(IP_INST_TIMER1) || defined(IP_INST_NS_TIMER1)
	hx_drv_timer_ClearIRQ(TIMER_ID_1);
#endif
#if defined(IP_INST_TIMER2) || defined(IP_INST_NS_TIMER2)
	hx_drv_timer_ClearIRQ(TIMER_ID_2);
#endif
#if defined(IP_INST_TIMER3) || defined(IP_INST_NS_TIMER3)
	hx_drv_timer_ClearIRQ(TIMER_ID_3);
#endif
#if defined(IP_INST_TIMER4) || defined(IP_INST_NS_TIMER4)
	hx_drv_timer_ClearIRQ(TIMER_ID_4);
#endif
#if defined(IP_INST_TIMER5) || defined(IP_INST_NS_TIMER5)
	hx_drv_timer_ClearIRQ(TIMER_ID_5);
#endif
#if defined(IP_INST_TIMER6) || defined(IP_INST_NS_TIMER6)
	hx_drv_timer_ClearIRQ(TIMER_ID_6);
#endif
#if defined(IP_INST_TIMER7) || defined(IP_INST_NS_TIMER7)
	hx_drv_timer_ClearIRQ(TIMER_ID_7);
#endif
#if defined(IP_INST_TIMER8) || defined(IP_INST_NS_TIMER8)
	hx_drv_timer_ClearIRQ(TIMER_ID_8);
#endif
#endif
#ifdef IP_gpio
#if defined(IP_INST_AON_GPIO) || defined(IP_INST_NS_AON_GPIO)
	hx_drv_gpio_clr_int_status(AON_GPIO0);
	hx_drv_gpio_clr_int_status(AON_GPIO1);
#endif
#if defined(IP_INST_SB_GPIO) || defined(IP_INST_NS_SB_GPIO)
	hx_drv_gpio_clr_int_status(SB_GPIO0);
	hx_drv_gpio_clr_int_status(SB_GPIO1);
#endif
#endif
#ifdef IP_hxautoi2c_mst
	hx_drv_hxautoi2c_clr_noack_int(HXAUTOI2CHC_INTSTATUS_DATA_NO_ACK);
	hx_drv_hxautoi2c_clr_noack_int(HXAUTOI2CHC_INTSTATUS_ADDR_NO_ACK);
#endif
}

void setTimer2AlarmPMU() {
//
	TIMER_ID_E id;
	TIMER_ERROR_E ret;
	TIMER_CFG_T timer_cfg;

	timer_cfg.period = 2000;

	timer_cfg.mode = TIMER_MODE_ONESHOT;
	timer_cfg.ctrl = TIMER_CTRL_PMU;
	timer_cfg.state = TIMER_STATE_PMU;
	id = TIMER_ID_2;

	ret = hx_drv_timer_hw_start(g_wakeuptimerid, &timer_cfg, NULL);

}


void SetPSSCLAudonly()
{
	PM_PD_AUDPRE_CFG_T cfg;
	uint32_t freq;
	SCU_LSC_CLK_CFG_T lsc_cfg;
	SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;
	PM_CFG_PWR_MODE_E mode;
	SCU_PLL_FREQ_E pmuwakeup_pll_freq;
	SCU_HSCCLKDIV_E pmuwakeup_cm55m_div;
	SCU_LSCCLKDIV_E pmuwakeup_cm55s_div;
	SCU_PLL_CLK_CFG_T pll_cfg;

	/*Get System Current Clock*/
	hx_drv_swreg_aon_get_pmuwakeup_freq(&pmuwakeup_pll_freq, &pmuwakeup_cm55m_div, &pmuwakeup_cm55s_div);
	hx_drv_swreg_aon_get_pllfreq(&freq);
	dbg_app_log("pmuwakeup_freq_type=%d, pmuwakeup_cm55m_div=%d, pmuwakeup_cm55s_div=%d\n", pmuwakeup_pll_freq, pmuwakeup_cm55m_div, pmuwakeup_cm55s_div);
	dbg_app_log("pmuwakeup_run_freq=%d\n", freq);


	mode = PM_MODE_PS_AUD_ONLY_PREROLLING;
	hx_lib_pm_get_defcfg_bymode(&cfg, mode);
	/*Setup bootrom clock speed when PMU Warm boot wakeup*/
	cfg.bootromspeed.bootromclkfreq = pmuwakeup_pll_freq;
	cfg.bootromspeed.pll_freq = freq;
	cfg.bootromspeed.cm55m_div = pmuwakeup_cm55m_div;
	cfg.bootromspeed.cm55s_div = pmuwakeup_cm55s_div;

#ifdef SUPPORT_CM55S_RESET
	cfg.cm55s_reset = SWREG_AON_PMUWAKE_CM55S_RERESET_YES;
#else
	cfg.cm55s_reset = SWREG_AON_PMUWAKE_CM55S_RERESET_NO;
#endif
	cfg.pmu_pad_pa01_mask = PM_IP_INT_MASK_ALL_UNMASK;
	cfg.pmu_rtc_mask = PM_RTC_INT_MASK_ALLUNMASK;
	cfg.pmu_pad_pa23_mask = PM_IP_INT_MASK_ALL_UNMASK;			/**< PMU SB GPIO Interrupt Mask **/
	cfg.pmu_i2cw_mask = PM_IP_INT_MASK;			/**< PMU I2C Wakeup Interrupt Mask **/
	cfg.pmu_timer_mask = 0x1FB;			/**< PMU Timer0~5 Wakeup Interrupt Mask  **/
	cfg.pmu_cmp_mask = PM_IP_INT_MASK;			/**< PMU CMP Wakeup Interrupt Mask  **/
	cfg.pmu_ts_mask = PM_IP_INT_MASK;			/**< PMU TS Wakeup Interrupt Mask  **/
	cfg.pmu_anti_mask = PM_IP_INT_MASK;
	cfg.pmu_senint_mask = PM_IP_INT_MASK;		/**< PMU SENSOR Interrupt Mask **/
	cfg.support_debugdump = 0;

	cfg.tcm_retention = PM_MEM_RET_YES;			/**< CM55M TCM Retention**/
	cfg.hscsram_retention[0] = PM_MEM_RET_YES;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[1] = PM_MEM_RET_YES;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[2] = PM_MEM_RET_YES;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[3] = PM_MEM_RET_YES;	/**< HSC SRAM Retention**/
	cfg.lscsram_retention = PM_MEM_RET_YES;		/**< LSC SRAM Retention**/
	cfg.skip_bootflow.sec_mem_flag = SWREG_AON_RETENTION;			/**< Skip Boot Flow**/
	cfg.skip_bootflow.first_bl_flag = SWREG_AON_RETENTION; /*!< First BL Retention */
	cfg.skip_bootflow.cm55m_s_app_flag = SWREG_AON_RETENTION; /*!< cm55m_s_app Retention */
	cfg.skip_bootflow.cm55m_ns_app_flag = SWREG_AON_RETENTION; /*!< cm55m_ns_app Retention */
	cfg.skip_bootflow.cm55s_s_app_flag = SWREG_AON_RETENTION; /*!< cm55s_s_app Retention */
	cfg.skip_bootflow.cm55s_ns_app_flag = SWREG_AON_RETENTION; /*!< cm55s_ns_app Retention */
	cfg.skip_bootflow.cm55m_model_flag = SWREG_AON_RETENTION; /*!< cm55m model Retention */
	cfg.skip_bootflow.cm55s_model_flag = SWREG_AON_RETENTION; /*!< cm55s model Retention */
	cfg.skip_bootflow.cm55m_appcfg_flag = SWREG_AON_RETENTION; /*!< cm55m appcfg Retention */
	cfg.skip_bootflow.cm55s_appcfg_flag = SWREG_AON_RETENTION; /*!< cm55s appcfg Retention */
	cfg.skip_bootflow.cm55m_s_app_rwdata_flag = SWREG_AON_NO_RETENTION;/*!< cm55m_s_app RW Data Retention */
	cfg.skip_bootflow.cm55m_ns_app_rwdata_flag = SWREG_AON_NO_RETENTION;/*!< cm55m_ns_app RW Data Retention */
#ifdef SUPPORT_CM55S_RESET
	cfg.skip_bootflow.cm55s_s_app_rwdata_flag = SWREG_AON_NO_RETENTION;/*!< cm55s_s_app RW Data Retention */
	cfg.skip_bootflow.cm55s_ns_app_rwdata_flag = SWREG_AON_NO_RETENTION;/*!< cm55s_ns_app RW Data Retention */
#else
	cfg.skip_bootflow.cm55s_s_app_rwdata_flag = SWREG_AON_RETENTION;/*!< cm55s_s_app RW Data Retention */
	cfg.skip_bootflow.cm55s_ns_app_rwdata_flag = SWREG_AON_RETENTION;/*!< cm55s_ns_app RW Data Retention */
#endif
	cfg.skip_bootflow.secure_debug_flag = SWREG_AON_RETENTION;
	cfg.pmu_dcdc_outpin = PM_CFG_DCDC_MODE_OFF;

	hx_lib_pm_cfg_set(&cfg, NULL, mode);

	setTimer2AlarmPMU();

	/*Use PMU lib to control HSC_CLK and LSC_CLK so set thoes parameter to 0*/
	memset(&hsc_cfg, 0, sizeof(SCU_PDHSC_HSCCLK_CFG_T));
	memset(&lsc_cfg, 0, sizeof(SCU_LSC_CLK_CFG_T));
	/*Trigger to PMU mode*/
	hx_lib_pm_trigger(hsc_cfg, lsc_cfg, PM_CLK_PARA_CTRL_BYPMLIB);

}

/*******************************************************************************
 * Code
 ******************************************************************************/
/*!
 * @brief Main function
 */
int pmu_audpre_cm55m_timer2_app(void) {

	uint32_t wakeup_event, wakeup_event1;
#ifdef DUMP_BOOT_CNTS
	uint32_t val = 0;
#endif
	dbg_app_log("PMU Audio Only Timer2 Wakeup Sample Code\r\n");
	/*Get PMU Wakeup Event*/
	hx_lib_pm_get_event(&wakeup_event, &wakeup_event1);
    dbg_app_log("WakeupEvt=0x%x\n", wakeup_event);
    dbg_app_log("WakeupEvt1=0x%x\n", wakeup_event1);
    print_wakeup_event(wakeup_event, wakeup_event1);

	if((wakeup_event == PMU_WAKEUP_NONE) && (wakeup_event1 == PMU_WAKEUPEVENT1_NONE))
	{
#ifdef DUMP_BOOT_CNTS
		val = hx_get_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C);
		val++;
	    hx_set_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C, val);
		dbg_app_log("boot cnt= %d\r\n", val);
#endif
		/*Get wakeup related IP Interrupt status*/
	    get_wakeup_ip_int();

		g_cm55s_ready = 0;
#ifdef LIB_HXMB
	    hx_lib_mb_cm55m_init(CM55M_MB_CB);
#endif

		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_RESET);
		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_NORMAL);
		hx_drv_scu_set_CM55S_CPUWAIT(SCU_CM55_CPU_RUN);

		while(1)
		{
			if(g_cm55s_ready == 1)
			{
				dbg_app_log("wait CM55S ready\n");
				break;
			}
		}

		g_cm55s_ready = 2;

		SetPSSCLAudonly();
	}else{
		/*Stop Wakeup Timer*/
		hx_drv_timer_hw_stop(g_wakeuptimerid);
		/*Get wakeup related IP Interrupt status*/
		get_wakeup_ip_int();
#ifdef DUMP_BOOT_CNTS
		val = hx_get_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C);
		val++;
	    hx_set_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C, val);
		dbg_app_log("boot cnt= %d\r\n", val);
#endif

		/*Clear PMU Wakeup Event*/
		hx_lib_pm_clear_event();
		/*clear wakeup related IP Interrupt*/
	    clear_all_wakeupip_int();
		g_cm55s_ready = 0;
#ifdef LIB_HXMB
	    hx_lib_mb_cm55m_init(CM55M_MB_CB);
#endif
#ifdef SUPPORT_CM55S_RESET
		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_RESET);
		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_NORMAL);
		hx_drv_scu_set_CM55S_CPUWAIT(SCU_CM55_CPU_RUN);

		while(1)
		{
			if(g_cm55s_ready == 1)
			{
				dbg_app_log("wait CM55S ready\n");
				break;
			}
		}
		g_cm55s_ready = 2;
#endif

		SetPSSCLAudonly();
	}

	while (1) {
		/* This point should never be reached */
	}

}
