#include "pmu_sim_tz_s_only_cm55m_audpre_vad.h"

#ifdef TRUSTZONE_SEC
#ifdef FREERTOS
/* Trustzone config. */
//
/* FreeRTOS includes. */
//#include "secure_port_macros.h"
#else
#if (__ARM_FEATURE_CMSE & 1) == 0
#error "Need ARMv8-M security extensions"
#elif (__ARM_FEATURE_CMSE & 2) == 0
#error "Compile with --cmse"
#endif
#include "arm_cmse.h"
//#include "veneer_table.h"
//
#endif
#endif
#include "mdapp.h"
#include "xprintf.h"
#include "hx_drv_scu.h"
#include "hx_drv_swreg_aon.h"

#ifdef IP_gpio
#include "hx_drv_gpio.h"
#endif
#include "hx_drv_pmu_export.h"
#include "hx_drv_pmu.h"
#include "powermode.h"
#include "BITOPS.h"
#include "hxmb.h"
#include "console_io.h"
#include "hx_drv_xdma.h"
#include "hx_drv_hxautoi2c_mst.h"


#define NOTSIM

#ifdef EPII_FPGA
#define DBG_APP_SIM_LOG             (1)
#else
#ifdef NOTSIM
#define DBG_APP_SIM_LOG             (1)
#else
#define DBG_APP_SIM_LOG             (0)
#endif
#endif
#if DBG_APP_SIM_LOG
    #define dbg_app_log(fmt, ...)       xprintf(fmt, ##__VA_ARGS__)
#else
    #define dbg_app_log(fmt, ...)
#endif



static volatile uint32_t g_cm55s_ready = 2;

#define MAX_STRING  100
//#define FORCE_PDSB_24M

//#define DUMP_CKGEN

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_vad.elf
#ifdef audpreonly_ret_pll400_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_rc24rc48rc32k_vad.elf
#ifdef audpreonly_ret_pll400_rc24rc48rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MRC48MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_rc24rc96rc32k_vad.elf
#ifdef audpreonly_ret_pll400_rc24rc96rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MRC96MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24xtal32_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24rc48xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24rc48xtal32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MRC48MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24rc96xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24rc96xtal32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MRC96MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24rc32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24rc48rc32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24rc48rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MRC48MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_xtal24rc96rc32k_vad.elf
#ifdef audpreonly_ret_pll400_xtal24rc96rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_XTAL24MRC96MRC32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_rc24xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_rc24xtal32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_rc24rc48xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_rc24rc48xtal32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MRC48MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_pll400_rc24rc96xtal32k_vad.elf
#ifdef audpreonly_ret_pll400_rc24rc96xtal32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_PLL400
#define SUPPORT_RC24MRC96MXTAL32K
#endif

// EPII_CM55M_arm_epii_evb_s_rd_audpreonly_ret_displl_xtal24rc32k_vad.elf
#ifdef audpreonly_ret_displl_xtal24rc32k_vad
#define SUPPORT_MEM_RETENTION
#define SUPPORT_WARMBOOT_DISPLL
#define SUPPORT_XTAL24MRC32K
#endif

//#define SUPPORT_CM55S_RESET
//#define DEBUG_DUMP

#define OTP_TYP00_FORMAT_VAL 			0x0
#define OTP_TYP11_FORMAT_VAL 			0x3
#define OTP_TYP11_IP_SCU_VAL 			0x0
#define OTP_TYP11_IP_SIMOLDO_VAL 		0x1
#define OTP_TYP11_IP_RCOSC_VAL 			0x2
#define OTP_TYP11_IP_TS_VAL 			0x3
#define OTP_TYP11_IP_ADC_VAL 			0x4
#define OTP_TYP11_IP_VAD_VAL 			0x5
#define OTP_TYP11_VALID_VAL 			0x0
#define OTP_TYP11_INVALID_VAL 			0x1
#define OTP_TYP11_NOTLAST_VAL 			0x0
#define OTP_TYP11_LAST_VAL 				0x1
#define OTP_NOTTRIM_VAL 				0x0
#define OTP_TYP11_HSCCLK_SEL_OFFSET 	0x20
#define OTP_TYP11_I2C2AHB_DBG_OFFSET 	0x80
#define OTP_TYP11_JTAG_OFFSET 			0x84
#define OTP_TYP11_RC24M_OFFSET 			0x00
#define OTP_TYP11_RC96M_OFFSET 			0x04
#define OTP_TYP11_RC32K_OFFSET 			0x08
#define OTP_TYP00_HSCCLK_SEL_OFFSET 	0x6000020
#define OTP_TYP00_I2C2AHB_DBG_OFFSET 	0x6000080
#define OTP_TYP00_JTAG_OFFSET 			0x6000084
#define OTP_TYP00_RC24M_OFFSET 			0x6000700
#define OTP_TYP00_RC96M_OFFSET 			0x6000704
#define OTP_TYP00_RC32K_OFFSET 			0x6000708

#define OTP_TRIM_RESERVED_START_ADDR		0x35
#define OTP_TRIM_RESERVED_END_ADDR			0x7FF
#define OTP_TYP11_FORMAT_DATA_POS			0
#define OTP_TYP11_FORMAT_DATA_SIZE			16
#define OTP_TYP11_FORMAT_ADDR_POS			16
#define OTP_TYP11_FORMAT_ADDR_SIZE			8
#define OTP_TYP11_FORMAT_IP_POS				24
#define OTP_TYP11_FORMAT_IP_SIZE			4
#define OTP_TYP11_FORMAT_TYPE_POS			28
#define OTP_TYP11_FORMAT_TYPE_SIZE			2
#define OTP_TYP11_FORMAT_LAST_POS			30
#define OTP_TYP11_FORMAT_LAST_SIZE			1
#define OTP_TYP11_FORMAT_VALID_POS			31
#define OTP_TYP11_FORMAT_VALID_SIZE			1

#define OTP_TYP00_FORMAT_ADDR_POS			0
#define OTP_TYP00_FORMAT_ADDR_SIZE			28
#define OTP_TYP00_FORMAT_TYPE_POS			28
#define OTP_TYP00_FORMAT_TYPE_SIZE			2
#define OTP_TYP00_FORMAT_LAST_POS			30
#define OTP_TYP00_FORMAT_LAST_SIZE			1
#define OTP_TYP00_FORMAT_VALID_POS			31
#define OTP_TYP00_FORMAT_VALID_SIZE			1
#define OTP_TYP00_FORMAT_DATA_POS			0
#define OTP_TYP00_FORMAT_DATA_SIZE			32

#define BIT_POS_REG_HSCCLK_SEL				 	0 //
#define BIT_SIZE_REG_HSCCLK_SEL				 	2
#define BIT_POS_REG_I2C2AHB_DBG_LIMIT		 	0 //
#define BIT_SIZE_REG_I2C2AHB_DBG_LIMIT		 	1
#define BIT_POS_REG_I2C2AHB_DBG_DISABLE		 	1 //
#define BIT_SIZE_REG_I2C2AHB_DBG_DISABLE		1

#define EPII_BL_COLDBOOT_CLKCASE	SCU_SYSCLKSRC_HW_RC24MRC32K
#define EPII_BL_COLDBOOT_PLLCLKSRC	SCU_PLLCLKSRC_RC24M1M
#define EPII_BL_COLDBOOT_CLOCKTYPE	SCU_PLL_FREQ_ENABLE
#define EPII_BL_COLDBOOT_PLLFREQ	BL_PLL_FREQ_400M
#define EPII_BL_COLDBOOT_PLLCLKSRC_DIV	0 //0:div1, 1:div2....
#define EPII_BL_COLDBOOT_CM55M_CLKDIV	SCU_HSCCLKDIV_1
#define EPII_BL_COLDBOOT_CM55S_CLKDIV	SCU_LSCCLKDIV_4


static char wakeup_event[][MAX_STRING]={
	{"[0]: PS_DPD : wakeup by (ext_force_pmu_dc_sync)"},
	{"[1]: PS_DPD wakeup by (RTC_timer_int)"},
	{"[2]: PS_DPD wakeup by (anti_tamp_int)"},
	{"[3]: PS_PD wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[4]: PS_PD wakeup by (ext_int_nxt_dc)"},
	{"[5]: PS_PD wakeup by (RTC_timer_int)"},
	{"[6]: PS_PD wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[7]: PS_PD wakeup by (CMP_int)"},
	{"[8]: PS_PD wakeup by (TS_int)"},
	{"[9]: PS_PD wakeup by (I2C_W_int)"},
	{"[10]: PS_PD wakeup by (REG_CPU_SCENARIO == 4'b0010 && SB_timer_int[0])"},
	{"[11]: PS_SCL wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[12]: PS_SCL wakeup by (~pmu_sc_active && Sensor_EXT_INT)"},
	{"[13]: PS_SCL wakeup by (ext_int_nxt_dc)"},
	{"[14]: PS_SCL wakeup by (RTC_timer_int)"},
	{"[15]: PS_SCL wakeup by (SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[16]: PS_SCL wakeup by (ADCC_int)"},
	{"[17]: PS_SCL wakeup by (TS_int)"},
	{"[18]: PS_SCL wakeup by (I2C_W_int)"},
	{"[19]: PS_SCL wakeup by (pmu_wdg_timeout_int)"},
	{"[20]: PS_SCH wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[21]: PS_SCH wakeup by (ext_int_nxt_dc)"},
	{"[22]: PS_SCH wakeup by (RTC_timer_int)"},
	{"[23]: PS_SCH wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[24]: PS_SCH wakeup by (ADCC_int)"},
	{"[25]: PS_SCH wakeup by (TS_int)"},
	{"[26]: PS_SCH wakeup by (I2C_W_int)"},
	{"[27]: PS_SCH wakeup by (pmu_wdg_timeout_int)"},
	{"[28]: PS_SCH wakeup by (WRDMAx_abnormal_int)"},
	{"[29]: PS_SCH wakeup by (DP_ABNORMAL_INT)"},
	{"[30]: PS_SCH wakeup VID Only by (DP_CDM_MOTION_INT)"},
	{"[31]: PS_SCH wakeup VIDAUD by (DP_CDM_MOTION_INT)"},
};

static char wakeup_event1[][MAX_STRING]={
	{"[0]: PS_DPD wakeup by (~pmu_sc_active &&PAD_AON_GPIO_0)"},
	{"[1]: PS_DPD wakeup by (~pmu_sc_active &&PAD_VMUTE)"},
	{"[2]: PS_DPD wakeup by (~pmu_sc_active && ext_int_nxt_dc)"},
	{"[8]: PS_PD wakeup by (anti_tamp_int)"},
	{"[16]: PS_SCL wakeup by (anti_tamp_int)"},
	{"[24]: PS_SCH wakeup by (SC_sen_noack)"},
	{"[25]: PS_SCH wakeup by (anti_tamp_int)"}
};

static char hwclk_case[][MAX_STRING]={
	{"0:RC24MRC32K"},
	{"1:RC24MRC48MRC32K"},
	{"2:RC24MRC96MRC32K"},
	{"3:XTAL24MXTAL32K"},
	{"4:XTAL24MRC48MXTAL32K"},
	{"5:XTAL24MRC96MXTAL32K"},
	{"6:XTAL24MRC32K"},
	{"7:XTAL24MRC48MRC32K"},
	{"8:XTAL24MRC96MRC32K"},
	{"9:RC24M_XTAL32K"},
	{"10:RC24MRC48M_XTAL32K"},
	{"11:RC24MRC96M_XTAL32K"},
};

static char pll_case[][MAX_STRING]={
	{"0:disable PLL"},
	{"1:Enable PLL"},
};

static char div_case[][MAX_STRING]={
	{"0:div1"},
	{"1:div2"},
	{"2:div3"},
	{"3:div4"},
	{"4:div5"},
	{"5:div6"},
	{"6:div7"},
	{"7:div8"},
	{"8:div9"},
	{"9:div10"},
	{"10:div11"},
	{"11:div12"},
	{"12:div13"},
	{"13:div14"},
	{"14:div15"},
	{"15:div16"},
};

static char mclk_case[][MAX_STRING]={
	{"0:12M"},
	{"1:24M"},
	{"2:32M"},
	{"3:48M"},
	{"4:96M"}
};

static char hscclksrc[][MAX_STRING]={
	{"0:RC24M1M"},
	{"1:XTAL24M"},
	{"2:RC96M48M"},
	{"3:PLL"}
};

static char hscd12clksrc[][MAX_STRING]={
	{"0:HSC"},
	{"1:HSCDIV2"},

};

static char hsc32k[][MAX_STRING]={
	{"0:RC32K1K"},
	{"1:XTAL32K"},
};

static char pufclk[][MAX_STRING]={
	{"0:RC24M1M"},
	{"1:XTAL24M"},
};

static char dpclk[][MAX_STRING]={
	{"0:RC24M1M"},
	{"1:RC96M48M"},
	{"1:RC96M48M Div 2"},
	{"3:XTAL24M"},
};

static char rxclk[][MAX_STRING]={
	{"0:DP"},
	{"1:MIPIRX"},
	{"2:SENPARA"},
};
static char hscmipiclksrc[][MAX_STRING]={
	{"0:RC24M"},
	{"1:RC96M48M"},
	{"2:XTAL24M"},
	{"3:PLL"}
};
static char hscppitxclksrc[][MAX_STRING]={
	{"0:RC24M"},
	{"1:RC96M48M"},
	{"2:XTAL24M"},
	{"3:PLL"}
};

static char lscclksrc[][MAX_STRING]={
	{"0:RC24M1M"},
	{"1:XTAL24M"},
	{"2:RC96M48M"},
	{"3:PLL"},
};
static char lscref[][MAX_STRING]={
	{"0:RC24M1M"},
	{"1:RC96M48M"},
	{"2:XTAL24M"},
	{"3:PLL"},
};
static char lsc32k[][MAX_STRING]={
	{"0:RC32K1K"},
	{"1:XTAL32K"},
};
static char lscscmclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:RC96M48M"},
		{"2:XTAL24M"},
};
static char vad_d_clk[][MAX_STRING]={
		{"0:PDMPCM"},
		{"1:I2SHOSTPCM"},
		{"2:I2SSLAVEPCM"},
};
static char adcckin_src[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:XTAL24M"},
};
static char sbclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:XTAL24M"},
};
static char sbclk32k[][MAX_STRING]={
		{"0:RC32K1K"},
		{"1:XTAL32K"},
};

static char adc_lp_hv[][MAX_STRING]={
		{"0:RC32K1K"},
		{"1:XTAL32K"},
};

static char aonclk[][MAX_STRING]={
		{"0:APB1_RC32K1K"},
		{"1:APB1_XTAL32K"},
		{"2:RC32K1K"},
		{"3:XTAL32K"},
};

static char aonclk32k[][MAX_STRING]={
		{"0:RC32K1K"},
		{"1:XTAL32K"},
};

static char anticlk32k[][MAX_STRING]={
		{"0:RC32K1K"},
		{"1:XTAL32K"},
};

static char str_rc24m1msel[][MAX_STRING]={
		{"0:RC24M"},
		{"1:RC1M"},
};
static char str_rc96m48msel[][MAX_STRING]={
		{"0:RC48M"},
		{"1:RC96M"},
};
static char str_rc32k1ksel[][MAX_STRING]={
		{"0:RC1K"},
		{"1:RC32K"},
};

static char str_aonswregpllsel[][MAX_STRING]={
		{"0:PLL_DISABLE"},
		{"1:PLL_Enable"},
};

static char str_pllclksrc[][MAX_STRING]={
		{"0:RC24M1M,"},
		{"1:RC96M48M"},
		{"2:XTAL24M"}
};

static char str_qspiclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:RC96M48M"},
		{"2:XTAL24M"},
		{"3:PLL"},
};
static char str_ospiclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:RC96M48M"},
		{"2:XTAL24M"},
		{"3:PLL"},
};


static char str_ckmonsrc_clk[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:XTAL24M"},
};

static char str_sspimclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:RC96M48M"},
		{"2:XTAL24M"},
};

static char str_sspisclksrc[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:RC96M48M"},
		{"2:XTAL24M"},
};

static char str_i2cmsrc_clk[][MAX_STRING]={
		{"0:RC24M1M"},
		{"1:XTAL24M"},
};

void print_hsc_clkcfg();
void print_hsc_clken();
void print_lsc_clk();
void print_lsc_clken();
void print_sb_clkcfg();
void print_sb_clkencfg();
void print_aon_clkcfg();
void print_aon_clkencfg();

void print_hsc_clkcfg()
{
	SCU_PDHSC_CLK_CFG_T cfg;

	hx_drv_scu_get_pdhsc_clk_cfg(&cfg);

	dbg_app_log("hscclksrc=%d(%s),hscclkdiv=%d\r\n", cfg.hscclk_related.hscclk.hscclksrc, hscclksrc[cfg.hscclk_related.hscclk.hscclksrc], cfg.hscclk_related.hscclk.hscclkdiv);
	dbg_app_log("hscd12clksrc=%d(%s), i3chcdiv=%d\r\n", cfg.hscclk_related.hscd12clksrc, hscd12clksrc[cfg.hscclk_related.hscd12clksrc] , cfg.hscclk_related.i3chcdiv);
	dbg_app_log("sdiodiv=%d, qspiclksrc=%d(%s)\r\n", cfg.hscclk_related.sdiodiv, cfg.qspiclksrc, str_qspiclksrc[cfg.qspiclksrc]);
	dbg_app_log("qspiclkdiv=%d, ospiclksrc=%d(%s)\r\n", cfg.qspiclkdiv, cfg.ospiclksrc, str_ospiclksrc[cfg.ospiclksrc]);
	dbg_app_log("ospiclkdiv=%d, hsc32k=%d(%s)\r\n", cfg.ospiclkdiv, cfg.hsc32k, hsc32k[cfg.hsc32k]);
	dbg_app_log("pufclk=%d(%s), dpclk=%d(%s)\r\n", cfg.pufclk, pufclk[cfg.pufclk], cfg.imageclk.dpclk, dpclk[cfg.imageclk.dpclk]);
	dbg_app_log("rxclk=%d(%s)\r\n", cfg.imageclk.rxclk, rxclk[cfg.imageclk.rxclk]);
	dbg_app_log("hscmipiclksrc=%d(%s), hscmipiclkdiv=%d\r\n", cfg.imageclk.mipiclk.hscmipiclksrc, hscmipiclksrc[cfg.imageclk.mipiclk.hscmipiclksrc], cfg.imageclk.mipiclk.hscmipiclkdiv);
	dbg_app_log("hscppitxclksrc=%d(%s), hscppitxclkdiv=%d\r\n", cfg.imageclk.ppitxclk.hscppitxclksrc, hscppitxclksrc[cfg.imageclk.ppitxclk.hscppitxclksrc], cfg.imageclk.ppitxclk.hscppitxclkdiv);

}


void print_hsc_clken()
{
	SCU_PDHSC_CLKEN_CFG_T cfg;

	hx_drv_scu_get_pdhsc_clken_cfg(&cfg);

	dbg_app_log("cm55m_clk_en=%d, u55_clk_en=%d\r\n", cfg.cm55m_clk_en, cfg.u55_clk_en);
	dbg_app_log("axi_clk_en=%d, ahb0_clk_en=%d\r\n", cfg.axi_clk_en, cfg.ahb0_clk_en);
	dbg_app_log("ahb5_clk_en=%d, ahb1_clk_en=%d\r\n", cfg.ahb5_clk_en, cfg.ahb1_clk_en);
	dbg_app_log("apb2_clk_en=%d, rom_clk_en=%d\r\n", cfg.apb2_clk_en, cfg.rom_clk_en);
	dbg_app_log("sram0_clk_en=%d, sram1_clk_en=%d\r\n", cfg.sram0_clk_en, cfg.sram1_clk_en);
	dbg_app_log("i3c_hc_clk_en=%d, puf_clk_en=%d\r\n", cfg.i3c_hc_clk_en, cfg.puf_clk_en);
	dbg_app_log("dma0_clk_en=%d, dma1_clk_en=%d\r\n", cfg.dma0_clk_en, cfg.dma1_clk_en);
	dbg_app_log("sdio_clk_en=%d, i2c2ahb_flash_w_clk_en=%d\r\n", cfg.sdio_clk_en, cfg.i2c2ahb_flash_w_clk_en);
	dbg_app_log("qspi_en=%d, ospi_en=%d\r\n", cfg.qspi_en, cfg.ospi_en);
	dbg_app_log("spi2ahb_en=%d\r\n", cfg.spi2ahb_en);

	dbg_app_log("xdma_w1_clk_en=%d, xdma_w2_clk_en=%d\r\n", cfg.imageclk_en.xdma_w1_clk_en, cfg.imageclk_en.xdma_w2_clk_en);
	dbg_app_log("xdma_w3_clk_en=%d, xdma_r_clk_en=%d\r\n", cfg.imageclk_en.xdma_w3_clk_en, cfg.imageclk_en.xdma_r_clk_en);
	dbg_app_log("scclk_clk_en=%d, inp_clk_en=%d\r\n", cfg.imageclk_en.scclk_clk_en, cfg.imageclk_en.inp_clk_en);
	dbg_app_log("dp_clk_en=%d, dp_2x2_clk_en=%d\r\n", cfg.imageclk_en.dp_clk_en, cfg.imageclk_en.dp_2x2_clk_en);
	dbg_app_log("dp_5x5_clk_en=%d, dp_cdm_clk_en=%d\r\n", cfg.imageclk_en.dp_5x5_clk_en, cfg.imageclk_en.dp_cdm_clk_en);
	dbg_app_log("dp_jpeg_clk_en=%d, dp_tpg_clk_en=%d\r\n", cfg.imageclk_en.dp_jpeg_clk_en, cfg.imageclk_en.dp_tpg_clk_en);
	dbg_app_log("dp_edm_clk_en=%d, dp_rgb2yuv_pclk_en=%d\r\n", cfg.imageclk_en.dp_edm_clk_en, cfg.imageclk_en.dp_rgb2yuv_pclk_en);
	dbg_app_log("dp_csc_pclk_en=%d, mipirx_clk_en=%d\r\n", cfg.imageclk_en.dp_csc_pclk_en, cfg.imageclk_en.mipirx_clk_en);
	dbg_app_log("mipitx_clk_en=%d\r\n", cfg.imageclk_en.mipitx_clk_en);

}

void print_lsc_clk()
{
	SCU_PDLSC_CLK_CFG_T cfg;

	hx_drv_scu_get_pdlsc_clk_cfg(&cfg);

	dbg_app_log("lscclksrc=%d(%s), lscclkdiv=%d\r\n", cfg.lscclk.lscclksrc, lscclksrc[cfg.lscclk.lscclksrc], cfg.lscclk.lscclkdiv);
	dbg_app_log("lscref=%d(%s), i2s_host_sclk_div=%d\r\n", cfg.lscref_related.lscref, lscref[cfg.lscref_related.lscref], cfg.lscref_related.i2s_host_sclk_div);
	dbg_app_log("pdmclk_div=%d, uart_div=%d\r\n", cfg.lscref_related.pdmclk_div, cfg.lscref_related.uart_div);
	dbg_app_log("i3cslv_div=%d, pwm_div=%d\r\n", cfg.lscref_related.i3cslv_div, cfg.lscref_related.pwm_div);
	dbg_app_log("ro_pd_div=%d, i2c_div=%d\r\n", cfg.lscref_related.ro_pd_div, cfg.lscref_related.i2c_div);
	dbg_app_log("lsc32k=%d(%s), vad_d_clk=%d\r\n", cfg.lsc32k, lsc32k[cfg.lsc32k], cfg.vad_d_clk);
	dbg_app_log("ckmonsrc_clk=%d(%s)\r\n", cfg.ckmonsrc_clk, str_ckmonsrc_clk[cfg.ckmonsrc_clk]);
	dbg_app_log("sspimsrc_clk=%d(%s), sspim_div=%d\r\n", cfg.sspimsrc_clk, str_sspimclksrc[cfg.sspimsrc_clk], cfg.sspim_div);
	dbg_app_log("sspissrc_clk=%d(%s), sspis_div=%d\r\n", cfg.sspissrc_clk, str_sspisclksrc[cfg.sspissrc_clk], cfg.sspis_div);
	dbg_app_log("lscscmclksrc=%d(%s), lscmclkdiv=%d\r\n", cfg.image_clk.scsenmclk.lscscmclksrc, lscscmclksrc[cfg.image_clk.scsenmclk.lscscmclksrc], cfg.image_clk.scsenmclk.lscmclkdiv);
	dbg_app_log("adcckin_src=%d(%s), adcckindiv=%d\r\n", cfg.adcckin.adcckin_src, adcckin_src[cfg.adcckin.adcckin_src], cfg.adcckin.adcckindiv);

}

void print_lsc_clken()
{
	SCU_PDLSC_CLKEN_CFG_T cfg;

	hx_drv_scu_get_pdlsc_clken_cfg(&cfg);

	dbg_app_log("cm55s_clk_en=%d, ahb_m_hclk_en=%d\r\n", cfg.cm55s_clk_en, cfg.ahb_m_hclk_en);
	dbg_app_log("ahb_2_hclk_en=%d, ahb_3_hclk_en=%d\r\n", cfg.ahb_2_hclk_en, cfg.ahb_3_hclk_en);
	dbg_app_log("apb_0_hclk_en=%d, sram2_clk_en=%d\r\n", cfg.apb_0_hclk_en, cfg.sram2_clk_en);
	dbg_app_log("dma2_clk_en=%d, dma3_clk_en=%d\r\n", cfg.dma2_clk_en, cfg.dma3_clk_en);
	dbg_app_log("i2s_host_sclk_en=%d, pdm_clk_en=%d\r\n", cfg.i2s_host_sclk_en, cfg.pdm_clk_en);
	dbg_app_log("uart0_clk_en=%d, uart1_clk_en=%d\r\n", cfg.uart0_clk_en, cfg.uart1_clk_en);
	dbg_app_log("uart2_clk_en=%d, i3c_slv0_sys_clk_en=%d\r\n", cfg.uart2_clk_en, cfg.i3c_slv0_sys_clk_en);
	dbg_app_log("i3c_slv1_sys_clk_en=%d, pwm012_clk_en=%d\r\n", cfg.i3c_slv1_sys_clk_en, cfg.pwm012_clk_en);
	dbg_app_log("i2s_slv_sclk_en=%d, ro_pd_clk_en=%d\r\n", cfg.i2s_slv_sclk_en, cfg.ro_pd_clk_en);
	dbg_app_log("i2c_slv0_ic_clk_en=%d, i2c_slv1_ic_clk_en=%d\r\n", cfg.i2c_slv0_ic_clk_en, cfg.i2c_slv1_ic_clk_en);
	dbg_app_log("i2c_mst_ic_clk_en=%d, i2c_mst_sen_ic_clk_en=%d\r\n", cfg.i2c_mst_ic_clk_en, cfg.i2c_mst_sen_ic_clk_en);
	dbg_app_log("sw_clk_en=%d, vad_d_clk_en=%d\r\n", cfg.sw_clk_en, cfg.vad_d_clk_en);
	dbg_app_log("adcck_en=%d, gpio_en=%d\r\n", cfg.adcck_en, cfg.gpio_en);
	dbg_app_log("sspim_en=%d, sspis_en=%d\r\n", cfg.sspim_en, cfg.sspis_en);
	dbg_app_log("ckmon_en=%d, sc_clk_lsc_en=%d\r\n", cfg.ckmon_en, cfg.imageclk_en.sc_clk_lsc_en);

}

void print_sb_clkcfg()
{
	SCU_PDSB_CLK_CFG_T cfg;

	hx_drv_scu_get_pdsb_clk_cfg(&cfg);

	dbg_app_log("sbclksrc=%d(%s), sbclkdiv=%d\r\n", cfg.sbclk.sbclksrc, sbclksrc[cfg.sbclk.sbclksrc], cfg.sbclk.sbclkdiv);
	dbg_app_log("sb32ksrc=%d(%s), himaxi2cm=%d(%s)\r\n", cfg.sb32ksrc, sbclk32k[cfg.sb32ksrc], cfg.himaxi2cm, str_i2cmsrc_clk[cfg.himaxi2cm]);

}

void print_sb_clkencfg()
{
	SCU_PDSB_CLKEN_CFG_T get_cfg;
	hx_drv_scu_get_pdsb_clken_cfg(&get_cfg);

	dbg_app_log("ahb_4_hclk_en=%d, ts_clk_en=%d\r\n", get_cfg.apb1_ahb4_pclk_en, get_cfg.ts_clk_en);
	dbg_app_log("adc_lp_hv_clk_en=%d, I2C2AHB_DBG_en=%d, WDT0_en=%d\r\n", get_cfg.adc_lp_hv_clk_en, get_cfg.I2C2AHB_DBG_en, get_cfg.WDT0_en);
	dbg_app_log("WDT1_en=%d, TIMER0_en=%d, TIMER1_en=%d\r\n", get_cfg.WDT1_en, get_cfg.TIMER0_en, get_cfg.TIMER1_en);
	dbg_app_log("TIMER2_en=%d, TIMER3_en=%d, TIMER4_en=%d\r\n", get_cfg.TIMER2_en, get_cfg.TIMER3_en, get_cfg.TIMER4_en);
	dbg_app_log("TIMER5_en=%d, TIMER6_en=%d, TIMER7_en=%d\r\n", get_cfg.TIMER5_en, get_cfg.TIMER6_en, get_cfg.TIMER7_en);
	dbg_app_log("TIMER8_en=%d, sb_gpio_en=%d, hmxi2cm_en=%d\r\n", get_cfg.TIMER8_en, get_cfg.sb_gpio_en, get_cfg.hmxi2cm_en);

}

void print_aon_clkcfg()
{
	SCU_PDAON_CLK_CFG_T cfg;

	hx_drv_scu_get_pdaon_clk_cfg(&cfg);
	dbg_app_log("aonclk=%d(%s), antitamp=%d(%s)\r\n", cfg.aonclk, aonclk[cfg.aonclk], cfg.antitamp, anticlk32k[cfg.antitamp]);
}

void print_aon_clkencfg()
{
	SCU_PDAON_CLKEN_CFG_T get_cfg;

	hx_drv_scu_get_pdaon_clken_cfg(&get_cfg);
	dbg_app_log("rtc0_clk_en=%d, rtc1_clk_en=%d, rtc2_clk_en=%d\r\n", get_cfg.rtc0_clk_en, get_cfg.rtc1_clk_en, get_cfg.rtc2_clk_en);
	dbg_app_log("pmu_clk_en=%d, aon_gpio_clk_en=%d, aon_swreg_clk_en=%d\r\n", get_cfg.pmu_clk_en, get_cfg.aon_gpio_clk_en, get_cfg.aon_swreg_clk_en);
	dbg_app_log("antitamper_clk_en=%d\r\n", get_cfg.antitamper_clk_en);

}

void CM55M_MB_CB(uint32_t event)
{
	uint32_t irq_status;
	hx_drv_mb_get_cm55m_irq_status(&irq_status);
	dbg_app_log("CM55M irq_status=0x%x\n", irq_status);

	g_cm55s_ready = 1;
	dbg_app_log("irq_status=0x%x\n", irq_status);
	hx_drv_mb_clear_cm55m_irq(irq_status);

	hx_drv_mb_get_cm55m_irq_status(&irq_status);
	dbg_app_log("after clear in ISR get CM55M irq_status=0x%x\n", irq_status);
}


static void dump_debug_reg_pmu()
{
	uint32_t reg_val = 0;
	uint32_t reg_addr = BASE_ADDR_APB_PMU_ALIAS;

	dbg_app_log("SCU start\n");
	for(reg_addr = BASE_ADDR_APB_SCU_AON_ALIAS; reg_addr<= (BASE_ADDR_APB_SCU_AON_ALIAS+0x4C); reg_addr=reg_addr+4)
	{
		reg_val = (*((volatile unsigned int*) reg_addr));
		dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);
	}
	for(reg_addr = BASE_ADDR_APB_SCU_AON_ALIAS+0x700; reg_addr<= (BASE_ADDR_APB_SCU_AON_ALIAS+0x710); reg_addr=reg_addr+4)
	{
		reg_val = (*((volatile unsigned int*) reg_addr));
		dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);
	}
	reg_addr = BASE_ADDR_APB_SCU_AON_ALIAS+0x730;
	reg_val = (*((volatile unsigned int*) reg_addr));
	dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);
	reg_addr = BASE_ADDR_APB_SCU_AON_ALIAS+0x734;
	reg_val = (*((volatile unsigned int*) reg_addr));
	dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);

	dbg_app_log("PMU start\n");
	for(reg_addr = BASE_ADDR_APB_PMU_ALIAS; reg_addr<= (BASE_ADDR_APB_PMU_ALIAS+0xFF); reg_addr=reg_addr+4)
	{
		reg_val = (*((volatile unsigned int*) reg_addr));
		dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);
	}

	dbg_app_log("\nSB Timer0 start\n");
	for(reg_addr = BASE_ADDR_APB_TIMER0_ALIAS; reg_addr<= (BASE_ADDR_APB_TIMER0_ALIAS+0x0C); reg_addr=reg_addr+4)
	{
		reg_val = (*((volatile unsigned int*) reg_addr));
		dbg_app_log("0x%08x=0x%08x\n",reg_addr, reg_val);
	}
}


static void print_wakeup_event(uint32_t event, uint32_t event1)
{

	if((event & 0x1)  != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[0]);
	}
	if((event & 0x2) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[1]);
	}
	if((event & 0x4) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[2]);
	}
	if((event & 0x8) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[3]);
	}
	if((event & 0x10) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[4]);
	}
	if((event & 0x20) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[5]);
	}
	if((event & 0x40) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[6]);
	}
	if((event & 0x80) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[7]);
	}
	if((event & 0x100) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[8]);
	}
	if((event & 0x200) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[9]);
	}
	if((event & 0x400) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[10]);
	}
	if((event & 0x800) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[11]);
	}
	if((event & 0x1000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[12]);
	}
	if((event & 0x2000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[13]);
	}
	if((event & 0x4000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[14]);
	}
	if((event & 0x8000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[15]);
	}
	if((event & 0x10000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[16]);
	}
	if((event & 0x20000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[17]);
	}
	if((event & 0x40000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[18]);
	}
	if((event & 0x80000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[19]);
	}
	if((event & 0x100000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[20]);
	}
	if((event & 0x200000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[21]);
	}
	if((event & 0x400000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[22]);
	}
	if((event & 0x800000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[23]);
	}
	if((event & 0x1000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[24]);
	}
	if((event & 0x2000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[25]);
	}
	if((event & 0x4000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[26]);
	}
	if((event & 0x8000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[27]);
	}
	if((event & 0x10000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[28]);
	}
	if((event & 0x20000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[29]);
	}
	if((event & 0x40000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[30]);
	}
	if((event & 0x80000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[31]);
	}
	if((event1 & 0x1)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[0]);
	}
	if((event1 & 0x2)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[1]);
	}
	if((event1 & 0x4)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[2]);
	}
	if((event1 & 0x100)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[3]);
	}
	if((event1 & 0x10000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[4]);
	}
	if((event1 & 0x1000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[5]);
	}
	if((event1 & 0x2000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[6]);
	}
}

void getPMUExtIntStatus()
{
	uint32_t val;
	hx_drv_pmu_get_ctrl(PMU_AON_GPIO, &val);
	dbg_app_log("PMU_AON_GPIO intstatus=0x%x\n", val);
	hx_drv_pmu_get_ctrl(PMU_SB_GPIO, &val);
	dbg_app_log("PMU_SB_GPIO intstatus=0x%x\n", val);
	hx_drv_pmu_get_ctrl(PMU_WDOGINT0, &val);
	dbg_app_log("PMU_WDOGINT0 intstatus=0x%x\n", val);
	hx_drv_pmu_get_ctrl(PMU_WDOGINT1, &val);
	dbg_app_log("PMU_WDOGINT1 intstatus=0x%x\n", val);
	hx_drv_pmu_get_ctrl(PMU_PAD_AON_GPIO_0_STATUS, &val);
	dbg_app_log("PMU_PAD_AON_GPIO_0_STATUS intstatus=0x%x\n", val);
	hx_drv_pmu_get_ctrl(PMU_PAD_VMUTE_STATUS, &val);
	dbg_app_log("PMU_PAD_VMUTE_STATUS intstatus=0x%x\n", val);
}


void get_all_ip_int()
{
	uint32_t status, irq_raw_status, irq_status;
#ifdef IP_xdma
	uint32_t wdma1_status, wdma2_status, wdma3_status, rdma_status;
#endif
#ifdef IP_rtc
	for(uint8_t idx = RTC_ID_0; idx < RTC_ID_MAX; idx++)
	{
		hx_drv_rtc_get_alarm_rawint_status(idx, &status);
		dbg_app_log("RTC id=%d, raw status=%d\n", idx, status);
		hx_drv_rtc_get_alarm_maskint_status(idx, &status);
		dbg_app_log("RTC id=%d, mask status=%d\n", idx, status);
	}
#endif
#ifdef IP_timer
	for(uint8_t idx = TIMER_ID_0; idx < TIMER_ID_MAX; idx++)
	{
		status = hx_drv_timer_StatusIRQ(idx);
		dbg_app_log("Timer id=%d, raw status=%d\n", idx, status);
	}
#endif
#ifdef IP_watchdog
	for(uint8_t idx = WATCHDOG_ID_0; idx < WATCHDOG_ID_MAX; idx++)
	{
		irq_raw_status = hx_drv_watchdog_irq_raw_status(idx);

		irq_status = hx_drv_watchdog_irq_status(idx);

		dbg_app_log("WDG id=%d, irq_raw_status=0x%x, irq_status=0x%x\n", idx, irq_raw_status, irq_status);

	}
#endif
#ifdef IP_gpio
    status = hx_drv_gpio_get_int_status(AON_GPIO0);
    dbg_app_log("AON GPIO_0, int_status:%d \n", status);
    status = hx_drv_gpio_get_int_status(SB_GPIO0);
    dbg_app_log("SB GPIO_0, int_status:%d \n", status);
#endif
#ifdef IP_xdma
    hx_drv_xdma_get_WDMA1INTStatus(&wdma1_status);
    hx_drv_xdma_get_WDMA2INTStatus(&wdma2_status);
    hx_drv_xdma_get_WDMA3INTStatus(&wdma3_status);
    hx_drv_xdma_get_RDMAINTStatus(&rdma_status);
	dbg_app_log("wdma1_status=0x%x, wdma2_status=0x%x, wdma3_status=0x%x, rdma_status=0x%x\n", wdma1_status, wdma2_status, wdma3_status, rdma_status);
#endif
#ifdef IP_hxautoi2c_mst
	uint32_t autoi2c_rawstatus = 0;
	autoi2c_rawstatus = hx_drv_hxautoi2c_get_rawstatus();
    dbg_app_log("autoi2c_rawstatus:0x%x \n", autoi2c_rawstatus);
#endif
}

void ClearWakeupEvt()
{
	uint32_t wakeup_event, wakeup_event1;
	hx_lib_pm_clear_event();
	hx_drv_pmu_get_ctrl(PMU_pmu_wakeup_EVT, &wakeup_event);
    dbg_app_log("after clear WakeupEvt=0x%x\n", wakeup_event);
	hx_drv_pmu_get_ctrl(PMU_pmu_wakeup_EVT1, &wakeup_event1);
    dbg_app_log("after clear WakeupEvt1=0x%x\n", wakeup_event1);
}

void clear_all_sysip_int()
{
#ifdef IP_rtc
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_0);
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_1);
	hx_drv_rtc_clear_alarm_int_status(RTC_ID_2);
#endif
#ifdef IP_timer
	hx_drv_timer_ClearIRQ(TIMER_ID_0);
	hx_drv_timer_ClearIRQ(TIMER_ID_1);
	hx_drv_timer_ClearIRQ(TIMER_ID_2);
	hx_drv_timer_ClearIRQ(TIMER_ID_3);
	hx_drv_timer_ClearIRQ(TIMER_ID_4);
	hx_drv_timer_ClearIRQ(TIMER_ID_5);
	hx_drv_timer_ClearIRQ(TIMER_ID_6);
	hx_drv_timer_ClearIRQ(TIMER_ID_7);
	hx_drv_timer_ClearIRQ(TIMER_ID_8);
#endif
#ifdef IP_watchdog
	hx_drv_watchdog_irq_clear(WATCHDOG_ID_0);
	hx_drv_watchdog_irq_clear(WATCHDOG_ID_1);
#endif
#ifdef IP_gpio
	hx_drv_gpio_clr_int_status(AON_GPIO0);
	hx_drv_gpio_clr_int_status(AON_GPIO1);
	hx_drv_gpio_clr_int_status(SB_GPIO0);
	hx_drv_gpio_clr_int_status(SB_GPIO1);
#endif
}

void dump_aud_mem()
{
	uint32_t addr, size, cnt, auto_dump, val;
    addr = BASE_ADDR_SRAM2_ALIAS+0x30000;
		size = 40;
	    cnt = size/4;
	    hx_InvalidateDCache_by_Addr((void *)addr, size);

		dbg_app_log("\n\audio buffer\n");
		for(uint32_t idx = 0; idx< cnt; idx++)
		{
			val = hx_get_memory((addr + (idx*4)));
			dbg_app_log("0x%08X ", val);
		}
		dbg_app_log("\n");
}

void clear_aud_mem()
{
	uint32_t addr, size, cnt;
    addr = BASE_ADDR_SRAM2_ALIAS+0x30000;
		size = 160;
	    cnt = size/4;
		for(uint32_t idx = 0; idx< cnt; idx++)
		{
			hx_set_memory((addr+ (idx*4)), 0);
		}

	    hx_CleanDCache_by_Addr((void *)addr, size);

}

void SetPSSCLAudonly()
{
	PM_PD_AUDPRE_CFG_T cfg;
	uint8_t speed,reset, precap, nframeend_ctrl, trigger, retention;
	uint32_t pmu_pad_pa01_mask, pmu_rtc_mask, support_debugdump;
	uint32_t pmu_pad_pa23_mask, pmu_i2cw_mask, pmu_timer_mask, pmu_cmp_mask, pmu_ts_mask;
	uint32_t dcdcpin, freq, cm55mdiv, cm55sdiv, pmu_anti_mask, pmu_senint_mask;
	SCU_LSC_CLK_CFG_T lsc_cfg;
	SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;
	PM_CFG_PWR_MODE_E mode;

#ifdef SUPPORT_WARMBOOT_DISPLL
	speed = SCU_PLL_FREQ_DISABLE;
#else
	speed = SCU_PLL_FREQ_ENABLE;
#endif
#ifdef SUPPORT_CM55S_RESET
	reset = 1;
#else
	reset = 0;
#endif
	nframeend_ctrl = 0;
#ifdef SUPPORT_MEM_RETENTION
	retention = 1;
#else
	retention = 0;
#endif



	pmu_pad_pa01_mask = 0;
	pmu_rtc_mask = 0;
	pmu_pad_pa23_mask = 0;
	pmu_i2cw_mask = 0;
	pmu_timer_mask = 0;
	pmu_cmp_mask = 0;
	pmu_ts_mask = 0;
	trigger = 1;
	support_debugdump = 0;
	dcdcpin = 0;
	pmu_senint_mask = 1;

#if defined(SUPPORT_WARMBOOT_PLL400)
	freq = 400000000;
	cm55mdiv = SCU_HSCCLKDIV_1;
	cm55sdiv = SCU_LSCCLKDIV_4;
#elif defined(SUPPORT_WARMBOOT_PLL300)
	freq = 300000000;
	cm55mdiv = SCU_HSCCLKDIV_1;
	cm55sdiv = SCU_LSCCLKDIV_3;
#elif defined(SUPPORT_WARMBOOT_PLL200)
	freq = 200000000;
	cm55mdiv = SCU_HSCCLKDIV_1;
	cm55sdiv = SCU_LSCCLKDIV_2;
#elif defined(SUPPORT_WARMBOOT_PLL100)
	freq = 100000000;
	cm55mdiv = SCU_HSCCLKDIV_1;
	cm55sdiv = SCU_LSCCLKDIV_1;
#else
	freq = 0;
	cm55mdiv = SCU_HSCCLKDIV_1;
	cm55sdiv = SCU_LSCCLKDIV_1;
#endif
	pmu_anti_mask = 0;
	dbg_app_log("speed=%d,reset=%d,nframeend_ctrl=%d,retention=%d,precap=%d\n", speed,reset,nframeend_ctrl,retention,precap);
	dbg_app_log("ag_mask=0x%x,rtc_mask=0x%x,sb_mask=0x%x,i2cw_mask=0x%x,timer_mask=0x%x,cmp_mask=0x%x,ts_mask=0x%x\n", pmu_pad_pa01_mask,pmu_rtc_mask,pmu_pad_pa23_mask,pmu_i2cw_mask,pmu_timer_mask,pmu_cmp_mask,pmu_ts_mask);
	dbg_app_log("trigger=%d,debug=%d, reset=%d\n", trigger,support_debugdump, reset);
	dbg_app_log("dcdcpin=%d, pmu_anti_mask=0x%x\n", dcdcpin, pmu_anti_mask);
	dbg_app_log("freq=%d, cm55mdiv=%d,cm55mdiv=%d, pmu_senint_mask=%d\n", freq, cm55mdiv, cm55mdiv, pmu_senint_mask);
	mode = PM_MODE_PS_AUD_ONLY_PREROLLING;
	hx_lib_pm_get_defcfg_bymode(&cfg, mode);
	cfg.bootromspeed.bootromclkfreq = speed;
	cfg.bootromspeed.pll_freq = freq;
	cfg.bootromspeed.cm55m_div = cm55mdiv;
	cfg.bootromspeed.cm55s_div = cm55sdiv;


	cfg.cm55s_reset = reset;
	cfg.pmu_pad_pa01_mask = pmu_pad_pa01_mask;
	cfg.pmu_rtc_mask = pmu_rtc_mask;
	cfg.pmu_pad_pa23_mask = pmu_pad_pa23_mask;			/**< PMU SB GPIO Interrupt Mask **/
	cfg.pmu_i2cw_mask = pmu_i2cw_mask;			/**< PMU I2C Wakeup Interrupt Mask **/
	cfg.pmu_timer_mask = pmu_timer_mask;			/**< PMU Timer0~5 Wakeup Interrupt Mask  **/
	cfg.pmu_cmp_mask = pmu_cmp_mask;			/**< PMU CMP Wakeup Interrupt Mask  **/
	cfg.pmu_ts_mask = pmu_ts_mask;			/**< PMU TS Wakeup Interrupt Mask  **/
	cfg.pmu_anti_mask = pmu_anti_mask;
	cfg.pmu_senint_mask = pmu_senint_mask;		/**< PMU SENSOR Interrupt Mask **/
	cfg.support_debugdump = support_debugdump;

	cfg.tcm_retention = retention;			/**< CM55M TCM Retention**/
	cfg.hscsram_retention[0] = retention;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[1] = retention;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[2] = retention;	/**< HSC SRAM Retention**/
	cfg.hscsram_retention[3] = retention;	/**< HSC SRAM Retention**/
	cfg.lscsram_retention = retention;		/**< LSC SRAM Retention**/
	cfg.skip_bootflow.sec_mem_flag = retention;			/**< Skip Boot Flow**/
	cfg.skip_bootflow.first_bl_flag = retention; /*!< First BL Retention */
	cfg.skip_bootflow.cm55m_s_app_flag = retention; /*!< cm55m_s_app Retention */
	cfg.skip_bootflow.cm55m_ns_app_flag = retention; /*!< cm55m_ns_app Retention */
	cfg.skip_bootflow.cm55s_s_app_flag = retention; /*!< cm55s_s_app Retention */
	cfg.skip_bootflow.cm55s_ns_app_flag = retention; /*!< cm55s_ns_app Retention */
	cfg.skip_bootflow.cm55m_model_flag = retention; /*!< cm55m model Retention */
	cfg.skip_bootflow.cm55s_model_flag = retention; /*!< cm55s model Retention */
	cfg.skip_bootflow.cm55m_appcfg_flag = retention; /*!< cm55m appcfg Retention */
	cfg.skip_bootflow.cm55s_appcfg_flag = retention; /*!< cm55s appcfg Retention */
	cfg.skip_bootflow.cm55m_s_app_rwdata_flag = retention;/*!< cm55m_s_app RW Data Retention */
	cfg.skip_bootflow.cm55m_ns_app_rwdata_flag = retention;/*!< cm55m_ns_app RW Data Retention */
	cfg.skip_bootflow.cm55s_s_app_rwdata_flag = retention;/*!< cm55s_s_app RW Data Retention */
	cfg.skip_bootflow.cm55s_ns_app_rwdata_flag = retention;/*!< cm55s_ns_app RW Data Retention */
	cfg.skip_bootflow.secure_debug_flag = retention;
	cfg.pmu_dcdc_outpin = dcdcpin;
	hx_set_memory(0x5200F018, 0x00000017);
	hx_lib_pm_cfg_set(&cfg, NULL, PM_MODE_PS_AUD_ONLY_PREROLLING);

	hx_set_memory(0x5200F018, 0x00000020);
#ifdef SUPPORT_RC24MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC24M1M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC24M1M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC48MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC96MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_XTAL24M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_XTAL24M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC48MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC96MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_XTAL24M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_XTAL24M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC48MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_XTAL24MRC96MRC32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC24M1M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC24M1M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC48MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_1;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_1;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
#ifdef SUPPORT_RC24MRC96MXTAL32K
	hsc_cfg.hscclk.hscclksrc = SCU_HSCCLKSRC_RC96M48M;
	hsc_cfg.hscclk.hscclkdiv = SCU_HSCCLKDIV_1;
	hsc_cfg.hscd12clksrc = SCU_HSCD12CLKSRC_HSC;
	hsc_cfg.i3chcdiv = SCU_HSCI3CHCLKDIV_2;
	hsc_cfg.sdiodiv = SCU_HSCSDIOCLKDIV_2;
	lsc_cfg.lscclksrc = SCU_LSCCLKSRC_RC96M48M;
	lsc_cfg.lscclkdiv = SCU_LSCCLKDIV_1;
#endif
	while(1)
	{
		if(g_cm55s_ready == 1)
		{
		dbg_app_log("CM55S Ready\r\n");
			break;
		}
	}

#ifdef DEBUG_DUMP
	dump_debug_reg_pmu();
#endif
	if(trigger == 1)
	{
		hx_set_memory(0x5200F018, 0x00000033);
		hx_lib_pm_trigger(hsc_cfg, lsc_cfg, PM_CLK_PARA_CTRL_BYAPP);
	}

}

/*******************************************************************************
 * Code
 ******************************************************************************/
/*!
 * @brief Main function
 */
int hello_world_app(void) {
	int getin;
	uint32_t wakeup_event, freq;
	uint8_t spirxdelay;
	uint32_t wakeup_event1;
	SCU_PLL_FREQ_E pmuwakeup_pll_freq;
	SCU_HSCCLKDIV_E pmuwakeup_cm55m_div;
	SCU_LSCCLKDIV_E pmuwakeup_cm55s_div;
	SCU_PLL_CLK_CFG_T pll_cfg;
	uint32_t wdma1_use, wdma2_use, wdma3_use, rdma_use;
	uint8_t jpegloop_flag;
	uint8_t nextjpeg_frame_no;
	uint8_t jpeg_total_slot;
	uint32_t val;
	hx_set_memory(0x5200F018, 0x0000000F);
	dbg_app_log("PMU Auto Test\r\n");
	hx_drv_pmu_get_ctrl(PMU_pmu_wakeup_EVT, &wakeup_event);
    dbg_app_log("WakeupEvt=0x%x\n", wakeup_event);
	hx_set_memory(0x5200F018, 0x00000010);
	hx_drv_pmu_get_ctrl(PMU_pmu_wakeup_EVT1, &wakeup_event1);
    dbg_app_log("WakeupEvt1=0x%x\n", wakeup_event1);
    print_wakeup_event(wakeup_event, wakeup_event1);
	hx_set_memory(0x5200F018, 0x00000011);
	hx_drv_swreg_aon_get_pmuwakeup_freq(&pmuwakeup_pll_freq, &pmuwakeup_cm55m_div, &pmuwakeup_cm55s_div);
	hx_drv_swreg_aon_get_pllfreq(&freq);
	dbg_app_log("pmuwakeup_freq_type=%d, pmuwakeup_cm55m_div=%d, pmuwakeup_cm55s_div=%d\n", pmuwakeup_pll_freq, pmuwakeup_cm55m_div, pmuwakeup_cm55s_div);
	dbg_app_log("pmuwakeup_run_freq=%d\n", freq);
	hx_set_memory(0x5200F018, 0x00000012);
	hx_drv_scu_get_pll_cfg(&pll_cfg);
	hx_set_memory(0x5200F018, 0x00000013);
	dbg_app_log("init_pll_para=%d,sysclksrc_sel=%d(%s)\n", pll_cfg.init_pll_para, pll_cfg.sysclksrc_sel, hwclk_case[pll_cfg.sysclksrc_sel]);
	dbg_app_log("clk_src=%d,%s,freq=%d\n", pll_cfg.clk_src, str_pllclksrc[pll_cfg.clk_src], pll_cfg.freq);
	dbg_app_log("pllclksrc_div=%d,pll_freq=%d\n", pll_cfg.pllclksrc_div, pll_cfg.pll_freq);

	/*
	val = hx_get_memory(BASE_ADDR_APB_SCU_AON_ALIAS+0x6C);
	HX_BIT_SET(val, 1, 17, 0);
	dbg_app_log("0x%x=0x%x\r\n", (BASE_ADDR_APB_SCU_AON_ALIAS+0x6C), val);
	hx_set_memory(BASE_ADDR_APB_SCU_AON_ALIAS+0x6C, val);
*/
#ifdef DUMP_CKGEN
	print_hsc_clkcfg();
	print_lsc_clk();
	print_sb_clkcfg();
	print_aon_clkcfg();

	print_hsc_clken();
	print_lsc_clken();
	print_sb_clkencfg();
	print_aon_clkencfg();
#endif

#ifdef SUPPORT_COLDBOOT
	dbg_app_log("cold boot\r\n");
	hx_set_memory(0x5200F018, 0x00000014);
#else

	if((wakeup_event == PMU_WAKEUP_NONE) && (wakeup_event1 == PMU_WAKEUPEVENT1_NONE))
	{
	   	hx_set_memory(0x5200F018, 0x00000013);
	    getPMUExtIntStatus();
	    get_all_ip_int();

	    hx_drv_swreg_aon_get_spi_rxsample_delay(&spirxdelay);
		dbg_app_log("spirxdelay= %d\r\n", spirxdelay);
	    ClearWakeupEvt();
	    clear_all_sysip_int();
	    hx_set_memory(0x5200F018, 0x00000014);
#ifdef SUPPORT_PRECAP
	    clear_aud_mem();
		dump_aud_mem();
#endif
		val = hx_get_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C);
		val++;
	    hx_set_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C, val);
		dbg_app_log("boot cnt= %d\r\n", val);
		g_cm55s_ready = 0;
#ifdef LIB_HXMB
	    hx_lib_mb_cm55m_init(CM55M_MB_CB);
#endif

		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_RESET);
		hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_NORMAL);
		hx_drv_scu_set_CM55S_CPUWAIT(SCU_CM55_CPU_RUN);

		SetPSSCLAudonly();
	}else{
		val = hx_get_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C);
		val++;
	    hx_set_memory(BASE_ADDR_APB_SWREG_AON_ALIAS+0x3C, val);
		dbg_app_log("boot cnt= %d\r\n", val);
#ifdef LIB_HXMB
	    hx_lib_mb_cm55m_init(CM55M_MB_CB);
#endif
		get_all_ip_int();
	    getPMUExtIntStatus();
	    get_all_ip_int();

	    ClearWakeupEvt();
	    clear_all_sysip_int();
		dbg_app_log("warm boot\r\n");
		hx_set_memory(0x5200F018, 0x00000015);
#ifdef NOTSIM
		SetPSSCLAudonly();
#endif
	}

#endif
	while (1) {
		/* This point should never be reached */
		getin = console_getchar();
		dbg_app_log("getin= %d\r\n", getin);
	}

}
