#include "pmu_dpd_sample.h"
#include "hx_drv_scu_export.h"
#include "powermode_export.h"
#include "veneer_sys_ctrl.h"
#include "veneer_power_ctrl.h"
#ifdef IP_timer
#include "hx_drv_timer.h"
#endif
#ifdef IP_rtc
#include "hx_drv_rtc.h"
#endif
#include "tfm_log.h"

#define WAKEUP_PERIOD   5
#define DBG_APP_SIM_LOG             (1)

#if DBG_APP_SIM_LOG
    #define dbg_app_log(fmt, ...)       LOG_MSG(fmt, ##__VA_ARGS__)
#else
    #define dbg_app_log(fmt, ...)
#endif


#define MAX_STRING  100
//#define DUMP_BOOT_CNTS

static char wakeup_event[][MAX_STRING]={
	{"[0]: PS_DPD : wakeup by (ext_force_pmu_dc_sync)"},
	{"[1]: PS_DPD wakeup by (RTC_timer_int)"},
	{"[2]: PS_DPD wakeup by (anti_tamp_int)"},
	{"[3]: PS_PD wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[4]: PS_PD wakeup by (ext_int_nxt_dc)"},
	{"[5]: PS_PD wakeup by (RTC_timer_int)"},
	{"[6]: PS_PD wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[7]: PS_PD wakeup by (CMP_int)"},
	{"[8]: PS_PD wakeup by (TS_int)"},
	{"[9]: PS_PD wakeup by (I2C_W_int)"},
	{"[10]: PS_PD wakeup by (REG_CPU_SCENARIO == 4'b0010 && SB_timer_int[0])"},
	{"[11]: PS_SCL wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[12]: PS_SCL wakeup by (~pmu_sc_active && Sensor_EXT_INT)"},
	{"[13]: PS_SCL wakeup by (ext_int_nxt_dc)"},
	{"[14]: PS_SCL wakeup by (RTC_timer_int)"},
	{"[15]: PS_SCL wakeup by (SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[16]: PS_SCL wakeup by (ADCC_int)"},
	{"[17]: PS_SCL wakeup by (TS_int)"},
	{"[18]: PS_SCL wakeup by (I2C_W_int)"},
	{"[19]: PS_SCL wakeup by (pmu_wdg_timeout_int)"},
	{"[20]: PS_SCH wakeup by ((REG_FORCE_EVENT_NSTATE==5'b10000) && REG_FORCE_EVENT_TRIG)"},
	{"[21]: PS_SCH wakeup by (ext_int_nxt_dc)"},
	{"[22]: PS_SCH wakeup by (RTC_timer_int)"},
	{"[23]: PS_SCH wakeup by (|SB_timer_int[5:1](VerA))(|SB_timer_int[8:1](VerB))"},
	{"[24]: PS_SCH wakeup by (ADCC_int)"},
	{"[25]: PS_SCH wakeup by (TS_int)"},
	{"[26]: PS_SCH wakeup by (I2C_W_int)"},
	{"[27]: PS_SCH wakeup by (pmu_wdg_timeout_int)"},
	{"[28]: PS_SCH wakeup by (WRDMAx_abnormal_int)"},
	{"[29]: PS_SCH wakeup by (DP_ABNORMAL_INT)"},
	{"[30]: PS_SCH wakeup VID Only by (DP_CDM_MOTION_INT)"},
	{"[31]: PS_SCH wakeup VIDAUD by (DP_CDM_MOTION_INT)"},
};

static char wakeup_event1[][MAX_STRING]={
	{"[0]: PS_DPD wakeup by (~pmu_sc_active &&PAD_AON_GPIO_0)"},
	{"[1]: PS_DPD wakeup by (~pmu_sc_active &&PAD_VMUTE)"},
	{"[2]: PS_DPD wakeup by (~pmu_sc_active && ext_int_nxt_dc)"},
	{"[8]: PS_PD wakeup by (anti_tamp_int)"},
	{"[16]: PS_SCL wakeup by (anti_tamp_int)"},
	{"[24]: PS_SCH wakeup by (SC_sen_noack)"},
	{"[25]: PS_SCH wakeup by (anti_tamp_int)"}
};


static void print_wakeup_event(uint32_t event, uint32_t event1)
{

	if((event & 0x1)  != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[0]);
	}
	if((event & 0x2) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[1]);
	}
	if((event & 0x4) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[2]);
	}
	if((event & 0x8) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[3]);
	}
	if((event & 0x10) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[4]);
	}
	if((event & 0x20) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[5]);
	}
	if((event & 0x40) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[6]);
	}
	if((event & 0x80) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[7]);
	}
	if((event & 0x100) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[8]);
	}
	if((event & 0x200) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[9]);
	}
	if((event & 0x400) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[10]);
	}
	if((event & 0x800) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[11]);
	}
	if((event & 0x1000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[12]);
	}
	if((event & 0x2000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[13]);
	}
	if((event & 0x4000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[14]);
	}
	if((event & 0x8000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[15]);
	}
	if((event & 0x10000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[16]);
	}
	if((event & 0x20000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[17]);
	}
	if((event & 0x40000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[18]);
	}
	if((event & 0x80000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[19]);
	}
	if((event & 0x100000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[20]);
	}
	if((event & 0x200000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[21]);
	}
	if((event & 0x400000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[22]);
	}
	if((event & 0x800000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[23]);
	}
	if((event & 0x1000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[24]);
	}
	if((event & 0x2000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[25]);
	}
	if((event & 0x4000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[26]);
	}
	if((event & 0x8000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[27]);
	}
	if((event & 0x10000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[28]);
	}
	if((event & 0x20000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[29]);
	}
	if((event & 0x40000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[30]);
	}
	if((event & 0x80000000) != 0)
	{
		dbg_app_log("event=%s\r\n", wakeup_event[31]);
	}

	if((event1 & 0x1)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[0]);
	}
	if((event1 & 0x2)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[1]);
	}
	if((event1 & 0x4)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[2]);
	}
	if((event1 & 0x100)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[3]);
	}
	if((event1 & 0x10000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[4]);
	}
	if((event1 & 0x1000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[5]);
	}
	if((event1 & 0x2000000)  != 0)
	{
		xprintf("event1=%s\r\n", wakeup_event1[6]);
	}

}

void getPMUExtIntStatus()
{
	uint8_t status;
	veneer_pm_ext_int_get(PMU_EXT_INT_TYPE_PA0_GPIO_DPD, &status);
	dbg_app_log("PAD_PA0 intstatus=0x%x\r\n", status);
}


void get_rtc_ip_int()
{
	uint32_t status;

#ifdef IP_rtc
	hx_drv_rtc_get_alarm_rawint_status(RTC_ID_0, &status);
	dbg_app_log("RTC_ID_0 raw status=%d\r\n", status);
	hx_drv_rtc_get_alarm_maskint_status(RTC_ID_0, &status);
	dbg_app_log("RTC_ID_0 mask status=%d\r\n", status);
#endif
}


void setRTC0_TimerWakeupPMU() {
	uint32_t alarm_en, alarm_cycle, time_cycle;
	uint32_t id = RTC_ID_0;
	RTC_ERROR_E ret;
	ret = hx_drv_rtc_clear_alarm_int_status(id);
	ret = hx_drv_rtc_enable(id, 0);
	/*Setup RTC0 5 secs alarm*/
	alarm_en = 1;

	time_cycle = 1000;
	alarm_cycle = time_cycle + WAKEUP_PERIOD;


	ret = hx_drv_rtc_set_alarm_cycle(id, alarm_en, alarm_cycle, NULL);
	ret = hx_drv_rtc_set_time_cycle(id, time_cycle);

}

void setRTC0WakeupPMU() {
	uint32_t alarm_en, alarm_cycle, time_cycle;
	uint32_t id = RTC_ID_0;
	RTC_ERROR_E ret;
	ret = hx_drv_rtc_clear_alarm_int_status(id);
	ret = hx_drv_rtc_read_val(id, &time_cycle);
	/*Setup RTC0 5 secs alarm*/
	alarm_en = 1;
	alarm_cycle = time_cycle + WAKEUP_PERIOD;
	ret = hx_drv_rtc_set_alarm_cycle(id, alarm_en, alarm_cycle, NULL);
	//dbg_app_log("setRTC0WakeupPMU ret=%d, alarm_cycle=0x%x, time_cycle=0x%x\r\n", ret, alarm_cycle, time_cycle);
}

void setRTC0() {
	rtc_time tm;
	uint32_t id = RTC_ID_0;
	RTC_ERROR_E ret;
	ret = hx_drv_rtc_enable(id, 0);
	tm.tm_year = 2023;
	tm.tm_mon = 8;
	tm.tm_mday = 16;
	tm.tm_hour = 10;
	tm.tm_min = 11;
	tm.tm_sec = 00;

	ret = hx_drv_rtc_set_time(id, &tm);
	//dbg_app_log("setRTC0 ret=%d\r\n", ret);
}


void setPS_DPD()
{
	PM_DPD_CFG_T cfg;
	SCU_LSC_CLK_CFG_T lsc_cfg;
	SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;
	PM_CFG_PWR_MODE_E mode;
	uint32_t freq;
	SCU_PLL_FREQ_E pmuwakeup_pll_freq;
	SCU_HSCCLKDIV_E pmuwakeup_cm55m_div;
	SCU_LSCCLKDIV_E pmuwakeup_cm55s_div;

	/*Get System Current Clock*/
	veneer_get_pmuwakeup_freq(&pmuwakeup_pll_freq, &pmuwakeup_cm55m_div, &pmuwakeup_cm55s_div);
	veneer_get_pllfreq(&freq);
	dbg_app_log("pmuwakeup_freq_type=%d, pmuwakeup_cm55m_div=%d, pmuwakeup_cm55s_div=%d\r\n", pmuwakeup_pll_freq, pmuwakeup_cm55m_div, pmuwakeup_cm55s_div);
	dbg_app_log("pmuwakeup_run_freq=%d\r\n", freq);

	mode = PM_MODE_PS_DPD;
	veneer_pm_get_defcfg_bymode(&cfg, mode);
	/*Setup bootrom clock speed when PMU Warm boot wakeup*/
	cfg.bootromspeed.bootromclkfreq = pmuwakeup_pll_freq;
	cfg.bootromspeed.pll_freq = freq;
	cfg.bootromspeed.cm55m_div = pmuwakeup_cm55m_div;
	cfg.bootromspeed.cm55s_div = pmuwakeup_cm55s_div;

	/*Setup CM55 Small can be reset*/
	cfg.cm55s_reset = SWREG_AON_PMUWAKE_CM55S_RERESET_YES;
#ifdef SUPPORT_PA0_WAKEUP
	/*UnMask PA0 Interrupt for PMU*/
	cfg.pmu_pad_pa0_mask = PM_IP_INT_MASK_ALL_UNMASK;
#else
	/*Mask PA0 Interrupt for PMU*/
	cfg.pmu_pad_pa0_mask = PM_IP_INT_MASK;
#endif
	/*Mask PA1 Interrupt for PMU*/
	cfg.pmu_pad_pa1_mask = PM_IP_INT_MASK;
#if defined(SUPPORT_RTC_WAKEUP) || defined(SUPPORT_RTC_WAKEUP2)
	/*UnMask RTC IP Interrupt fo PMU*/
	cfg.pmu_rtc_mask = PM_RTC_INT_MASK_ALLUNMASK;
#else
	/*Mask RTC IP Interrupt for PMU*/
	cfg.pmu_rtc_mask = PM_RTC_INT_MASK_ALLMASK;
#endif
	/*Mask ANTI Tamper Interrupt for PMU*/
	cfg.pmu_anti_mask = PM_IP_INT_MASK;
	/*No Debug Dump message*/
	cfg.support_debugdump = 0;
	/*Not DCDC pin output*/
	cfg.pmu_dcdc_outpin = PM_CFG_DCDC_MODE_VMUTE;

#ifdef SUPPORT_PA0_WAKEUP
	/*Set PA0 Pinmux that PMU can detect level high trigger wakeup*/
	veneer_sys_set_PA0_pinmux(SCU_PA0_PINMUX_PMU_SINT0);
#endif
	dbg_app_log("speed=%d,reset=%d\r\n", cfg.bootromspeed.bootromclkfreq, cfg.cm55s_reset);
	dbg_app_log("pmu_rtc_mask=0x%x,pmu_pad_pa0_mask=0x%x,pmu_pad_pa1_mask=0x%x\r\n", cfg.pmu_rtc_mask,cfg.pmu_pad_pa0_mask,cfg.pmu_pad_pa1_mask);
	dbg_app_log("debug=%d, reset=%d, mode=%d\r\n", cfg.support_debugdump, cfg.cm55s_reset, mode);
	dbg_app_log("dcdcpin=%d, pmu_anti_mask=0x%x\r\n", cfg.pmu_dcdc_outpin, cfg.pmu_anti_mask);
	dbg_app_log("freq=%d, cm55mdiv=%d,cm55sdiv=%d\r\n", freq, cfg.bootromspeed.cm55m_div, cfg.bootromspeed.cm55s_div);

	/*Set PMU DPD configuration*/
	veneer_pm_cfg_set(&cfg, NULL, mode);

#ifdef SUPPORT_RTC_WAKEUP
	/*Setup RTC0 5 secs wakeup*/
	setRTC0_TimerWakeupPMU();
#endif
#ifdef SUPPORT_RTC_WAKEUP2
	/*Setup RTC0 5 secs wakeup*/
	setRTC0WakeupPMU();
#endif

	/*Use PMU lib to control HSC_CLK and LSC_CLK so set thoes parameter to 0*/
	memset(&hsc_cfg, 0, sizeof(SCU_PDHSC_HSCCLK_CFG_T));
	memset(&lsc_cfg, 0, sizeof(SCU_LSC_CLK_CFG_T));
	/*Trigger to PMU mode*/
	veneer_pm_trigger(&hsc_cfg, &lsc_cfg, PM_CLK_PARA_CTRL_BYPMLIB);
}

/*******************************************************************************
 * Code
 ******************************************************************************/
/*!
 * @brief Main function
 */
int pmu_dpd_app(void) {
	uint32_t wakeup_event,wakeup_event1;

	dbg_app_log("NS PMU DPD Sample Code\r\n");
	/*1. get wakeup event*/
	veneer_pm_get_event(&wakeup_event, &wakeup_event1);
    dbg_app_log("WakeupEvt=0x%x\r\n", wakeup_event);
    dbg_app_log("WakeupEvt1=0x%x\r\n", wakeup_event1);
    print_wakeup_event(wakeup_event, wakeup_event1);


	if((wakeup_event == PMU_WAKEUP_NONE) && (wakeup_event1 == PMU_WAKEUPEVENT1_NONE))
	{
		/*Cold boot*/
		/*Get PA0 or PA1 INT Status*/
	    getPMUExtIntStatus();
		/*Get RTC INT Status*/
	    get_rtc_ip_int();

		/*Clear PMU Wakeup Event*/
		veneer_pm_clear_event();
#ifdef IP_rtc
		/*clear RTC INT status*/
	    hx_drv_rtc_clear_alarm_int_status(RTC_ID_0);
#endif
		/*Setup PMU DPD*/
#ifdef SUPPORT_RTC_WAKEUP2
		setRTC0();
#endif
		setPS_DPD();
	}else{
	    rtc_time tm;
        hx_drv_rtc_read_time(RTC_ID_0, &tm);
		dbg_app_log("RTC0 time %d-%d-%d %d:%d:%d\r\n",
        tm.tm_year,
        tm.tm_mon,
        tm.tm_mday,
        tm.tm_hour,
        tm.tm_min,
        tm.tm_sec);

		/*Warm boot*/
		/*Get PA0 or PA1 INT Status*/
	    getPMUExtIntStatus();
		/*Get RTC INT Status*/
	    get_rtc_ip_int();
#ifdef IP_rtc
		/*clear RTC INT status*/
		hx_drv_rtc_clear_alarm_int_status(RTC_ID_0);
#endif
		dbg_app_log("warm boot\r\n");

		/*Clear PMU Wakeup Event*/
		veneer_pm_clear_event();
		/*Setup PMU DPD*/
	    setPS_DPD();
	}

	while (1) {
		/* This point should never be reached */
	}

}
