#include "WE2_core.h"
#include "xprintf.h"
#include "board.h"
#include "veneer_sys_ctrl.h"
#include "veneer_timer_ctrl.h"
#include "hx_drv_timer.h"
#include "cmsis_os2.h"                  // ::CMSIS:RTOS2
#include "FreeRTOS.h"                   // ARM.FreeRTOS::RTOS:Core
#include "task.h"                       // ARM.FreeRTOS::RTOS:Core

static volatile uint32_t cm55m_s_timer_event_cnt = 0;
static volatile uint32_t cm55m_s_timer_event_flag = 0;

void timer_event(uint32_t event)
{
    cm55m_s_timer_event_cnt++;
    cm55m_s_timer_event_flag = 1;
}

static void app_main (void *arg) {
    /* Allocate secure contex for this task (because it calls secure side) */
    portALLOCATE_SECURE_CONTEXT (configMINIMAL_SECURE_STACK_SIZE);
    printf("Non-secure RTOS2 FreeRTOS app_main Thread running ...\r\n");

    uint32_t version1;
    uint32_t version2;
    printf("call nsc sys_get_version\r\n");
    SCU_ERROR_E ret1 = veneer_sys_get_version(&version1, &version2);
    printf("ret = 0x%08X, version1 = 0x%08X, version1 = 0x%08X\r\n", ret1, version1, version1);

    TIMER_CFG_T cfg;
    cfg.period = 1000;
    cfg.mode = TIMER_MODE_PERIODICAL;
    cfg.ctrl = TIMER_CTRL_CPU;
    cfg.state = TIMER_STATE_DC;
    printf("call nsc timer_cm55m_start\r\n");
    TIMER_ERROR_E ret2 = veneer_timer_cm55m_start(&cfg, timer_event);
    printf("ret = 0x%08X\r\n", ret2);

    while (1) {
      if (cm55m_s_timer_event_flag) {
          cm55m_s_timer_event_flag = 0;
          printf("cm55m_s_event_cnt = 0x%08X\r\n", cm55m_s_timer_event_cnt);
      }
    }
}

int main(void)
{
    board_init();

    (void) osKernelInitialize();

    osThreadNew(app_main, NULL, NULL);    // Create application main thread

    if (osKernelGetState() == osKernelReady) {
        osKernelStart();                    // Start thread execution
    }

    for(;;) {}

    return 0;
}
