#include "WE2_core.h"
#include "board.h"
#include "xprintf.h"
#include "hx_drv_scu_export.h"
#include "hx_drv_scu.h"
#include "CM55M_TrustZone_FW_mem.h"

/* TZ_START_NS: Start address of non-secure application */
#define TZ_START_NS  CM55M_NS_APP_ROM_BASE
 
/* typedef for non-secure callback functions */
typedef void (*funcptr_void) (void) __attribute__((cmse_nonsecure_call));

int main(void) {
    funcptr_void NonSecure_ResetHandler;
    uint32_t ns_entry;
    uint32_t ns_msp;

    board_init();

    hx_drv_scu_set_PB0_pinmux(SCU_PB0_PINMUX_UART0_RX_1);
    hx_drv_scu_set_PB1_pinmux(SCU_PB1_PINMUX_UART0_TX_1);

    printf("core0 hello_word_s running ...\r\n");

    ns_msp = *((uint32_t *)(TZ_START_NS));
    ns_entry = *((uint32_t *)((TZ_START_NS) + 4U));

    printf("ns_start addr = 0x%08X\r\n", TZ_START_NS);
    printf("get ns_msp = 0x%08X\r\n", ns_msp);
    printf("get ns_entry = 0x%08X\r\n", ns_entry);

    SCB_NS->VTOR = TZ_START_NS;

    /* Set non-secure main stack (MSP_NS) */
    __TZ_set_MSP_NS(ns_msp);

    /* Get non-secure reset handler */
    NonSecure_ResetHandler = (funcptr_void)(ns_entry);

    printf("NonSecure_ResetHandler\r\n");

    hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_RESET);
    hx_drv_scu_set_cm55s_state(SCU_CM55S_STATE_NORMAL);
    hx_drv_scu_set_CM55S_CPUWAIT(SCU_CM55_CPU_RUN);

    /* Start non-secure state software application */
    NonSecure_ResetHandler();

    /* Non-secure software does not return, this code is not executed */
    
    for(;;) {}
}
