/*
 * dp_task.c
 *
 *  Created on: 2022/2/22
 *      Author: 902447
 */

#ifndef APP_SCENARIO_APP_FREERTOS_TZ_S_ONLY_SAMPLE_DP_TASK_C_
#define APP_SCENARIO_APP_FREERTOS_TZ_S_ONLY_SAMPLE_DP_TASK_C_

#include <stdio.h>
#include <assert.h>
#include <stdbool.h>
#include <stdint.h>
#include <string.h>
#include <stdlib.h>


#include "WE2_device.h"
#include "WE2_core.h"
#include "WE2_debug.h"
#include "board.h"
#include "dp_task.h"
#include "cisdp_cfg.h"
#include "cisdp_sensor.h"
#ifdef IP_xdma
#include "hx_drv_xdma.h"
#include "sensor_dp_lib.h"
#endif
#include "hx_drv_swreg_aon.h"
#include "pmu_pd_sample.h"

#define DBG_APP_DP_LOG             (1)

#if DBG_APP_DP_LOG
    #define dbg_dp_printf(fmt, ...)       xprintf(fmt, ##__VA_ARGS__)
#else
    #define dbg_dp_printf(fmt, ...)
#endif

//#define NO_PMU

static volatile uint32_t g_cur_frame = 0;
static volatile uint32_t g_frame_ready = 0;
static volatile uint32_t g_xdma_abnormal = 0;
static volatile uint32_t g_rs_abnormal = 0;
static volatile uint32_t g_hog_abnormal = 0;
static volatile uint32_t g_rs_frameready = 0;
static volatile uint32_t g_hog_frameready = 0;
static volatile uint32_t g_md_detect = 0;
static volatile uint32_t g_time = 0;
static volatile uint32_t g_prev_time = 0;
static volatile uint32_t g_wdt1_timeout = 0;
static volatile uint32_t g_wdt2_timeout = 0;
static volatile uint32_t g_wdt3_timeout = 0;
static volatile uint32_t g_spi_send = 0;
static volatile uint32_t g_spi_send_datasize = 0;
static volatile uint32_t g_spi_send_cdmtype = 0;
static volatile uint32_t g_spi_send_hotsize = 0;
static volatile uint32_t g_spi_send_highsize = 0;
static volatile uint32_t g_spi_send_lowsize = 0;
static volatile uint8_t g_hw5x5_yuv422 = 0;


static void app_dplib_cb(SENSORDPLIB_STATUS_E event)
{
	uint32_t de0_count, conv_count;
	uint16_t af_framecnt;
	uint16_t be_framecnt;
	//dbg_dp_printf("event = %d\n", event);

	if(event != SENSORDPLIB_STATUS_TIMER_FIRE_APP_NOTREADY)
	{
		hx_drv_edm_get_de_count(0, &de0_count);
		//dbg_dp_printf("de0_count = 0x%x\n", de0_count);
		hx_drv_edm_get_conv_de_count(&conv_count);
		//dbg_dp_printf("conv_count = 0x%x\n", conv_count);
	}
	switch(event)
	{
	case SENSORDPLIB_STATUS_EDM_WDT1_TIMEOUT:
		dbg_dp_printf("CB WDT1 Timeout\n");
		g_wdt1_timeout = 1;
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		break;
	case SENSORDPLIB_STATUS_EDM_WDT2_TIMEOUT:
		dbg_dp_printf("CB WDT2 Timeout\n");
		g_wdt2_timeout = 1;
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		break;
	case SENSORDPLIB_STATUS_EDM_WDT3_TIMEOUT:
		dbg_dp_printf("CB WDT3 Timeout\n");
		g_wdt3_timeout = 1;
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		break;
	case SENSORDPLIB_STATUS_SENSORCTRL_WDT_OUT:
		/*
		 * TODO error happen need check sensor
		 * 1. SWRESET Sensor Control & DP
		 * 2. restart streaming flow
		 */
		dbg_dp_printf("WDT OUT %d\n", event);
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		break;

	case SENSORDPLIB_STATUS_CDM_FIFO_OVERFLOW:
	case SENSORDPLIB_STATUS_CDM_FIFO_UNDERFLOW:
		dbg_dp_printf("CDM_FIFO_ERROR %d\n", event);
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		g_xdma_abnormal = 1;
		break;

	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL1:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL2:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL3:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL4:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL5:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL6:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL7:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL8:
	case SENSORDPLIB_STATUS_XDMA_WDMA1_ABNORMAL9:

	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL1:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL2:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL3:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL4:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL5:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL6:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_ABNORMAL7:

	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL1:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL2:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL3:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL4:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL5:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL6:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL7:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL8:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_ABNORMAL9:

		dbg_dp_printf("WDMA123 abnormal %d\n", event);
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		g_xdma_abnormal = 1;
		break;

	case SENSORDPLIB_STATUS_XDMA_RDMA_ABNORMAL1:
	case SENSORDPLIB_STATUS_XDMA_RDMA_ABNORMAL2:
	case SENSORDPLIB_STATUS_XDMA_RDMA_ABNORMAL3:
	case SENSORDPLIB_STATUS_XDMA_RDMA_ABNORMAL4:
	case SENSORDPLIB_STATUS_XDMA_RDMA_ABNORMAL5:
		dbg_dp_printf("RDMA abnormal %d\n", event);
		g_xdma_abnormal = 1;
    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
		break;

	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL1:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL2:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL3:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL4:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL5:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL6:
	case SENSORDPLIB_STATUS_RSDMA_ABNORMAL7:
		/*
		 *  error happen need
		 * 1. SWRESET RS & RS DMA
		 * 2. Re-run flow again
		 */
		dbg_dp_printf("RSDMA abnormal %d\n", event);
	    g_rs_abnormal = 1;
		break;

	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL1:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL2:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL3:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL4:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL5:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL6:
	case SENSORDPLIB_STATUS_HOGDMA_ABNORMAL7:
		/*
		 *  error happen need
		 * 1. SWRESET HOG & HOG DMA
		 * 2. Re-run flow again
		 */
		dbg_dp_printf("HOGDMA abnormal %d\n", event);
		g_hog_abnormal = 1;
		break;

	case SENSORDPLIB_STATUS_CDM_MOTION_DETECT:
		/*
		 * app anything want to do
		 * */
		g_md_detect = 1;
		dbg_dp_printf("Motion Detect\n");
		break;
	case SENSORDPLIB_STATUS_XDMA_FRAME_READY:
    	g_cur_frame++;
        // already capture user wanted frame number
    	g_frame_ready = 1;
		dbg_dp_printf("FRAME_READY\n");
		break;
	case SENSORDPLIB_STATUS_XDMA_WDMA1_FINISH:
	case SENSORDPLIB_STATUS_XDMA_WDMA2_FINISH:
	case SENSORDPLIB_STATUS_XDMA_WDMA3_FINISH:
	case SENSORDPLIB_STATUS_XDMA_RDMA_FINISH:
		break;

	case SENSORDPLIB_STATUS_RSDMA_FINISH:
		/*
		 * RS Frame result ready
		 */
		g_rs_frameready = 1;
		break;
	case SENSORDPLIB_STATUS_HOGDMA_FINISH:
		/*
		 * HOG Frame result ready
		 */
		g_hog_frameready = 1;
		break;
	case SENSORDPLIB_STATUS_TIMER_FIRE_APP_NOTREADY:
		g_time++;
//		hx_drv_edm_get_frame_count(&af_framecnt, &be_framecnt);
//		dbg_dp_printf("af_framecnt=%d,be_framecnt=%d\n",af_framecnt,be_framecnt);
		break;
	case SENSORDPLIB_STATUS_TIMER_FIRE_APP_READY:
		g_time++;
//		hx_drv_edm_get_frame_count(&af_framecnt, &be_framecnt);
//		dbg_dp_printf("af_framecnt=%d,be_framecnt=%d\n",af_framecnt,be_framecnt);
		break;
	default:
		break;
	}
}


void dp_var_init()
{
	g_cur_frame = 0;
	g_xdma_abnormal = 0;
	g_frame_ready = 0;
	g_rs_abnormal = 0;
	g_hog_abnormal = 0;
	g_rs_frameready = 0;
	g_hog_frameready = 0;
	g_md_detect = 0;
	g_time = 0;
	g_wdt1_timeout = 0;
	g_wdt2_timeout = 0;
	g_wdt3_timeout = 0;
	g_prev_time = 0;
	g_spi_send = 0;
	g_spi_send_datasize = 0;
	g_spi_send_cdmtype = 0;
	g_spi_send_hotsize = 0;
	g_spi_send_highsize = 0;
	g_spi_send_lowsize = 0;
	g_hw5x5_yuv422 = 0;

#ifdef INP_HVSYNCINT_DUMP
	g_inp_vsin_cnt = 0;
	g_inp_vsout_cnt = 0;
	g_inp_hsin_cnt = 0;
	g_inp_hsout_cnt = 0;
#endif
}

void app_start_aos_stream(uint32_t sensorctrl_start)
{
#ifdef SUPPORT_SEN_NOREINIT
	SWREG_AON_SENSORINIT_E init;
	hx_drv_swreg_aon_get_sensorinit(&init);
	if(init == SWREG_AON_SENSOR_INIT_NO)
	{
    	xprintf("\r\nCIS AOS Init\r\n");
	    if(cisdp_sensor_init(CISDP_INIT_TYPE_AOS) < 0)
	    {
	    	xprintf("\r\nCIS AOS Init fail\r\n");
	    	APP_BLOCK_FUNC();
	    }else{
	    	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_YES);
	    }
	}
#else
    if(cisdp_sensor_init(CISDP_INIT_TYPE_AOS) < 0)
    {
    	xprintf("\r\nCIS AOS Init fail\r\n");
    	APP_BLOCK_FUNC();
    }
#endif

    dp_var_init();
    if(cisdp_dp_init(CISDP_INIT_TYPE_AOS, SENSORDPLIB_PATH_INT_INP_HW5X5_JPEG, app_dplib_cb) < 0)
    {
    	xprintf("\r\nDATAPATH AOS Init fail\r\n");
    	APP_BLOCK_FUNC();
    }

#ifdef SUPPORT_SEN_NOREINIT
	if(init == SWREG_AON_SENSOR_INIT_NO)
	{
	    cisdp_sensor_start_AOS(sensorctrl_start, 1);
	}else{
	    cisdp_sensor_start_AOS(sensorctrl_start, 0);
	}
#else
    //PMU use pass 0
    cisdp_sensor_start_AOS(sensorctrl_start, 1);
#endif
}

void app_setup_dplib()
{

	dbg_dp_printf( "app_setup_dplib start\n");

#ifdef NO_PMU
	app_start_aos_stream(1);
#else
	app_start_aos_stream(0);
#endif

	dbg_dp_printf( "app_setup_dplib end\n");
#ifdef NO_PMU
	while(1)
	{
		if(g_frame_ready == 1){
			app_dump_jpeginfo();
			g_frame_ready = 0;
			sensordplib_retrigger_capture();
		}
	}
#endif
}

void app_stop_dplib()
{
	dbg_dp_printf( "app_stop_dplib start\n");
	cisdp_sensor_stop();
#ifdef SUPPORT_SEN_NOREINIT
	hx_drv_swreg_aon_set_sensorinit(SWREG_AON_SENSOR_INIT_NO);
#endif
	dbg_dp_printf( "app_stop_dplib end\n");
}

void app_dump_jpeginfo()
{
	uint8_t jpegloop_flag;
	uint8_t nextjpeg_frame_no;
	uint8_t jpeg_total_slot;
	uint32_t jpegip_size;

	hx_drv_xdma_get_WDMA2_loopflag(&jpegloop_flag);
	hx_drv_xdma_get_WDMA2NextFrameIdx(&nextjpeg_frame_no);
	hx_drv_xdma_get_WDMA2_bufferNo(&jpeg_total_slot);
	dbg_dp_printf("jpegloop_flag=%d,nextjpeg_frame_no=%d,jpeg_total_slot=%d\n",
			jpegloop_flag, nextjpeg_frame_no, jpeg_total_slot);
	hx_drv_jpeg_get_EncOutRealMEMSize(&jpegip_size);
	dbg_dp_printf("jpegip_size=0x%x\n", jpegip_size);
}

#endif /* APP_SCENARIO_APP_FREERTOS_TZ_S_ONLY_SAMPLE_DP_TASK_C_ */
