/**
 * @file hx_drv_CIS_common.c
 * @author himax/902447
 * @brief 
 * @version V1.0.0
 * @date 2019-06-24
 * 
 * @copyright (C) COPYRIGHT, Himax, Inc. ALL RIGHTS RESERVED
 * 
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "WE2_device.h"
#include "board.h"
#include "BITOPS.h"
#ifdef FREERTOS
#ifdef TRUSTZONE_SEC_ONLY
/* FreeRTOS kernel includes. */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "timers.h"
#endif
#endif
#include "dev_common.h"
#include "xprintf.h"
#include "hx_drv_timer.h"
#ifdef IP_timer
#include "timer_interface.h"
#endif
#include "hx_drv_CIS_common.h"
#include "hx_drv_sensorctrl.h"


#ifdef NSC
#include "veneer_sys_ctrl.h"
#else
#include "hx_drv_scu.h"
#endif

#include "driver_interface.h"

static uint8_t g_slave_id = HX_CIS_SLAVE_ID;
static CIS_XHSHUTDOWN_INDEX_E g_xshutdown_pin = (CIS_XHSHUTDOWN_INDEX_E)AON_GPIO2;
static uint8_t xsleep_default_val = 1;
static uint8_t cis_soi_init = 0;

HX_CIS_ERROR_E hx_drv_cis_init(CIS_XHSHUTDOWN_INDEX_E xshutdown_pin,
		uint8_t mclk_div) {

    SENSORCTRL_MCLKCTRL_E mclkctrl;
    GPIO_INDEX_E iomux_idx;
    if(mclk_div == SENSORCTRL_MCLK_NO)
    {
    	hx_drv_sensorctrl_set_MCLK(0, 1);
    }else{
    	hx_drv_sensorctrl_set_MCLK(1, mclk_div);
    }

	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

	if(cis_soi_init == 1)
	{
	    xprintf("CIS_SOIK351P Power-On Sequence \n");

	    //default set Trig Low
	    hx_drv_sensorctrl_set_trigger_ctrl(SENSORCTRL_TRIGGER_BY_CPU);
	    hx_drv_sensorctrl_set_trigger_val(0);

	    hx_drv_sensorctrl_set_xSleepCtrl(SENSORCTRL_XSLEEP_BY_CPU);
	    hx_drv_sensorctrl_set_xSleep(0);

	    g_xshutdown_pin = xshutdown_pin;
	    if(xshutdown_pin != CIS_XHSUTDOWN_IOMUX_NONE)
	    {
	        iomux_idx = (GPIO_INDEX_E)xshutdown_pin;
	        hx_drv_sensorctrl_set_xShutdown(iomux_idx, 0);
	    }

	    hx_drv_timer_cm55x_delay_us(50, TIMER_STATE_DC);

	    hx_drv_sensorctrl_set_xSleepCtrl(SENSORCTRL_XSLEEP_BY_CPU);
	    hx_drv_sensorctrl_set_xSleep(1);

	    g_xshutdown_pin = xshutdown_pin;
	    if(xshutdown_pin != CIS_XHSUTDOWN_IOMUX_NONE)
	    {
	        iomux_idx = (GPIO_INDEX_E)xshutdown_pin;
	        hx_drv_sensorctrl_set_xShutdown(iomux_idx, 1);
	        //		board_delay_cycle(1* BOARD_SYS_TIMER_MS_CONV);
	        hx_drv_timer_cm55x_delay_ms(1, TIMER_STATE_DC);
	        hx_drv_sensorctrl_set_xShutdown(iomux_idx, 0);
	        //		board_delay_cycle(500* BOARD_SYS_TIMER_US_CONV);
	        hx_drv_timer_cm55x_delay_us(500, TIMER_STATE_DC);
	    }
	}
	else
	{
        hx_drv_sensorctrl_set_xSleepCtrl(SENSORCTRL_XSLEEP_BY_CPU);
        hx_drv_sensorctrl_set_xSleep(0);

        g_xshutdown_pin = xshutdown_pin;
        if(xshutdown_pin != CIS_XHSUTDOWN_IOMUX_NONE)
        {
            iomux_idx = (GPIO_INDEX_E)xshutdown_pin;
            hx_drv_sensorctrl_set_xShutdown(iomux_idx, 0);
    //		board_delay_cycle(1* BOARD_SYS_TIMER_MS_CONV);
            hx_drv_timer_cm55x_delay_ms(1, TIMER_STATE_DC);
            hx_drv_sensorctrl_set_xShutdown(iomux_idx, 1);
    //		board_delay_cycle(500* BOARD_SYS_TIMER_US_CONV);
            hx_drv_timer_cm55x_delay_us(500, TIMER_STATE_DC);
        }

        hx_drv_sensorctrl_set_xSleepCtrl(SENSORCTRL_XSLEEP_BY_CPU);
        if(xsleep_default_val == 0)
        {
            hx_drv_sensorctrl_set_xSleep(0);
        }
        else
        {
            hx_drv_sensorctrl_set_xSleep(1);
        }
	}

	return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_set_slaveID(uint8_t slave_id) {
	g_slave_id = slave_id;
	return HX_CIS_NO_ERROR;
}
HX_CIS_ERROR_E hx_drv_cis_get_slaveID(uint8_t *slave_id) {
	*slave_id = g_slave_id;
	return HX_CIS_NO_ERROR;
}

/* write by reg table */
HX_CIS_ERROR_E hx_drv_cis_setRegTable(HX_CIS_SensorSetting_t *pSensorSetting,
		uint16_t Length) {
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;
	uint32_t i = 0;
	uint8_t val;
	uint16_t regAddr;

	//pin mux set to default
//#ifdef TRUSTZONE_SEC
//	hx_drv_scu_set_SEN_GPIO_pinmux(0x00000000);
//#else
//#ifndef TRUSTZONE
//	hx_drv_scu_set_SEN_GPIO_pinmux(0x00000000);
//#else
//	veneer_sys_set_sensorgpio_pinmux(0x00000000);
//#endif
//#endif

	if (Length == 0) {
		xprintf("setRegTable fail: no item\r\n");
		return HX_CIS_ERROR_NOT_SUPPORT;
	}

#ifdef SUPPROT_CIS_DEBUG_PRINT
	xprintf("\n");
	xprintf("hx_drv_cis_setRegTable_Sz=%d\r\n",Length);
#endif

	for (i = 0; i < Length; i++) {
		status = HX_CIS_NO_ERROR;
		if (HX_CIS_I2C_Action_W == pSensorSetting[i].I2C_ActionType) {
			val = pSensorSetting[i].Value;
			regAddr = pSensorSetting[i].RegAddree;

//			xprintf("{HX_CIS_I2C_Action_W, 0x%04x, 0x%02x},\n", pSensorSetting[i].RegAddree, pSensorSetting[i].Value);

			for (uint8_t idx = 0; idx < HX_CIS_I2C_RETRY_TIME; idx++) {
#ifdef SUPPROT_CIS_DEBUG_PRINT
				xprintf("hx_drv_cis_set_reg(0x%04x, 0x%02x) \n", regAddr, val);
#endif
				HX_CIS_ERROR_E i2c_state = hx_drv_cis_set_reg(regAddr, val, 0);
				if (i2c_state != HX_CIS_NO_ERROR) {
					xprintf("    retry=%d, (regAddr=0x%04x, val=0x%02x) Fail (%d)\r\n",idx,regAddr, val, i2c_state);

					/**
					 * workaround for HM0360 reset noack
					 */
					if((regAddr == 0x0103 || regAddr == 0x0100) && (i2c_state == HX_CIS_I2C_DATA_NO_ACK || i2c_state == HX_CIS_I2C_LOST_BUS))
					{
						xprintf("HM0360 reset workaround\r\n");
						break;
					}

					if (idx >= (HX_CIS_I2C_RETRY_TIME - 1))
						return HX_CIS_ERROR_I2C;
				} else {
					if (idx > 0)
						xprintf("    retry=%d, (regAddr=0x%04x, val=0x%02x)  Success\r\n",idx,regAddr, val);
					break;
				}
			}
		} else if (HX_CIS_I2C_Action_R == pSensorSetting[i].I2C_ActionType) {
			val = 0xFF; //default
			regAddr = pSensorSetting[i].RegAddree;
			if (hx_drv_cis_get_reg(regAddr, &val) != HX_CIS_NO_ERROR) {
				return HX_CIS_ERROR_I2C;
			}
			pSensorSetting[i].Value = val;
		} else if (HX_CIS_I2C_Action_S == pSensorSetting[i].I2C_ActionType) {
			board_delay_ms(pSensorSetting[i].RegAddree);
			status = HX_CIS_NO_ERROR;
		} else if (HX_CIS_I2C_Action_W_1Byte_Reg == pSensorSetting[i].I2C_ActionType) {
			val = pSensorSetting[i].Value;
			regAddr = pSensorSetting[i].RegAddree;

//			xprintf("{HX_CIS_I2C_Action_W, 0x%04x, 0x%02x},\n", pSensorSetting[i].RegAddree, pSensorSetting[i].Value);

			for (uint8_t idx = 0; idx < HX_CIS_I2C_RETRY_TIME; idx++) {
#ifdef SUPPROT_CIS_DEBUG_PRINT
				xprintf("hx_drv_cis_set_reg(0x%04x, 0x%02x) \n", regAddr, val);
#endif
				HX_CIS_ERROR_E i2c_state = hx_drv_cis_set_reg_1byte((regAddr&0xFF), val, 0);
				if (i2c_state != HX_CIS_NO_ERROR) {
					xprintf("    retry=%d, (regAddr1Byte=0x%02x, val=0x%02x) Fail (%d)\r\n",idx,regAddr, val, i2c_state);

					if (idx >= (HX_CIS_I2C_RETRY_TIME - 1))
						return HX_CIS_ERROR_I2C;
				} else {
					if (idx > 0)
						xprintf("    retry=%d, (regAdd1Byter=0x%02x, val=0x%02x)  Success\r\n",idx,regAddr, val);
					break;
				}
			}
		} else if (HX_CIS_I2C_Action_R_1Byte_Reg == pSensorSetting[i].I2C_ActionType) {
			val = 0xFF; //default
			regAddr = pSensorSetting[i].RegAddree;
			if (hx_drv_cis_get_reg_1byte((regAddr&0xFF), &val) != HX_CIS_NO_ERROR) {
				return HX_CIS_ERROR_I2C;
			}
			pSensorSetting[i].Value = val;

		} else {
			xprintf("\n\rsetting index = %d, unknow action=%d ", i ,pSensorSetting[i].I2C_ActionType);
			status = HX_CIS_ERROR_INVALID_PARAMETERS;
			return status;
		}
	}

#ifdef SUPPROT_CIS_DEBUG_PRINT
	xprintf("\n");
#endif

	return status;
}

/**
 * \brief Get Configuration to CIS Sensor by I2C Master.
 *
 * \param[in] pSensorSetting Configuration table for CIS Sensor
 * \param[in] Length Configuration table Length for CIS Sensor
 * \return HX_CIS_ERROR_E.
 * */
HX_CIS_ERROR_E hx_drv_cis_getRegTable(HX_CIS_SensorSetting_t *pSensorSetting,
		uint16_t Length) {
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;
	uint32_t i = 0;
	uint8_t val;
	uint16_t regAddr;

#ifdef SUPPROT_CIS_DEBUG_PRINT
	xprintf("\n");
	xprintf("hx_drv_cis_setRegTable_Sz=%d\r\n",Length);
#endif

	for (i = 0; i < Length; i++) {
		status = HX_CIS_NO_ERROR;
		if ((HX_CIS_I2C_Action_R == pSensorSetting[i].I2C_ActionType)
				|| (HX_CIS_I2C_Action_W == pSensorSetting[i].I2C_ActionType)) {
			val = 0xFF; //default
			regAddr = pSensorSetting[i].RegAddree;
			if (hx_drv_cis_get_reg(regAddr, &val) != HX_CIS_NO_ERROR) {
				return HX_CIS_ERROR_I2C;
			}
			pSensorSetting[i].Value = val;
			xprintf("0x%04x=0x%02x\r\n",regAddr, val);
		} else if (HX_CIS_I2C_Action_S == pSensorSetting[i].I2C_ActionType) {
			status = HX_CIS_NO_ERROR;
		}
	}

#ifdef SUPPROT_CIS_DEBUG_PRINT
	xprintf("\n");
#endif

	return status;
}

HX_CIS_ERROR_E hx_drv_cis_set_reg(uint16_t addr, uint8_t val,
		uint8_t cmu_update) {
	uint8_t rwBuffer[HX_CIS_I2C_DATA_BYTE] = { 0x00 };
	uint8_t regLen = HX_CIS_I2C_ADDR_BYTE;
	uint8_t regAddr[HX_CIS_I2C_ADDR_BYTE];
	int32_t retI2C = 0;

    SENSORCTRL_MCLKCTRL_E mclkctrl;
	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

    //pin mux set to default
	drv_interface_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_0, SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0);

	regAddr[0] = (addr >> 8) & 0xFF;
	regAddr[1] = addr & 0xFF;

	rwBuffer[0] = val;

	retI2C = hx_drv_i2cm_write_data(HX_CIS_IIC_M_ID, g_slave_id, regAddr, regLen, rwBuffer, HX_CIS_I2C_DATA_BYTE);
	if(retI2C < E_OK)
	{
#ifdef SUPPROT_CIS_DEBUG_PRINT
		xprintf("hm01B0_set_reg I2C fail\r\n");
#endif
//		return HX_CIS_ERROR_I2C;
		return retI2C;
	}


	if(cmu_update)
	{
		if(hx_drv_cis_CMU_Update() != HX_CIS_NO_ERROR)
		{
#ifdef SUPPROT_CIS_DEBUG_PRINT
			xprintf("hx_drv_cis_CMU_Update fail\r\n");
#endif
			return HX_CIS_ERROR_I2C;
		}
	}
	return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_set_reg_1byte(uint8_t addr, uint8_t val,
		uint8_t cmu_update) {
	uint8_t rwBuffer[HX_CIS_I2C_DATA_BYTE] = { 0x00 };
	uint8_t regLen = 1;
	uint8_t regAddr[1];
	int32_t retI2C = 0;

    SENSORCTRL_MCLKCTRL_E mclkctrl;
	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

    //pin mux set to default
	drv_interface_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_0, SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0);

	regAddr[0] = addr;
	rwBuffer[0] = val;

	retI2C = hx_drv_i2cm_write_data(HX_CIS_IIC_M_ID, g_slave_id, regAddr, regLen, rwBuffer, HX_CIS_I2C_DATA_BYTE);
	if(retI2C < E_OK)
	{
#ifdef SUPPROT_CIS_DEBUG_PRINT
		xprintf("hm01B0_set_reg I2C fail\r\n");
#endif

		return retI2C;
	}


	if(cmu_update)
	{
		if(hx_drv_cis_CMU_Update() != HX_CIS_NO_ERROR)
		{
#ifdef SUPPROT_CIS_DEBUG_PRINT
			xprintf("hx_drv_cis_CMU_Update fail\r\n");
#endif
			return HX_CIS_ERROR_I2C;
		}
	}
	return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_get_reg(uint16_t addr, uint8_t *val) {
	uint8_t RegByteCount = 2;
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;
	uint8_t rwBuffer[HX_CIS_I2C_DATA_BYTE] = { 0x00 };
	uint8_t regAddr[HX_CIS_I2C_ADDR_BYTE];
	int32_t retI2C = 0;

    SENSORCTRL_MCLKCTRL_E mclkctrl;
	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

    //pin mux set to default
	drv_interface_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_0, SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0);

	*val = 0;

	regAddr[0] = (addr >> 8) & 0xFF;
	regAddr[1] = addr & 0xFF;

    retI2C = hx_drv_i2cm_write_restart_read(HX_CIS_IIC_M_ID, g_slave_id, regAddr, RegByteCount, rwBuffer, HX_CIS_I2C_DATA_BYTE);
    if(retI2C < E_OK)
    {
  #ifdef SUPPROT_HM01B0_DEBUG_PRINT
    	xprintf("HX CIS getRegister I2C fail\r\n");
  #endif
  	  return HX_CIS_ERROR_I2C;
    }else{
    	status = HX_CIS_NO_ERROR;
    }

    if (HX_CIS_NO_ERROR == status) {
    	*val = rwBuffer[0];
    }else{
#ifdef SUPPROT_HM01B0_DEBUG_PRINT
    	xprintf("hx_drv_cis_get_reg fail 0x%x\r\n", regAddr);
#endif
    }

	return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_get_reg_1byte(uint8_t addr, uint8_t *val) {
	uint8_t RegByteCount = 1;
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;
	uint8_t rwBuffer[HX_CIS_I2C_DATA_BYTE] = { 0x00 };
	uint8_t regAddr[1];
	int32_t retI2C = 0;

    SENSORCTRL_MCLKCTRL_E mclkctrl;
	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

    //pin mux set to default
	drv_interface_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_0, SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0);

	*val = 0;

	regAddr[0] = addr;

    retI2C = hx_drv_i2cm_write_restart_read(HX_CIS_IIC_M_ID, g_slave_id, regAddr, RegByteCount, rwBuffer, HX_CIS_I2C_DATA_BYTE);
    if(retI2C < E_OK)
    {
  #ifdef SUPPROT_HM01B0_DEBUG_PRINT
    	xprintf("HX CIS getRegister I2C fail\r\n");
  #endif
  	  return HX_CIS_ERROR_I2C;
    }else{
    	status = HX_CIS_NO_ERROR;
    }

    if (HX_CIS_NO_ERROR == status) {
    	*val = rwBuffer[0];
    }else{
#ifdef SUPPROT_HM01B0_DEBUG_PRINT
    	xprintf("hx_drv_cis_get_reg fail 0x%x\r\n", regAddr);
#endif
    }

	return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_CMU_Update(void) {
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;
	uint8_t rwBuffer[HX_CIS_I2C_DATA_BYTE] = { 0x00 };
	uint8_t regLen = HX_CIS_I2C_ADDR_BYTE;
	uint8_t regAddr[HX_CIS_I2C_ADDR_BYTE];
	int32_t retI2C = 0;

    SENSORCTRL_MCLKCTRL_E mclkctrl;
	hx_drv_sensorctrl_get_MCLKCtrl(&mclkctrl);
	if(mclkctrl != SENSORCTRL_MCLKCTRL_NONAOS)
	{
		hx_drv_sensorctrl_set_MCLKCtrl(SENSORCTRL_MCLKCTRL_NONAOS);
	}

	drv_interface_set_sensor_i2cm_pinmux(SCU_SEN_I2CM_SDA_PINMUX_I2CM_SDA_0, SCU_SEN_I2CM_SCL_PINMUX_I2CM_SCL_0);

	regAddr[0] = (HX_CIS_CMU_REG_ADDR >> 8) & 0xFF;
	regAddr[1] = HX_CIS_CMU_REG_ADDR & 0xFF;

	rwBuffer[0] = 1;

	retI2C = hx_drv_i2cm_write_data(HX_CIS_IIC_M_ID, g_slave_id, regAddr, regLen, rwBuffer, HX_CIS_I2C_DATA_BYTE);
	if(retI2C < E_OK)
	{
#ifdef SUPPROT_HM01B0_DEBUG_PRINT
		xprintf("HX CIS CMU_Update I2C fail\r\n");
#endif
		return HX_CIS_ERROR_I2C;
	}
	return status;
}

HX_CIS_ERROR_E hx_drv_cis_xshutdown_rst(void) {
	HX_CIS_ERROR_E status = HX_CIS_NO_ERROR;

	if(g_xshutdown_pin == CIS_XHSUTDOWN_IOMUX_NONE)
	{
		return HX_CIS_UNKNOWN_ERROR;
	}
	else
	{
	    GPIO_INDEX_E iomux_idx;
		iomux_idx = (GPIO_INDEX_E)g_xshutdown_pin;
		hx_drv_sensorctrl_set_xShutdown(iomux_idx, 0);

		hx_drv_timer_cm55x_delay_ms(1, TIMER_STATE_DC);
		hx_drv_sensorctrl_set_xShutdown(iomux_idx, 1);

		hx_drv_timer_cm55x_delay_us(500, TIMER_STATE_DC);
	}

	return status;
}

HX_CIS_ERROR_E hx_drv_cis_enable_soi_init_flow(void) {
    cis_soi_init = 1;

    return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_disable_soi_init_flow(void) {
    cis_soi_init = 0;

    return HX_CIS_NO_ERROR;
}

HX_CIS_ERROR_E hx_drv_cis_set_xsleep_def_val(uint8_t val) {
    xsleep_default_val = val;

    return HX_CIS_NO_ERROR;
}
