#include "WE2_core.h"
#include "xprintf.h"
#include "board.h"
#include "hx_drv_scu_export.h"
#include "hx_drv_scu.h"
#include "CM55S_TrustZone_FW_mem.h"

/* TZ_START_NS: Start address of non-secure application */
#define TZ_START_NS  CM55S_NS_APP_ROM_BASE
 
/* typedef for non-secure callback functions */
typedef void (*funcptr_void) (void) __attribute__((cmse_nonsecure_call));

int main(void) {
    funcptr_void NonSecure_ResetHandler;
    uint32_t ns_entry;
    uint32_t ns_msp;

    board_init();

    printf("core1 hello_word_s running ...\r\n");

    ns_msp = *((uint32_t *)(TZ_START_NS));
    ns_entry = *((uint32_t *)((TZ_START_NS) + 4U));

    printf("ns_start addr = 0x%08X\r\n", TZ_START_NS);
    printf("get ns_msp = 0x%08X\r\n", ns_msp);
    printf("get ns_entry = 0x%08X\r\n", ns_entry);

    SCB_NS->VTOR = TZ_START_NS;

    /* Set non-secure main stack (MSP_NS) */
    __TZ_set_MSP_NS(ns_msp);

    /* Get non-secure reset handler */
    NonSecure_ResetHandler = (funcptr_void)(ns_entry);

    printf("NonSecure_ResetHandler\r\n");

    /* Start non-secure state software application */
    NonSecure_ResetHandler();

    /* Non-secure software does not return, this code is not executed */
    
    for(;;) {}
}
