#include <stdio.h>
#include <assert.h>
#include <stdbool.h>
#include <stdint.h>
#include <string.h>
#include <stdlib.h>
#include "WE2_device.h"

#ifdef TRUSTZONE_SEC
#ifdef FREERTOS
/* Trustzone config. */
//#include "trustzone_cfg.h"
/* FreeRTOS includes. */
//#include "secure_port_macros.h"
#else
#if (__ARM_FEATURE_CMSE & 1) == 0
#error "Need ARMv8-M security extensions"
#elif (__ARM_FEATURE_CMSE & 2) == 0
#error "Compile with --cmse"
#endif
#include "arm_cmse.h"
//#include "veneer_table.h"
//#include "trustzone_cfg.h"
#endif
#endif
#include "xprintf.h"
#include "board.h"
#include "mdapp.h"
#include "xprintf.h"
#include "pmu_sim_audpre_cm55s_vad.h"
#include "hx_drv_timer.h"
#include "hx_drv_pdm_rx.h"
#include "hx_drv_scu.h"
#include "hx_drv_scu_export.h"
#include "hx_drv_vad.h"
#include "powermode.h"
#include "hxmb.h"

#define NOTSIM

#ifdef EPII_FPGA
#define DBG_APP_SIM_LOG             (1)
#else
#ifdef NOTSIM
#define DBG_APP_SIM_LOG             (1)
#else
#define DBG_APP_SIM_LOG             (0)
#endif
#endif
#if DBG_APP_SIM_LOG
    #define dbg_app_log(fmt, ...)       xprintf(fmt, ##__VA_ARGS__)
#else
    #define dbg_app_log(fmt, ...)
#endif



volatile uint8_t dma_infinite_loop = 1;
volatile uint8_t g_vad_detect_flag = 0;
void *g_pdm_rx_buf_ptr = (void *)0x36030000;    /* refer to __HEAP_LIMIT */
PDM_DEV_INFO g_app_pdm_dev_info;
VAD_CFG_T g_vad_cfg;

#define VAD_INPUT_GAIN		3
#define VAD_SPEECH_GAIN		0
#define VAD_NOISE_GAIN		0

static void vad_callback(uint32_t status)
{
	hx_set_memory(0x5200F034, 0x00000022);
	dbg_app_log("VAD Callback (Done) \n");
	g_vad_detect_flag = 1;
}

/** init VAD **/
void VAD_Init()
{
	g_vad_cfg.input_gain = VAD_INPUT_GAIN;
	g_vad_cfg.speech_gain = VAD_SPEECH_GAIN;
	g_vad_cfg.noise_gain = VAD_NOISE_GAIN;
	g_vad_cfg.high_pass = VAD_HIGH_PASS_FILTER_CUTOFF_2K;
	g_vad_cfg.lut = VAD_LUT_BYPASS;
	g_vad_cfg.inverse = VAD_INVERSE_FILTER_NO_BYPASS;
	g_vad_cfg.k_noise = 0x64;
	g_vad_cfg.vad_src = VAD_SRC_PDM;
	g_vad_cfg.vad_ch = VAD_PCM_DATA_L_CH;
	g_vad_cfg.pdm_data_path_out = PDM_DATA_PATH_0_OUT_TO_VAD;

	hx_drv_vad_init(HW_VAD_BASEADDR, &g_vad_cfg);
	hx_drv_vad_register_cb(vad_callback);
}

void VAD_SetEnable(uint8_t enable)
{
	if ( enable == 0 )
		hx_drv_vad_set_enable(0);
	else
		hx_drv_vad_set_enable(1);
}

void VAD_WFI()
{
	dbg_app_log("CliVAD_WFI Start ---- \n");
    /* Disable system tick */
    EPII_Set_Systick_enable(0);
    __WFI();
    dbg_app_log("CliVAD_WFI End ----\n");
}

//
void dump_aud_dma_LLI()
{
	uint32_t addr, size, cnt, val;
    addr = 0x51800100;
	size = 40;
	cnt = size/4;

	dbg_app_log("\n\audio buffer\n");
	for(uint32_t idx = 0; idx< cnt; idx++)
	{
		val = hx_get_memory((addr + (idx*4)));
		dbg_app_log("0x%08X ", val);
	}
	dbg_app_log("\n");
}
/*******************************************************************************
 * Code
 ******************************************************************************/
void app_pdm_dma_rx_cb()
{
    hx_drv_pdm_stop_transfer();
    dbg_app_log("\n\n[%s]\n\n", __FUNCTION__);
}

static PDM_ERROR_E app_pdm_init()
{
    memset((void *)&g_app_pdm_dev_info, 0x00, sizeof(PDM_DEV_INFO));

    /* PDM setting */
	g_app_pdm_dev_info.pdm_cfg.reg_addr = HIMAX_PDM_BASE_ADDR;
    g_app_pdm_dev_info.pdm_cfg.rx_fifo_threshold = 5;
    g_app_pdm_dev_info.pdm_cfg.oversampling_ratio = 8; // 6: 32KHz, 8: 16KHz
    g_app_pdm_dev_info.pdm_cfg.cic_stages = 0;
    g_app_pdm_dev_info.pdm_cfg.cic_delay = 0;
    g_app_pdm_dev_info.pdm_cfg.dc_removal = 6;
    g_app_pdm_dev_info.pdm_cfg.bit_range_shift = 5;
    g_app_pdm_dev_info.pdm_cfg.data_in_0_en = PDM_DATA_IN_ENABLE;
    g_app_pdm_dev_info.pdm_cfg.data_in_1_en = PDM_DATA_IN_DISABLE;
    g_app_pdm_dev_info.pdm_cfg.data_in_2_en = PDM_DATA_IN_DISABLE;
    g_app_pdm_dev_info.pdm_cfg.data_in_3_en = PDM_DATA_IN_DISABLE;
    g_app_pdm_dev_info.pdm_cfg.capture_channel = PDM_CAPTURE_CHANNEL_LEFT_ONLY;
	g_app_pdm_dev_info.pdm_cfg.dma_ch = PDM_USE_DMA2_CH_0;
	g_app_pdm_dev_info.pdm_cfg.pdm_clk_src = PDM_CLKSRC_LSCREF;
	g_app_pdm_dev_info.pdm_cfg.sample_rate = PDM_PCM_FREQ_16K;
    g_app_pdm_dev_info.pdm_rx_cb = app_pdm_dma_rx_cb;
    g_app_pdm_dev_info.pdm_err_cb = NULL;

    if(hx_drv_pdm_init(&g_app_pdm_dev_info)!= PDM_NO_ERROR)
        return PDM_ERROR_INIT_FAIL;
}

/*!
 * @brief Main function
 */
int hello_world_app(void) {
	int getin;
	dbg_app_log("Hello from secure world! Only Secure\r\n");
	dbg_app_log("Test Xprintf\r\n");
	g_vad_detect_flag = 0;
	hx_lib_mb_set_cm55s_rdy();

	hx_drv_scu_set_PB9_pinmux(SCU_PB9_PINMUX_PDM_CLK_1);
	hx_drv_scu_set_PB10_pinmux(SCU_PB10_PINMUX_PDM_DATA0_1);
	hx_drv_scu_set_PB11_pinmux(SCU_PB11_PINMUX_PDM_DATA1_1);
	hx_drv_scu_set_PC3_pinmux(SCU_PC3_PINMUX_PDM_DATA2);
	hx_drv_scu_set_PC4_pinmux(SCU_PC4_PINMUX_PDM_DATA3);

    app_pdm_init();
    dbg_app_log("dma_infinite_loop:%d \n", dma_infinite_loop);

    uint32_t buffer_addr = (uint32_t) g_pdm_rx_buf_ptr;
    uint32_t block_num = 40;     /* SRAM2 only 384KB, 0x36000000 ~ 0x3606_0000 */
    uint32_t block_sz = 4096;
    hx_drv_pdm_dma_lli_transfer((void *) buffer_addr, block_num, block_sz, dma_infinite_loop);

    for(uint8_t idx = 0; idx < 5 ; idx++)
    {
    	dump_aud_dma_LLI();
    }

    for(uint32_t idx = 0; idx < 30000 ; idx++)
    {
    	__NOP();
    }

	hx_set_memory(0x5200F034, 0x00000018);
    VAD_Init();
	hx_set_memory(0x5200F034, 0x00000019);
    VAD_SetEnable(1);
	hx_set_memory(0x5200F034, 0x00000020);
    VAD_WFI();
	hx_set_memory(0x5200F034, 0x00000021);
	while (1) {
		if(g_vad_detect_flag == 1)
		{
			dbg_app_log("force DC\r\n");
			hx_lib_pm_force_state_set(PMU_PS_STATE_DC);
			g_vad_detect_flag = 0;
		}
#ifndef NOTSIM
		/* This point should never be reached */
		getin = console_getchar();
		dbg_app_log("getin= %d\r\n", getin);
#endif
	}

}
