/*
 * Copyright (c) 2021-2022, Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 *
 */
#include "tfm_irq_test_service.h"
#include "tfm_sp_log.h"
#include "psa/service.h"
#include "psa_manifest/tfm_hx_service.h"
#include "tfm_hx_service_defs.h"

//YX 20230210
#include "arm_cmse.h"
#include "hx_drv_pmu.h"
#include "spi_eeprom_comm.h"
#include "spi_psram_comm.h"
#include "veneer_clk_ctrl.h"
#include "veneer_eeprom_ctrl.h"
#include "veneer_power_ctrl.h"
#include "veneer_psram_ctrl.h"
#include "veneer_sys_ctrl.h"
#include "veneer_timer_ctrl.h"
#include "powermode.h"
#include "hx_drv_swreg_aon.h"
#include "hx_drv_swreg_lsc.h"

/////////////////// veneer_timer_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_timer_sensor_start(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_timer_sensor_stop(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55m_start(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55m_stop(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55s_start(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55s_stop(const psa_msg_t *msg);
/////////////////// veneer_clk_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_timer_clk_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_timer_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_wdg_clk_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_wdg_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_rtc_clk_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_rtc_cycle(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_freq(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_vad_d_src_sel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_vad_d_src_sel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_i2s_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_i2s_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdm_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdm_clkdiv(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_xtal32k_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_xtal32k_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_xtal24m_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_xtal24m_en(const psa_msg_t *msg);
#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pll_cfg(const psa_msg_t *msg);
#endif
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_src(const psa_msg_t *msg);
#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pll_enable(const psa_msg_t *msg);
#endif
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_lock_status(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_dpclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_dpclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_dpclken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_dpclken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_hscclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_hscclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_hsc32kclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_hsc32kclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_dpclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_dpclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_dpclken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_dpclken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_lscclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_lscclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_lscrefclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_lscrefclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_adcckinclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_adcckinclk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdsb_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdsb_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdsb_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdsb_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdaon_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdaon_clk_cfg(const psa_msg_t *msg);
#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_simple_clk_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_clk_get_simple_clk_cfg(const psa_msg_t *msg);
#endif
enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdaon_clken_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_rtc_state(const psa_msg_t *msg);

/////////////////// veneer_sys_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_sys_get_u55_state(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_U55_PORPL(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_cm55s_state(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2S_mode(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_I2S_mode(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PDM_IP(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_PDM_IP(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_xip_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_xip_en(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_slave(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_resetn(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_vad_d_pcm_sel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfval(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfmul(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfsel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_version(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA1_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA0_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA2_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA3_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_sensor_i2cm_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_FAE_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_TRIG_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_INT_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_XSLEEP_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_MCLK_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_sensorgpio_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_CSW0_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_CSW1_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D1_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D2_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D3_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D4_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D5_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D6_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D7_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_FVALID_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_LVALID_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_PCLKO_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_SDCLK_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_CMD_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT0_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT1_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT2_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT3_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SW_DATA_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SW_CLK_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB2_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB3_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB4_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB5_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB6_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB7_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB8_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB9_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB10_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB11_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PC3_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PC4_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2CM_SCLSDA_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB0_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB1_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_DO_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_DI_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_SCLK_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_CS_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2C_SLV_share_enable(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_I3C_SLV_share_enable(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_DP_SWReset(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_get_DP_SWReset(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_pdlsc_pdmck_src(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_wdt_ctrl(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_sys_set_timer_ctrl(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_audio_capture_channel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_get_audio_capture_channel(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_lsc_adclv_reset(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_lsc_adchv_reset(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_SRSTN_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_SWCLKTCK_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_SWDIO_TMS_pinmux(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_get_all_pinmux_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_set_all_pinmux_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_get_pllfreq(const psa_msg_t *msg);

/////////////////// veneer_power_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_pm_get_defcfg_bymode(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_pmu_dpdone_check(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_ctrl_fromPMUtoCPU(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_cfg_set(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_cfg_get(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_mode_get(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_trigger(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_get_event(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_clear_event(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_force_state_set(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_force_state_get(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_set_dma_cfg(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_pm_ext_int_get(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_get_pmuwakeup_freq(const psa_msg_t *msg);

/////////////////// veneer_eeprom_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_open(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_open_speed(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_read_ID(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_1read(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_2read(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_4read(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_word_read(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_word_write(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_write(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_Send_Op_code(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_erase_all(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_erase_sector(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_enable_XIP(const psa_msg_t *msg);
/////////////////// veneer_psram_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_open(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_SetXIP(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_set_powermode(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_get_info(const psa_msg_t *msg);
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_close(const psa_msg_t *msg);

static psa_status_t hx_handle_msg(const psa_msg_t *msg)
{
    psa_status_t status;

    switch (msg->type) {
#if defined(_veneer_timer_sensor_start)
    case (TFM_HX_SERVICE + _veneer_timer_sensor_start):
        status = tfm_hx_veneer_timer_sensor_start(msg);
        break;
#endif
#if defined(_veneer_timer_sensor_stop)
    case (TFM_HX_SERVICE + _veneer_timer_sensor_stop):
        status = tfm_hx_veneer_timer_sensor_stop(msg);
        break;
#endif
#if defined(_veneer_timer_cm55m_start)
    case (TFM_HX_SERVICE + _veneer_timer_cm55m_start):
        status = tfm_hx_veneer_timer_cm55m_start(msg);
        break;
#endif
#if defined(_veneer_timer_cm55m_stop)
    case (TFM_HX_SERVICE + _veneer_timer_cm55m_stop):
        status = tfm_hx_veneer_timer_cm55m_stop(msg);
        break;
#endif
#if defined(_veneer_timer_cm55s_start)
    case (TFM_HX_SERVICE + _veneer_timer_cm55s_start):
        status = tfm_hx_veneer_timer_cm55s_start(msg);
        break;
#endif
#if defined(_veneer_timer_cm55s_stop)
    case (TFM_HX_SERVICE + _veneer_timer_cm55s_stop):
        status = tfm_hx_veneer_timer_cm55s_stop(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_timer_clk_en)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_timer_clk_en):
        status = tfm_hx_veneer_clk_ctrl_set_timer_clk_en(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_timer_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_timer_clkdiv):
        status = tfm_hx_veneer_clk_ctrl_set_timer_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_wdg_clk_en)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_wdg_clk_en):
        status = tfm_hx_veneer_clk_ctrl_set_wdg_clk_en(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_wdg_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_wdg_clkdiv):
        status = tfm_hx_veneer_clk_ctrl_set_wdg_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_rtc_clk_en)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_rtc_clk_en):
        status = tfm_hx_veneer_clk_ctrl_set_rtc_clk_en(msg);
        break;
#endif
#if defined(_veneer_clk_ctrl_set_rtc_cycle)
    case (TFM_HX_SERVICE + _veneer_clk_ctrl_set_rtc_cycle):
        status = tfm_hx_veneer_clk_ctrl_set_rtc_cycle(msg);
        break;
#endif
#if defined(_veneer_clk_get_freq)
    case (TFM_HX_SERVICE + _veneer_clk_get_freq):
        status = tfm_hx_veneer_clk_get_freq(msg);
        break;
#endif
#if defined(_veneer_clk_set_vad_d_src_sel)
    case (TFM_HX_SERVICE + _veneer_clk_set_vad_d_src_sel):
        status = tfm_hx_veneer_clk_set_vad_d_src_sel(msg);
        break;
#endif
#if defined(_veneer_clk_get_vad_d_src_sel)
    case (TFM_HX_SERVICE + _veneer_clk_get_vad_d_src_sel):
        status = tfm_hx_veneer_clk_get_vad_d_src_sel(msg);
        break;
#endif
#if defined(_veneer_clk_set_i2s_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_set_i2s_clkdiv):
        status = tfm_hx_veneer_clk_set_i2s_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_get_i2s_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_get_i2s_clkdiv):
        status = tfm_hx_veneer_clk_get_i2s_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdm_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdm_clkdiv):
        status = tfm_hx_veneer_clk_set_pdm_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdm_clkdiv)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdm_clkdiv):
        status = tfm_hx_veneer_clk_get_pdm_clkdiv(msg);
        break;
#endif
#if defined(_veneer_clk_set_xtal32k_en)
    case (TFM_HX_SERVICE + _veneer_clk_set_xtal32k_en):
        status = tfm_hx_veneer_clk_set_xtal32k_en(msg);
        break;
#endif
#if defined(_veneer_clk_get_xtal32k_en)
    case (TFM_HX_SERVICE + _veneer_clk_get_xtal32k_en):
        status = tfm_hx_veneer_clk_get_xtal32k_en(msg);
        break;
#endif
#if defined(_veneer_clk_set_xtal24m_en)
    case (TFM_HX_SERVICE + _veneer_clk_set_xtal24m_en):
        status = tfm_hx_veneer_clk_set_xtal24m_en(msg);
        break;
#endif
#if defined(_veneer_clk_get_xtal24m_en)
    case (TFM_HX_SERVICE + _veneer_clk_get_xtal24m_en):
        status = tfm_hx_veneer_clk_get_xtal24m_en(msg);
        break;
#endif
#if defined(_veneer_clk_set_pll_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pll_cfg):
        status = tfm_hx_veneer_clk_set_pll_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pll_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pll_cfg):
        status = tfm_hx_veneer_clk_get_pll_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pll_src)
    case (TFM_HX_SERVICE + _veneer_clk_get_pll_src):
        status = tfm_hx_veneer_clk_get_pll_src(msg);
        break;
#endif
#if defined(_veneer_clk_set_pll_enable)
    case (TFM_HX_SERVICE + _veneer_clk_set_pll_enable):
        status = tfm_hx_veneer_clk_set_pll_enable(msg);
        break;
#endif
#if defined(_veneer_clk_get_pll_lock_status)
    case (TFM_HX_SERVICE + _veneer_clk_get_pll_lock_status):
        status = tfm_hx_veneer_clk_get_pll_lock_status(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_dpclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_dpclk_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_dpclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_dpclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_dpclk_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_dpclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_dpclken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_dpclken_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_dpclken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_dpclken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_dpclken_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_dpclken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_hscclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_hscclk_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_hscclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_hscclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_hscclk_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_hscclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_hsc32kclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_hsc32kclk_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_hsc32kclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_hsc32kclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_hsc32kclk_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_hsc32kclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_clk_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_clk_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdhsc_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdhsc_clken_cfg):
        status = tfm_hx_veneer_clk_set_pdhsc_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdhsc_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdhsc_clken_cfg):
        status = tfm_hx_veneer_clk_get_pdhsc_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_dpclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_dpclk_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_dpclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_dpclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_dpclk_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_dpclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_dpclken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_dpclken_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_dpclken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_dpclken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_dpclken_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_dpclken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_lscclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_lscclk_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_lscclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_lscclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_lscclk_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_lscclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_lscrefclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_lscrefclk_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_lscrefclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_lscrefclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_lscrefclk_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_lscrefclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_adcckinclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_adcckinclk_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_adcckinclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_adcckinclk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_adcckinclk_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_adcckinclk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_clk_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_clk_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdlsc_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdlsc_clken_cfg):
        status = tfm_hx_veneer_clk_set_pdlsc_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdlsc_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdlsc_clken_cfg):
        status = tfm_hx_veneer_clk_get_pdlsc_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdsb_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdsb_clk_cfg):
        status = tfm_hx_veneer_clk_set_pdsb_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdsb_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdsb_clk_cfg):
        status = tfm_hx_veneer_clk_get_pdsb_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdsb_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdsb_clken_cfg):
        status = tfm_hx_veneer_clk_set_pdsb_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdsb_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdsb_clken_cfg):
        status = tfm_hx_veneer_clk_get_pdsb_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_pdaon_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_pdaon_clk_cfg):
        status = tfm_hx_veneer_clk_set_pdaon_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdaon_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdaon_clk_cfg):
        status = tfm_hx_veneer_clk_get_pdaon_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_set_simple_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_set_simple_clk_cfg):
        status = tfm_hx_veneer_clk_set_simple_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_simple_clk_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_simple_clk_cfg):
        status = tfm_hx_veneer_clk_get_simple_clk_cfg(msg);
        break;
#endif
#if defined(_veneer_clk_get_pdaon_clken_cfg)
    case (TFM_HX_SERVICE + _veneer_clk_get_pdaon_clken_cfg):
        status = tfm_hx_veneer_clk_get_pdaon_clken_cfg(msg);
        break;
#endif
#if defined(_veneer_set_rtc_state)
    case (TFM_HX_SERVICE + _veneer_set_rtc_state):
        status = tfm_hx_veneer_set_rtc_state(msg);
        break;
#endif
#if defined(_veneer_sys_get_u55_state)
    case (TFM_HX_SERVICE + _veneer_sys_get_u55_state):
        status = tfm_hx_veneer_sys_get_u55_state(msg);
        break;
#endif
#if defined(_veneer_sys_get_U55_PORPL)
    case (TFM_HX_SERVICE + _veneer_sys_get_U55_PORPL):
        status = tfm_hx_veneer_sys_get_U55_PORPL(msg);
        break;
#endif
#if defined(_veneer_sys_get_cm55s_state)
    case (TFM_HX_SERVICE + _veneer_sys_get_cm55s_state):
        status = tfm_hx_veneer_sys_get_cm55s_state(msg);
        break;
#endif
#if defined(_veneer_sys_set_I2S_mode)
    case (TFM_HX_SERVICE + _veneer_sys_set_I2S_mode):
        status = tfm_hx_veneer_sys_set_I2S_mode(msg);
        break;
#endif
#if defined(_veneer_sys_get_I2S_mode)
    case (TFM_HX_SERVICE + _veneer_sys_get_I2S_mode):
        status = tfm_hx_veneer_sys_get_I2S_mode(msg);
        break;
#endif
#if defined(_veneer_sys_set_PDM_IP)
    case (TFM_HX_SERVICE + _veneer_sys_set_PDM_IP):
        status = tfm_hx_veneer_sys_set_PDM_IP(msg);
        break;
#endif
#if defined(_veneer_sys_get_PDM_IP)
    case (TFM_HX_SERVICE + _veneer_sys_get_PDM_IP):
        status = tfm_hx_veneer_sys_get_PDM_IP(msg);
        break;
#endif
#if defined(_veneer_sys_set_xip_en)
    case (TFM_HX_SERVICE + _veneer_sys_set_xip_en):
        status = tfm_hx_veneer_sys_set_xip_en(msg);
        break;
#endif
#if defined(_veneer_sys_set_ospi_xip_en)
    case (TFM_HX_SERVICE + _veneer_sys_set_ospi_xip_en):
        status = tfm_hx_veneer_sys_set_ospi_xip_en(msg);
        break;
#endif
#if defined(_veneer_sys_set_ospi_slave)
    case (TFM_HX_SERVICE + _veneer_sys_set_ospi_slave):
        status = tfm_hx_veneer_sys_set_ospi_slave(msg);
        break;
#endif
#if defined(_veneer_sys_set_ospi_resetn)
    case (TFM_HX_SERVICE + _veneer_sys_set_ospi_resetn):
        status = tfm_hx_veneer_sys_set_ospi_resetn(msg);
        break;
#endif
#if defined(_veneer_sys_set_vad_d_pcm_sel)
    case (TFM_HX_SERVICE + _veneer_sys_set_vad_d_pcm_sel):
        status = tfm_hx_veneer_sys_set_vad_d_pcm_sel(msg);
        break;
#endif
#if defined(_veneer_sys_set_sdio_itcfval)
    case (TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfval):
        status = tfm_hx_veneer_sys_set_sdio_itcfval(msg);
        break;
#endif
#if defined(_veneer_sys_set_sdio_itcfmul)
    case (TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfmul):
        status = tfm_hx_veneer_sys_set_sdio_itcfmul(msg);
        break;
#endif
#if defined(_veneer_sys_set_sdio_itcfsel)
    case (TFM_HX_SERVICE + _veneer_sys_set_sdio_itcfsel):
        status = tfm_hx_veneer_sys_set_sdio_itcfsel(msg);
        break;
#endif
#if defined(_veneer_sys_get_version)
    case (TFM_HX_SERVICE + _veneer_sys_get_version):
        status = tfm_hx_veneer_sys_get_version(msg);
        break;
#endif
#if defined(_veneer_sys_set_PA1_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PA1_pinmux):
        status = tfm_hx_veneer_sys_set_PA1_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PA0_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PA0_pinmux):
        status = tfm_hx_veneer_sys_set_PA0_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PA2_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PA2_pinmux):
        status = tfm_hx_veneer_sys_set_PA2_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PA3_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PA3_pinmux):
        status = tfm_hx_veneer_sys_set_PA3_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_sensor_i2cm_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_sensor_i2cm_pinmux):
        status = tfm_hx_veneer_sys_set_sensor_i2cm_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_FAE_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_FAE_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_FAE_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_TRIG_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_TRIG_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_TRIG_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_INT_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_INT_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_INT_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_XSLEEP_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_XSLEEP_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_XSLEEP_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_MCLK_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_MCLK_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_MCLK_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_sensorgpio_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_sensorgpio_pinmux):
        status = tfm_hx_veneer_sys_set_sensorgpio_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_CSW0_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_CSW0_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_CSW0_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_CSW1_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_CSW1_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_CSW1_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D1_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D1_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D1_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D2_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D2_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D2_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D3_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D3_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D3_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D4_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D4_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D4_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D5_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D5_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D5_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D6_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D6_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D6_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_D7_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_D7_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_D7_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_FVALID_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_FVALID_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_FVALID_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_LVALID_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_LVALID_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_LVALID_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SEN_PCLKO_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SEN_PCLKO_pinmux):
        status = tfm_hx_veneer_sys_set_SEN_PCLKO_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_SDCLK_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_SDCLK_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_SDCLK_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_CMD_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_CMD_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_CMD_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_DAT0_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT0_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_DAT0_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_DAT1_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT1_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_DAT1_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_DAT2_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT2_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_DAT2_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SDIO_DAT3_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SDIO_DAT3_pinmux):
        status = tfm_hx_veneer_sys_set_SDIO_DAT3_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SW_DATA_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SW_DATA_pinmux):
        status = tfm_hx_veneer_sys_set_SW_DATA_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SW_CLK_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SW_CLK_pinmux):
        status = tfm_hx_veneer_sys_set_SW_CLK_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB2_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB2_pinmux):
        status = tfm_hx_veneer_sys_set_PB2_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB3_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB3_pinmux):
        status = tfm_hx_veneer_sys_set_PB3_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB4_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB4_pinmux):
        status = tfm_hx_veneer_sys_set_PB4_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB5_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB5_pinmux):
        status = tfm_hx_veneer_sys_set_PB5_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB6_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB6_pinmux):
        status = tfm_hx_veneer_sys_set_PB6_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB7_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB7_pinmux):
        status = tfm_hx_veneer_sys_set_PB7_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB8_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB8_pinmux):
        status = tfm_hx_veneer_sys_set_PB8_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB9_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB9_pinmux):
        status = tfm_hx_veneer_sys_set_PB9_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB10_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB10_pinmux):
        status = tfm_hx_veneer_sys_set_PB10_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB11_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB11_pinmux):
        status = tfm_hx_veneer_sys_set_PB11_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PC3_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PC3_pinmux):
        status = tfm_hx_veneer_sys_set_PC3_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PC4_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PC4_pinmux):
        status = tfm_hx_veneer_sys_set_PC4_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_I2CM_SCLSDA_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_I2CM_SCLSDA_pinmux):
        status = tfm_hx_veneer_sys_set_I2CM_SCLSDA_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB0_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB0_pinmux):
        status = tfm_hx_veneer_sys_set_PB0_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_PB1_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_PB1_pinmux):
        status = tfm_hx_veneer_sys_set_PB1_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux):
        status = tfm_hx_veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SPIS_DO_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SPIS_DO_pinmux):
        status = tfm_hx_veneer_sys_set_SPIS_DO_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SPIS_DI_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SPIS_DI_pinmux):
        status = tfm_hx_veneer_sys_set_SPIS_DI_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SPIS_SCLK_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SPIS_SCLK_pinmux):
        status = tfm_hx_veneer_sys_set_SPIS_SCLK_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_SPIS_CS_pinmux)
    case (TFM_HX_SERVICE + _veneer_sys_set_SPIS_CS_pinmux):
        status = tfm_hx_veneer_sys_set_SPIS_CS_pinmux(msg);
        break;
#endif
#if defined(_veneer_sys_set_I2C_SLV_share_enable)
    case (TFM_HX_SERVICE + _veneer_sys_set_I2C_SLV_share_enable):
        status = tfm_hx_veneer_sys_set_I2C_SLV_share_enable(msg);
        break;
#endif
#if defined(_veneer_sys_set_I3C_SLV_share_enable)
    case (TFM_HX_SERVICE + _veneer_sys_set_I3C_SLV_share_enable):
        status = tfm_hx_veneer_sys_set_I3C_SLV_share_enable(msg);
        break;
#endif
#if defined(_veneer_sys_set_DP_SWReset)
    case (TFM_HX_SERVICE + _veneer_sys_set_DP_SWReset):
        status = tfm_hx_veneer_sys_set_DP_SWReset(msg);
        break;
#endif
#if defined(_veneer_sys_get_DP_SWReset)
    case (TFM_HX_SERVICE + _veneer_sys_get_DP_SWReset):
        status = tfm_hx_veneer_sys_get_DP_SWReset(msg);
        break;
#endif
#if defined(_veneer_set_pdlsc_pdmck_src)
    case (TFM_HX_SERVICE + _veneer_set_pdlsc_pdmck_src):
        status = tfm_hx_veneer_set_pdlsc_pdmck_src(msg);
        break;
#endif
#if defined(_veneer_sys_set_wdt_ctrl)
    case (TFM_HX_SERVICE + _veneer_sys_set_wdt_ctrl):
        status = tfm_hx_veneer_sys_set_wdt_ctrl(msg);
        break;
#endif
#if defined(_veneer_sys_set_timer_ctrl)
    case (TFM_HX_SERVICE + _veneer_sys_set_timer_ctrl):
        status = tfm_hx_veneer_sys_set_timer_ctrl(msg);
        break;
#endif
#if defined(_veneer_set_audio_capture_channel)
    case (TFM_HX_SERVICE + _veneer_set_audio_capture_channel):
        status = tfm_hx_veneer_set_audio_capture_channel(msg);
        break;
#endif
#if defined(_veneer_get_audio_capture_channel)
    case (TFM_HX_SERVICE + _veneer_get_audio_capture_channel):
        status = tfm_hx_veneer_get_audio_capture_channel(msg);
        break;
#endif
#if defined(_veneer_set_lsc_adclv_reset)
    case (TFM_HX_SERVICE + _veneer_set_lsc_adclv_reset):
        status = tfm_hx_veneer_set_lsc_adclv_reset(msg);
        break;
#endif
#if defined(_veneer_set_lsc_adchv_reset)
    case (TFM_HX_SERVICE + _veneer_set_lsc_adchv_reset):
        status = tfm_hx_veneer_set_lsc_adchv_reset(msg);
        break;
#endif
#if defined(_veneer_set_SRSTN_pinmux)
    case (TFM_HX_SERVICE + _veneer_set_SRSTN_pinmux):
        status = tfm_hx_veneer_set_SRSTN_pinmux(msg);
        break;
#endif
#if defined(_veneer_set_SWCLKTCK_pinmux)
    case (TFM_HX_SERVICE + _veneer_set_SWCLKTCK_pinmux):
        status = tfm_hx_veneer_set_SWCLKTCK_pinmux(msg);
        break;
#endif
#if defined(_veneer_set_SWDIO_TMS_pinmux)
    case (TFM_HX_SERVICE + _veneer_set_SWDIO_TMS_pinmux):
        status = tfm_hx_veneer_set_SWDIO_TMS_pinmux(msg);
        break;
#endif
#if defined(_veneer_get_all_pinmux_cfg)
    case (TFM_HX_SERVICE + _veneer_get_all_pinmux_cfg):
        status = tfm_hx_veneer_get_all_pinmux_cfg(msg);
        break;
#endif
#if defined(_veneer_set_all_pinmux_cfg)
    case (TFM_HX_SERVICE + _veneer_set_all_pinmux_cfg):
        status = tfm_hx_veneer_set_all_pinmux_cfg(msg);
        break;
#endif
#if defined(_veneer_get_pllfreq)
    case (TFM_HX_SERVICE + _veneer_get_pllfreq):
        status = tfm_hx_veneer_get_pllfreq(msg);
        break;
#endif
#if defined(_veneer_pm_get_defcfg_bymode)
    case (TFM_HX_SERVICE + _veneer_pm_get_defcfg_bymode):
        status = tfm_hx_veneer_pm_get_defcfg_bymode(msg);
        break;
#endif
#if defined(_veneer_pm_pmu_dpdone_check)
    case (TFM_HX_SERVICE + _veneer_pm_pmu_dpdone_check):
        status = tfm_hx_veneer_pm_pmu_dpdone_check(msg);
        break;
#endif
#if defined(_veneer_pm_ctrl_fromPMUtoCPU)
    case (TFM_HX_SERVICE + _veneer_pm_ctrl_fromPMUtoCPU):
        status = tfm_hx_veneer_pm_ctrl_fromPMUtoCPU(msg);
        break;
#endif
#if defined(_veneer_pm_cfg_set)
    case (TFM_HX_SERVICE + _veneer_pm_cfg_set):
        status = tfm_hx_veneer_pm_cfg_set(msg);
        break;
#endif
#if defined(_veneer_pm_cfg_get)
    case (TFM_HX_SERVICE + _veneer_pm_cfg_get):
        status = tfm_hx_veneer_pm_cfg_get(msg);
        break;
#endif
#if defined(_veneer_pm_mode_get)
    case (TFM_HX_SERVICE + _veneer_pm_mode_get):
        status = tfm_hx_veneer_pm_mode_get(msg);
        break;
#endif
#if defined(_veneer_pm_trigger)
    case (TFM_HX_SERVICE + _veneer_pm_trigger):
        status = tfm_hx_veneer_pm_trigger(msg);
        break;
#endif
#if defined(_veneer_pm_get_event)
    case (TFM_HX_SERVICE + _veneer_pm_get_event):
        status = tfm_hx_veneer_pm_get_event(msg);
        break;
#endif
#if defined(_veneer_pm_clear_event)
    case (TFM_HX_SERVICE + _veneer_pm_clear_event):
        status = tfm_hx_veneer_pm_clear_event(msg);
        break;
#endif
#if defined(_veneer_pm_force_state_set)
    case (TFM_HX_SERVICE + _veneer_pm_force_state_set):
        status = tfm_hx_veneer_pm_force_state_set(msg);
        break;
#endif
#if defined(_veneer_pm_force_state_get)
    case (TFM_HX_SERVICE + _veneer_pm_force_state_get):
        status = tfm_hx_veneer_pm_force_state_get(msg);
        break;
#endif
#if defined(_veneer_pm_set_dma_cfg)
    case (TFM_HX_SERVICE + _veneer_pm_set_dma_cfg):
        status = tfm_hx_veneer_pm_set_dma_cfg(msg);
        break;
#endif
#if defined(_veneer_pm_ext_int_get)
    case (TFM_HX_SERVICE + _veneer_pm_ext_int_get):
        status = tfm_hx_veneer_pm_ext_int_get(msg);
        break;
#endif
#if defined(_veneer_get_pmuwakeup_freq)
    case (TFM_HX_SERVICE + _veneer_get_pmuwakeup_freq):
        status = tfm_hx_veneer_get_pmuwakeup_freq(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_open)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_open):
        status = tfm_hx_veneer_spi_eeprom_open(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_open_speed)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_open_speed):
        status = tfm_hx_veneer_spi_eeprom_open_speed(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_read_ID)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_read_ID):
        status = tfm_hx_veneer_spi_eeprom_read_ID(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_1read)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_1read):
        status = tfm_hx_veneer_spi_eeprom_1read(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_2read)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_2read):
        status = tfm_hx_veneer_spi_eeprom_2read(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_4read)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_4read):
        status = tfm_hx_veneer_spi_eeprom_4read(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_word_read)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_word_read):
        status = tfm_hx_veneer_spi_eeprom_word_read(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_word_write)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_word_write):
        status = tfm_hx_veneer_spi_eeprom_word_write(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_write)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_write):
        status = tfm_hx_veneer_spi_eeprom_write(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_Send_Op_code)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_Send_Op_code):
        status = tfm_hx_veneer_spi_eeprom_Send_Op_code(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_erase_all)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_erase_all):
        status = tfm_hx_veneer_spi_eeprom_erase_all(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_erase_sector)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_erase_sector):
        status = tfm_hx_veneer_spi_eeprom_erase_sector(msg);
        break;
#endif
#if defined(_veneer_spi_eeprom_enable_XIP)
    case (TFM_HX_SERVICE + _veneer_spi_eeprom_enable_XIP):
        status = tfm_hx_veneer_spi_eeprom_enable_XIP(msg);
        break;
#endif
#if defined(_veneer_spi_psram_open)
    case (TFM_HX_SERVICE + _veneer_spi_psram_open):
        status = tfm_hx_veneer_spi_psram_open(msg);
        break;
#endif
#if defined(_veneer_spi_psram_SetXIP)
    case (TFM_HX_SERVICE + _veneer_spi_psram_SetXIP):
        status = tfm_hx_veneer_spi_psram_SetXIP(msg);
        break;
#endif
#if defined(_veneer_spi_psram_set_powermode)
    case (TFM_HX_SERVICE + _veneer_spi_psram_set_powermode):
        status = tfm_hx_veneer_spi_psram_set_powermode(msg);
        break;
#endif
#if defined(_veneer_spi_psram_get_info)
    case (TFM_HX_SERVICE + _veneer_spi_psram_get_info):
        status = tfm_hx_veneer_spi_psram_get_info(msg);
        break;
#endif
#if defined(_veneer_spi_psram_close)
    case (TFM_HX_SERVICE + _veneer_spi_psram_close):
        status = tfm_hx_veneer_spi_psram_close(msg);
        break;
#endif
    default:
        status = PSA_ERROR_NOT_SUPPORTED;
        break;
    }

    return status;
}

#if TFM_SP_HX_MODEL_IPC == 1
static void flih_hx_get_msg(psa_signal_t signal, psa_msg_t *msg)
{
    psa_status_t status;

    status = psa_get(signal, msg);
    if (status != PSA_SUCCESS) {
        psa_panic();
    }
}

void hx_service_entry(void)
{
    volatile psa_signal_t signals = 0;
    psa_msg_t msg;
#if defined(TFM_PARTITION_HX_IRQS_DMA1_QSPI)
    psa_irq_enable(QSPI_ssi_intp_IRQn_SIGNAL);
    psa_irq_enable(DMAC1_DMACINTR_IRQn_SIGNAL);
#endif

    while (1) {
        signals = psa_wait(PSA_WAIT_ANY, PSA_BLOCK);
        if (signals & TFM_HX_SERVICE_SIGNAL) {
            flih_hx_get_msg(TFM_HX_SERVICE_SIGNAL, &msg);
            psa_reply(msg.handle, hx_handle_msg(&msg));
        }
        else {
            //clear IRQ signal when hx_handle_msg do not clear
#if !defined(TEST_NS_SLIH_IRQ) && !defined(TEST_NS_FLIH_IRQ)
            if (signals & TIMER2INT_IRQn_SIGNAL)
                psa_reset_signal(TIMER2INT_IRQn_SIGNAL);
#endif
            if (signals & TIMER3INT_IRQn_SIGNAL)
                psa_reset_signal(TIMER3INT_IRQn_SIGNAL);
#if defined(TFM_PARTITION_HX_IRQS_DMA1_QSPI)
            if (signals & DMAC1_DMACINTR_IRQn_SIGNAL)
                psa_reset_signal(DMAC1_DMACINTR_IRQn_SIGNAL);
            if (signals & QSPI_ssi_intp_IRQn_SIGNAL)
                psa_reset_signal(QSPI_ssi_intp_IRQn_SIGNAL);
#endif
        }
    }
}
#elif TFM_SP_HX_MODEL_SFN == 1
psa_status_t hx_case_sfn(const psa_msg_t *msg)
{
    return hx_handle_msg(msg);
}
#endif

uint32_t timer_isr_event_cnt = 0;
void timer_isr_event(uint32_t event) {
    timer_isr_event_cnt++;
}

#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*Timer_ISREvent_NS_t) (uint32_t event);
#else
typedef void (*Timer_ISREvent_NS_t)(uint32_t event) __attribute__((cmse_nonsecure_call));
#endif

Timer_ISREvent_NS_t g_sentimerISR_NS_CB = NULL;
//Periodic Timer Callback
void sensor_timer_fire(uint32_t event)
{
    //trigger capture frame
    if(g_sentimerISR_NS_CB != NULL)
        g_sentimerISR_NS_CB(event);
}

enum tfm_hx_err_t tfm_hx_veneer_timer_sensor_start(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;
    TIMER_CFG_T cfg;
    Timer_ISREvent_t cb_event;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef IP_timer
    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(cb_event))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));
    psa_read(msg->handle, 1, &cb_event, sizeof(cb_event));

    g_sentimerISR_NS_CB = (Timer_ISREvent_NS_t) cmse_nsfptr_create(cb_event);
    return_value = hx_drv_timer_sensor_start(&cfg, sensor_timer_fire);
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_timer_sensor_stop(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef IP_timer
    g_sentimerISR_NS_CB = NULL;
    return_value = hx_drv_timer_sensor_stop();
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

//#ifdef CM55_BIG
Timer_ISREvent_NS_t g_cm55mtimerISR_NS_CB = NULL;
//Periodic Timer Callback
void cm55m_timer_fire(uint32_t event)
{
    //trigger capture frame
    if(g_cm55mtimerISR_NS_CB != NULL)
        g_cm55mtimerISR_NS_CB(event);
}
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55m_start(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;
    TIMER_CFG_T cfg;
    Timer_ISREvent_t cb_event;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef IP_timer
    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(cb_event))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));
    psa_read(msg->handle, 1, &cb_event, sizeof(cb_event));

    g_cm55mtimerISR_NS_CB = (Timer_ISREvent_NS_t) cmse_nsfptr_create(cb_event);
    return_value = hx_drv_timer_cm55m_start(&cfg, cm55m_timer_fire);
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_timer_cm55m_stop(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef IP_timer
    g_cm55mtimerISR_NS_CB = NULL;
    return_value = hx_drv_timer_cm55m_stop();
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
//#else //#ifdef CM55_BIG
Timer_ISREvent_NS_t g_cm55stimerISR_NS_CB = NULL;
//Periodic Timer Callback
void cm55s_timer_fire(uint32_t event)
{
    //trigger capture frame
    if(g_cm55stimerISR_NS_CB != NULL)
        g_cm55stimerISR_NS_CB(event);
}
enum tfm_hx_err_t tfm_hx_veneer_timer_cm55s_start(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;
    TIMER_CFG_T cfg;
    Timer_ISREvent_t cb_event;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef CM55_SMALL
    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(cb_event))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));
    psa_read(msg->handle, 1, &cb_event, sizeof(cb_event));

    g_cm55stimerISR_NS_CB = (Timer_ISREvent_NS_t) cmse_nsfptr_create(cb_event);
    return_value = hx_drv_timer_cm55s_start(&cfg, cm55s_timer_fire);
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_timer_cm55s_stop(const psa_msg_t *msg)
{
    TIMER_ERROR_E return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

#ifdef CM55_SMALL
    g_cm55stimerISR_NS_CB = NULL;
    return_value = hx_drv_timer_cm55s_stop();
#else
    return_value = TIMER_UNKNOWN_ERROR;
#endif

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
//#endif //#ifdef CM55_BIG

/////////////////// veneer_clk_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_timer_clk_en(const psa_msg_t *msg)
{
    uint32_t return_value;
    TIMER_ID_E id;
    uint8_t clk_en;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_en))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &clk_en, sizeof(clk_en));

    return_value = hx_drv_scu_set_timer_clk_en(id, clk_en);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_timer_clkdiv(const psa_msg_t *msg)
{
    uint32_t return_value;
    TIMER_ID_E id;
    uint32_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &clk_div, sizeof(clk_div));

    return_value = hx_drv_scu_set_timer_clkdiv(id, clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_wdg_clk_en(const psa_msg_t *msg)
{
    uint32_t return_value;
    WATCHDOG_ID_E id;
    uint8_t clk_en;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_en))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &clk_en, sizeof(clk_en));

    return_value = hx_drv_scu_set_wdg_clk_en(id, clk_en);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_wdg_clkdiv(const psa_msg_t *msg)
{
    uint32_t return_value;
    WATCHDOG_ID_E id;
    uint32_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &clk_div, sizeof(clk_div));

    return_value = hx_drv_scu_set_wdg_clkdiv(id, clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_rtc_clk_en(const psa_msg_t *msg)
{
    uint32_t return_value;
    RTC_ID_E id;
    uint8_t clk_en;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_en))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &clk_en, sizeof(clk_en));

    return_value = hx_drv_scu_set_rtc_clk_en(id, clk_en);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_ctrl_set_rtc_cycle(const psa_msg_t *msg)
{
    uint32_t return_value;
    RTC_ID_E id;
    uint32_t cycle_width;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(cycle_width))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &cycle_width, sizeof(cycle_width));

    return_value = hx_drv_scu_set_rtc_cycle(id, cycle_width);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_freq(const psa_msg_t *msg)
{
    uint32_t freq;

    SCU_CLK_FREQ_TYPE_E type;

    if (msg->out_size[0] != sizeof(freq))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(type))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &type, sizeof(type));

    if (SCU_NO_ERROR != hx_drv_scu_get_freq(type, &freq))
        freq = 0;

    psa_write(msg->handle, 0, &freq, sizeof(freq));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_vad_d_src_sel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_LSCVADDCLKSRC_E data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_vad_d_src_sel(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_vad_d_src_sel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_LSCVADDCLKSRC_E data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_vad_d_src_sel(&data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &data, sizeof(data));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_i2s_clkdiv(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &clk_div, sizeof(clk_div));

    return_value = hx_drv_scu_set_i2s_clkdiv(clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_i2s_clkdiv(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_i2s_clkdiv(&clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &clk_div, sizeof(clk_div));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdm_clkdiv(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &clk_div, sizeof(clk_div));

    return_value = hx_drv_scu_set_pdm_clkdiv(clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdm_clkdiv(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t clk_div;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(clk_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdm_clkdiv(&clk_div);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &clk_div, sizeof(clk_div));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_xtal32k_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_xtal32k_en(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_xtal32k_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_xtal32k_en(&enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &enable, sizeof(enable));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_xtal24m_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_xtal24m_en(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_xtal24m_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_xtal24m_en(&enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &enable, sizeof(enable));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pll_cfg(const psa_msg_t *msg)
{    
    SCU_ERROR_E return_value;
    SCU_PLL_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pll_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
#endif

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PLL_CLK_CFG_T pll_cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(pll_cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pll_cfg(&pll_cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &pll_cfg, sizeof(pll_cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_src(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PLLCLKSRC_E pllclksrc;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(pllclksrc))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pll_src(&pllclksrc);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &pllclksrc, sizeof(pllclksrc));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pll_enable(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_pll_enable(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
#endif

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pll_lock_status(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t lock;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(lock))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pll_lock_status(&lock);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &lock, sizeof(lock));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_dpclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_DPCLK_CFG_T cfg;
    uint8_t change_dprx;
    uint8_t change_dp;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(change_dprx))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] != sizeof(change_dp))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));
    psa_read(msg->handle, 1, &change_dprx, sizeof(change_dprx));
    psa_read(msg->handle, 2, &change_dp, sizeof(change_dp));

    return_value = hx_drv_scu_set_pdhsc_dpclk_cfg(cfg, change_dprx, change_dp);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_dpclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_DPCLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdhsc_dpclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_dpclken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_DPCLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdhsc_dpclken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_dpclken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_DPCLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_set_pdhsc_dpclken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_hscclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_HSCCLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdhsc_hscclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_hscclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_HSCCLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdhsc_hscclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_hsc32kclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_HSC32KCLKSRC_E cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdhsc_hsc32kclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_hsc32kclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_HSC32KCLKSRC_E cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdhsc_hsc32kclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_adcckinclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_ADCCKIN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_adcckinclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdhsc_clken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_clken_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdsb_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDSB_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdsb_clken_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdaon_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDAON_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdaon_clken_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_rtc_state(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    RTC_ID_E id; 
    SCU_RTC_STATE_E state;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(state))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &state, sizeof(state));

    return_value = hx_drv_scu_set_rtc_state(id, state);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

#ifdef TODO
enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdhsc_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdhsc_clk_cfg(cfg.hsc_cfg,
                                                cfg.change_dprx, 
                                                cfg.change_dp, 
                                                cfg.hsc32k_src_change, 
                                                cfg.purf_src_change, 
                                                cfg.qspi_change, 
                                                cfg.ospi_change);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdhsc_clk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdhsc_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDHSC_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdhsc_clken_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_dpclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_DPCLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_dpclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_dpclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_DPCLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_dpclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_dpclken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_DPCLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_dpclken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_dpclken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_DPCLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_dpclken_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_lscclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_LSC_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_lscclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_lscclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_LSC_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_lscclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_lscrefclk_cfg(const psa_msg_t *msg)
{
    SCU_PDLSC_LSCREF_CFG_T cfg;
    SCU_ERROR_E return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_lscrefclk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_lscrefclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_LSCREF_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_lscrefclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_adcckinclk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_ADCCKIN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_adcckinclk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_CLK_CFG_T cfg;
    uint8_t change_dp;
    uint8_t vad_src_change;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(change_dp))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] != sizeof(vad_src_change))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));
    psa_read(msg->handle, 1, &change_dp, sizeof(change_dp));
    psa_read(msg->handle, 2, &vad_src_change, sizeof(vad_src_change));

    //return_value = hx_drv_scu_set_pdlsc_clk_cfg(cfg, change_dp, vad_src_change);
    //too few arguments to function 'hx_drv_scu_set_pdlsc_clk_cfg'

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdlsc_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdlsc_clk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdlsc_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDLSC_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdlsc_clken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdsb_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDSB_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdsb_clk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdsb_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDSB_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdsb_clk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdsb_clken_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDSB_CLKEN_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdsb_clken_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_set_pdaon_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDAON_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_pdaon_clk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_pdaon_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDAON_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_pdaon_clk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
#endif
#ifdef CM55_BIG
enum tfm_hx_err_t tfm_hx_veneer_clk_set_simple_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SIMPLE_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_simple_clk_cfg(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_clk_get_simple_clk_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SIMPLE_CLK_CFG_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_simple_clk_cfg(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
#endif

/////////////////// veneer_sys_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_sys_get_u55_state(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_U55_STATE_E state;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(state))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_u55_state(&state);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &state, sizeof(state));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_U55_PORPL(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_U55_PORPL_E data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_U55_PORPL(&data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &data, sizeof(data));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_cm55s_state(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_CM55S_STATE_E state;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(state))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_cm55s_state(&state);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &state, sizeof(state));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2S_mode(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_I2S_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &mode, sizeof(mode));

    return_value = hx_drv_scu_set_I2S_mode(mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_I2S_mode(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_I2S_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_I2S_mode(&mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &mode, sizeof(mode));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PDM_IP(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDM_IP_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &mode, sizeof(mode));

    return_value = hx_drv_scu_set_PDM_IP(mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_PDM_IP(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PDM_IP_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_PDM_IP(&mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &mode, sizeof(mode));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_xip_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_xip_en(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_xip_en(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_ospi_xip_en(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_slave(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_ospi_slave(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_ospi_resetn(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint8_t normal;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(normal))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &normal, sizeof(normal));

    return_value = hx_drv_scu_set_ospi_resetn(normal);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_vad_d_pcm_sel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_VAD_PCM_DATA_SEL_E data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_vad_d_pcm_sel(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfval(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_sdio_itcfval(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfmul(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_sdio_itcfmul(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_sdio_itcfsel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t data;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &data, sizeof(data));

    return_value = hx_drv_scu_set_sdio_itcfsel(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_version(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t version1;
    uint32_t version2;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(version1))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[2] != sizeof(version2))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_version(&version1, &version2);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &version1, sizeof(version1));
    psa_write(msg->handle, 2, &version2, sizeof(version2));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA1_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PA1_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PA1_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA0_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PA0_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PA0_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA2_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PA2_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PA2_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PA3_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PA3_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PA3_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_sensor_i2cm_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_I2CM_SDA_PINMUX_E i2cm_sda;
    SCU_SEN_I2CM_SCL_PINMUX_E i2cm_scl;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(i2cm_sda))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(i2cm_scl))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &i2cm_sda, sizeof(i2cm_sda));
    psa_read(msg->handle, 1, &i2cm_scl, sizeof(i2cm_scl));

    hx_drv_scu_set_SEN_I2C_MST_SDA_pinmux(i2cm_sda);
    hx_drv_scu_set_SEN_I2C_MST_SCL_pinmux(i2cm_scl);

    return_value = SCU_NO_ERROR;
    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_FAE_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_FAE_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_FAE_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_TRIG_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_TRIG_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_TRIG_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_INT_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_INT_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_INT_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_XSLEEP_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_XSLEEP_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_XSLEEP_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_MCLK_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_MCLK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_MCLK_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_sensorgpio_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_GPIO_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_GPIO_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_CSW0_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_CSW0_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_CSW0_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_CSW1_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_CSW1_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_CSW1_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D1_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D1_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D1_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D2_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D2_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D2_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D3_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D3_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D3_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D4_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D4_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D4_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D5_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D5_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D5_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D6_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D6_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D6_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_D7_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_D7_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_D7_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_FVALID_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_FVALID_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_FVALID_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_LVALID_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_LVALID_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_LVALID_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SEN_PCLKO_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SEN_PCLK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SEN_PCLKO_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_SDCLK_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_SDCLK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_SDCLK_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_CMD_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_CMD_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_CMD_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT0_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_DATA0_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_DAT0_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT1_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_DATA1_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_DAT1_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT2_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_DATA2_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_DAT2_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SDIO_DAT3_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SDIO_DATA3_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SDIO_DAT3_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SW_DATA_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SW_DATA_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SW_DATA_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SW_CLK_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SW_CLK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SW_CLK_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB2_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB2_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB2_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB3_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB3_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB3_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB4_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB4_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB4_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB5_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB5_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB5_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB6_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB6_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB6_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB7_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB7_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB7_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB8_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB8_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB8_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB9_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB9_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB9_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB10_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB10_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB10_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB11_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB11_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB11_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PC3_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PC3_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PC3_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PC4_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PC4_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PC4_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2CM_SCLSDA_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_I2CM_SCLSDA_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_I2CM_SCLSDA_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB0_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB0_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB0_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_PB1_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PB1_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_PB1_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_UART_RX_TX_CTS_RTS_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_UART_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_UART_RX_TX_CTS_RTS_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_DO_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SPIS_DO_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SPIS_DO_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_DI_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SPIS_DI_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SPIS_DI_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_SCLK_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SPIS_SCLK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SPIS_SCLK_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_SPIS_CS_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SPIS_CS_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SPIS_CS_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_I2C_SLV_share_enable(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_I2CSLV_SHARE_E enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_I2C_SLV_share_enable(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_I3C_SLV_share_enable(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_I3CSLV_SHARE_E enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_drv_scu_set_I3C_SLV_share_enable(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_DP_SWReset(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_DP_SWRESET_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_DP_SWReset(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_get_DP_SWReset(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_DP_SWRESET_T cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_DP_SWReset(&cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &cfg, sizeof(cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_pdlsc_pdmck_src(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_LSCPDMCLKSRC_E pdmsrc_clk;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(pdmsrc_clk))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_set_pdlsc_pdmck_src(pdmsrc_clk);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &pdmsrc_clk, sizeof(pdmsrc_clk));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_wdt_ctrl(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t id;
    SCU_WDTCTRL_E ctrl;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(ctrl))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &ctrl, sizeof(ctrl));

    return_value = hx_drv_scu_set_wdt_ctrl(id, ctrl);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_sys_set_timer_ctrl(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    uint32_t id;
    SCU_TIMERCTRL_E ctrl;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(id))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(ctrl))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &id, sizeof(id));
    psa_read(msg->handle, 1, &ctrl, sizeof(ctrl));

    return_value = hx_drv_scu_set_timer_ctrl(id, ctrl);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_audio_capture_channel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_AUDIO_HWTYPE_E audio_type;
    SCU_AUDIO_CAPTURE_CHANNEL_E channel;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(audio_type))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(channel))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &audio_type, sizeof(audio_type));
    psa_read(msg->handle, 1, &channel, sizeof(channel));

    return_value = hx_drv_scu_set_audio_capture_channel(audio_type, channel);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_get_audio_capture_channel(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_AUDIO_CAPTURE_CHANNEL_E channel;
    SCU_AUDIO_HWTYPE_E audio_type;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(channel))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(audio_type))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &audio_type, sizeof(audio_type));

    return_value = hx_drv_scu_get_audio_capture_channel(audio_type, &channel);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &channel, sizeof(channel));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_lsc_adclv_reset(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SWRESET_E cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_lsc_adclv_reset(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_lsc_adchv_reset(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_SWRESET_E cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cfg, sizeof(cfg));

    return_value = hx_drv_scu_set_lsc_adchv_reset(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_SRSTN_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PAD_SRSTN_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SRSTN_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_SWCLKTCK_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PAD_SWCLK_TCK_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SWCLKTCK_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_SWDIO_TMS_pinmux(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PAD_SWDIO_TMS_PINMUX_E pinmux;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux, sizeof(pinmux));

    return_value = hx_drv_scu_set_SWDIO_TMS_pinmux(pinmux);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_get_all_pinmux_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PINMUX_CFG_T pinmux_cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(pinmux_cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_drv_scu_get_all_pinmux_cfg(&pinmux_cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &pinmux_cfg, sizeof(pinmux_cfg));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_set_all_pinmux_cfg(const psa_msg_t *msg)
{
    SCU_ERROR_E return_value;
    SCU_PINMUX_CFG_T pinmux_cfg;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(pinmux_cfg))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &pinmux_cfg, sizeof(pinmux_cfg));

    return_value = hx_drv_scu_set_all_pinmux_cfg(&pinmux_cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_get_pllfreq(const psa_msg_t *msg)
{
    uint32_t freq;

    if (msg->out_size[0] != sizeof(freq))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    hx_drv_swreg_aon_get_pllfreq(&freq);

    psa_write(msg->handle, 0, &freq, sizeof(freq));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

/////////////////// veneer_power_ctrl ///////////////////
#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_pmutocpuctrl_NS_t)(void);
#else
typedef void (*sensordplib_pmutocpuctrl_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif

#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_waitpmudmadone_NS_t)(void);
#else
typedef void (*sensordplib_waitpmudmadone_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif

#if defined(__IAR_SYSTEMS_ICC__)
typedef __cmse_nonsecure_call void (*sensordplib_pmudpinit_NS_t)(void);
#else
typedef void (*sensordplib_pmudpinit_NS_t)(void) __attribute__((cmse_nonsecure_call));
#endif

sensordplib_waitpmudmadone_NS_t g_sensordplib_waitpmudmadoneCB = NULL;
sensordplib_pmutocpuctrl_NS_t g_sensordplib_pmutocpuctrlCB = NULL;
sensordplib_pmudpinit_NS_t g_sensordplib_pmudpinitCB = NULL;

void sensordplib_pmutocpuctrl_s()
{
	if(g_sensordplib_pmutocpuctrlCB !=NULL )
		g_sensordplib_pmutocpuctrlCB();
}

void sensordplib_waitpmudmadone_s()
{
	if(g_sensordplib_waitpmudmadoneCB !=NULL )
		g_sensordplib_waitpmudmadoneCB();
}

void sensordplib_pmudpinit_s()
{
	if(g_sensordplib_pmudpinitCB !=NULL )
		g_sensordplib_pmudpinitCB();
}

enum tfm_hx_err_t tfm_hx_veneer_pm_get_defcfg_bymode(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    uint8_t *cfg;

    PM_CFG_PWR_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &mode, sizeof(mode));

    cfg = (uint8_t *)malloc(msg->out_size[0]);

    return_value = hx_lib_pm_get_defcfg_bymode(cfg, mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, cfg, msg->out_size[0]);
    free(cfg);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_pmu_dpdone_check(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    sensordplib_waitpmudmadone_t cb_fun;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(sensordplib_waitpmudmadone_t))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cb_fun, sizeof(sensordplib_waitpmudmadone_t));

	g_sensordplib_waitpmudmadoneCB = (sensordplib_waitpmudmadone_NS_t) cmse_nsfptr_create(cb_fun);

    return_value = hx_lib_pm_pmu_dpdone_check(sensordplib_waitpmudmadone_s);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_ctrl_fromPMUtoCPU(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    sensordplib_pmutocpuctrl_t cb_fun;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(sensordplib_pmudpinit_t))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &cb_fun, sizeof(sensordplib_pmudpinit_t));

	g_sensordplib_pmutocpuctrlCB = (sensordplib_pmutocpuctrl_NS_t) cmse_nsfptr_create(cb_fun);

    return_value = hx_lib_pm_ctrl_fromPMUtoCPU(sensordplib_pmutocpuctrl_s);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_cfg_set(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    void *cfg;
    sensordplib_pmudpinit_t cb_fun;
    PM_CFG_PWR_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != 0 && msg->in_size[0] <= 512)
        cfg = (void *)malloc(msg->in_size[0]);
    else
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(cb_fun)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] != sizeof(mode)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, cfg, msg->in_size[0]);
    psa_read(msg->handle, 1, &cb_fun, sizeof(cb_fun));
    psa_read(msg->handle, 2, &mode, sizeof(mode));

	g_sensordplib_pmudpinitCB = (sensordplib_pmudpinit_NS_t) cmse_nsfptr_create(cb_fun);
    return_value = hx_lib_pm_cfg_set(cfg, sensordplib_pmudpinit_s, mode);
    free(cfg);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_cfg_get(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    void *cfg;
    PM_CFG_PWR_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[0] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &mode, sizeof(mode));

    cfg = (void *)malloc(msg->out_size[0]);

    return_value = hx_lib_pm_cfg_get(cfg, mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, cfg, msg->out_size[0]);
    free(cfg);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_mode_get(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    PM_CFG_PWR_MODE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(mode))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_pm_mode_get(&mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &mode, sizeof(mode));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_trigger(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    SCU_PDHSC_HSCCLK_CFG_T hsc_cfg;
    SCU_LSC_CLK_CFG_T lsc_cfg;
    PM_CLK_PARA_CTRL_E clk_ctrl;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(hsc_cfg)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(lsc_cfg)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] != sizeof(clk_ctrl))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &hsc_cfg, sizeof(hsc_cfg));
    psa_read(msg->handle, 1, &lsc_cfg, sizeof(lsc_cfg));
    psa_read(msg->handle, 2, &clk_ctrl, sizeof(clk_ctrl));

    return_value = hx_lib_pm_trigger(hsc_cfg, lsc_cfg, clk_ctrl);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_get_event(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    PMU_WAKEUPEVENT_E aWakeupEvt;
    PMU_WAKEUPEVENT1_E aWakeupEvt1;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(aWakeupEvt))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[2] != sizeof(aWakeupEvt1))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_pm_get_event(&aWakeupEvt, &aWakeupEvt1);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &aWakeupEvt, sizeof(aWakeupEvt));
    psa_write(msg->handle, 2, &aWakeupEvt1, sizeof(aWakeupEvt1));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_clear_event(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_pm_clear_event();

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_force_state_set(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    PMU_PS_STATE_E state;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(state)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &state, sizeof(state));

    return_value = hx_lib_pm_force_state_set(state);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_force_state_get(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    PMU_PS_STATE_E state;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(state))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_pm_force_state_get(&state);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &state, sizeof(state));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_set_dma_cfg(const psa_msg_t *msg)
{
    PMU_ERROR_E return_value;
    uint8_t dma_int;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(dma_int)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &dma_int, sizeof(dma_int));

    return_value = hx_drv_pmu_set_ctrl(PMU_REG_PMU_DMA_CFG, dma_int);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_pm_ext_int_get(const psa_msg_t *msg)
{
    PM_ERROR_E return_value;
    PM_EXT_INT_STATUS_TYPE_E type;
    uint8_t status;

    if (msg->in_size[0] != sizeof(type)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(status))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &type, sizeof(type));

    return_value = hx_lib_pm_ext_int_get(type, &status);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &status, sizeof(status));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_get_pmuwakeup_freq(const psa_msg_t *msg)
{
    SCU_PLL_FREQ_E pll_freq;
    SCU_HSCCLKDIV_E cm55m_div;
    SCU_LSCCLKDIV_E cm55s_div;

    if (msg->out_size[0] != sizeof(pll_freq))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(cm55m_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[2] != sizeof(cm55s_div))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    hx_drv_swreg_aon_get_pmuwakeup_freq(&pll_freq, &cm55m_div, &cm55s_div);

    psa_write(msg->handle, 0, &pll_freq, sizeof(pll_freq));
    psa_write(msg->handle, 1, &cm55m_div, sizeof(cm55m_div));
    psa_write(msg->handle, 2, &cm55s_div, sizeof(cm55s_div));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

/////////////////// veneer_eeprom_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_open(const psa_msg_t *msg)
{
    int32_t return_value;
    VENEER_SPI_EEPROM_E spi_id;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    return_value = hx_lib_spi_eeprom_open((USE_DW_SPI_MST_E) spi_id);
    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_open_speed(const psa_msg_t *msg)
{
    int32_t return_value;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t clk_hz;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(clk_hz)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &clk_hz, sizeof(clk_hz));

    return_value = hx_lib_spi_eeprom_open_speed((USE_DW_SPI_MST_E) spi_id, clk_hz);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_read_ID(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t id_info;
    VENEER_SPI_EEPROM_E spi_id;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(id_info))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));

    return_value = hx_lib_spi_eeprom_read_ID((USE_DW_SPI_MST_E) spi_id, &id_info);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &id_info, sizeof(id_info));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_1read(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));

    data = (uint8_t *)malloc(msg->out_size[1]);

    return_value = hx_lib_spi_eeprom_1read((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->out_size[1]);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, data, msg->out_size[1]);
    free(data);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_2read(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));

    data = (uint8_t *)malloc(msg->out_size[1]);

    return_value = hx_lib_spi_eeprom_2read((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->out_size[1]);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, data, msg->out_size[1]);
    free(data);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_4read(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));

    data = (uint8_t *)malloc(msg->out_size[1]);

    return_value = hx_lib_spi_eeprom_4read((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->out_size[1]);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, data, msg->out_size[1]);
    free(data);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_word_read(const psa_msg_t *msg)
{
    int32_t return_value;
    uint32_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] <= 0 || msg->out_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));

    data = (uint32_t *)malloc(msg->out_size[1]);

    return_value = hx_lib_spi_eeprom_word_read((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->out_size[1]);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, data, msg->out_size[1]);
    free(data);

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_word_write(const psa_msg_t *msg)
{
    int32_t return_value;
    uint32_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] <= 0 || msg->in_size[2] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    data = (uint32_t *)malloc(msg->in_size[2]);

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));
    psa_read(msg->handle, 2, data, msg->in_size[2]);

    return_value = hx_lib_spi_eeprom_word_write((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->in_size[2]);
    free(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_write(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t* data;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t flash_addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(flash_addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[2] <= 0 || msg->in_size[2] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    data = (uint8_t *)malloc(msg->in_size[2]);

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &flash_addr, sizeof(flash_addr));
    psa_read(msg->handle, 2, data, msg->in_size[2]);

    return_value = hx_lib_spi_eeprom_write((USE_DW_SPI_MST_E) spi_id, flash_addr, data, msg->in_size[2], 0);
    free(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_Send_Op_code(const psa_msg_t *msg)
{
    int32_t return_value;
    uint8_t* data;
    VENEER_SPI_EEPROM_E spi_id;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] <= 0 || msg->in_size[1] > 512)
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    data = (uint8_t *)malloc(msg->in_size[1]);

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, data, msg->in_size[1]);

    return_value = hx_lib_spi_eeprom_Send_Op_code((USE_DW_SPI_MST_E) spi_id, data, msg->in_size[1]);
    free(data);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_erase_all(const psa_msg_t *msg)
{
    int32_t return_value;
    VENEER_SPI_EEPROM_E spi_id;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));

    return_value = hx_lib_spi_eeprom_erase_all((USE_DW_SPI_MST_E) spi_id);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_erase_sector(const psa_msg_t *msg)
{
    int32_t return_value;
    VENEER_SPI_EEPROM_E spi_id;
    uint32_t addr;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(spi_id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(addr)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &spi_id, sizeof(spi_id));
    psa_read(msg->handle, 1, &addr, sizeof(addr));

    return_value = hx_lib_spi_eeprom_erase_sector((USE_DW_SPI_MST_E) spi_id, addr, FLASH_SECTOR);
    //return_value = hx_lib_spi_eeprom_erase_sector((USE_DW_SPI_MST_E) spi_id, addr);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_eeprom_enable_XIP(const psa_msg_t *msg)
{
    int32_t return_value;
    typedef struct veneer_spi_eeprom_enable_XIP_in_para_t {
        VENEER_SPI_EEPROM_E spi_id;
        bool xip_enable;
        VENEER_FLASH_ACCESS_MODE_E xip_mode;
        bool xip_cont;
    } veneer_spi_eeprom_enable_XIP_in_para_t;

    veneer_spi_eeprom_enable_XIP_in_para_t in_para;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(in_para)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &in_para, sizeof(in_para));

    return_value = hx_lib_spi_eeprom_enable_XIP((USE_DW_SPI_MST_E)in_para.spi_id, 
                                                 in_para.xip_enable, 
                                                 (FLASH_ACCESS_MODE_E) in_para.xip_mode,
                                                 in_para.xip_cont);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

/////////////////// veneer_psram_ctrl ///////////////////
enum tfm_hx_err_t tfm_hx_veneer_spi_psram_open(const psa_msg_t *msg)
{
    int32_t return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_spi_psram_open();

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_psram_SetXIP(const psa_msg_t *msg)
{
    int32_t return_value;
    bool enable;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(enable)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &enable, sizeof(enable));

    return_value = hx_lib_spi_psram_SetXIP(enable);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_psram_set_powermode(const psa_msg_t *msg)
{
    int32_t return_value;
    VENEER_PSRAM_POWER_MDOE_E mode;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(mode)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &mode, sizeof(mode));

    return_value = hx_lib_spi_psram_set_powermode((PSRAM_POWER_MDOE_E)mode);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_psram_get_info(const psa_msg_t *msg)
{
    int32_t return_value;
    uint32_t data;
    uint32_t reg;
    uint32_t id;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->out_size[1] != sizeof(data))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[0] != sizeof(reg)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    if (msg->in_size[1] != sizeof(id)) 
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    psa_read(msg->handle, 0, &reg, sizeof(reg));
    psa_read(msg->handle, 1, &id, sizeof(id));

    return_value = hx_lib_spi_psram_get_info(&data, reg, id);

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));
    psa_write(msg->handle, 1, &data, sizeof(data));

    return TFM_FLIH_HX_ERR_SUCCESS;
}

enum tfm_hx_err_t tfm_hx_veneer_spi_psram_close(const psa_msg_t *msg)
{
    int32_t return_value;

    if (msg->out_size[0] != sizeof(return_value))
        return (enum tfm_hx_err_t) PSA_ERROR_PROGRAMMER_ERROR;

    return_value = hx_lib_spi_psram_close();

    psa_write(msg->handle, 0, &return_value, sizeof(return_value));

    return TFM_FLIH_HX_ERR_SUCCESS;
}
